@@ -17,12 +17,12 @@ describe('TopSearchBarSection', () => {
     (window.matchMedia as jest.Mock).mockImplementation(() => ({
       addEventListener: jest.fn(),
       removeEventListener: jest.fn(),
-      matches: () => false,
+      matches: true,
     }));
 
-    const { container } = renderComponent();
+    const component = renderComponent();
 
-    expect(container.querySelector('[data-test-id="wrapper"]')).toBeInTheDocument();
+    expect(component.queryByTestId('wrapper')).toBeInTheDocument();
     expect(screen.getByRole('button', { name: /test item/i })).toBeInTheDocument();
   });
 
@@ -30,12 +30,12 @@ describe('TopSearchBarSection', () => {
     (window.matchMedia as jest.Mock).mockImplementation(() => ({
       addEventListener: jest.fn(),
       removeEventListener: jest.fn(),
-      matches: () => true,
+      matches: false,
     }));
 
-    const { container } = renderComponent();
+    const component = renderComponent();
 
-    expect(container.querySelector('[data-test-id="wrapper"]')).not.toBeInTheDocument();
+    expect(component.queryByTestId('wrapper')).not.toBeInTheDocument();
     expect(screen.getByRole('button', { name: /test item/i })).toBeInTheDocument();
   });
 });
