@@ -1,14 +1,12 @@
 import React, { useCallback } from 'react';
 
-import { FieldConfigEditorProps, NumberFieldConfigSettings } from '@grafana/data';
+import { StandardEditorProps, NumberFieldConfigSettings } from '@grafana/data';
 
 import { NumberInput } from './NumberInput';
 
-export const NumberValueEditor: React.FC<FieldConfigEditorProps<number, NumberFieldConfigSettings>> = ({
-  value,
-  onChange,
-  item,
-}) => {
+type Props = StandardEditorProps<number, NumberFieldConfigSettings>;
+
+export const NumberValueEditor = ({ value, onChange, item }: Props) => {
   const { settings } = item;
 
   const onValueChange = useCallback(
