@@ -1,11 +1,12 @@
-import React, { FC } from 'react';
+import React from 'react';
+
 import { LoadingPlaceholder } from '@grafana/ui';
 
 interface Props {
   pageName?: string;
 }
 
-const PageLoader: FC<Props> = ({ pageName = '' }) => {
+const PageLoader = ({ pageName = '' }: Props) => {
   const loadingText = `Loading ${pageName}...`;
   return (
     <div className="page-loader-wrapper">
