@@ -1,7 +1,7 @@
 import React from 'react';
 
 import { DataFrame, FALLBACK_COLOR, FieldType, TimeRange } from '@grafana/data';
-import { VisibilityMode, TimelineValueAlignment } from '@grafana/schema';
+import { VisibilityMode, TimelineValueAlignment, TooltipDisplayMode } from '@grafana/schema';
 import { PanelContext, PanelContextRoot, UPlotConfigBuilder, VizLayout, VizLegend, VizLegendItem } from '@grafana/ui';
 
 import { GraphNG, GraphNGProps } from '../GraphNG/GraphNG';
@@ -58,6 +58,8 @@ export class TimelineChart extends React.Component<TimelineProps> {
       // When there is only one row, use the full space
       rowHeight: alignedFrame.fields.length > 2 ? this.props.rowHeight : 1,
       getValueColor: this.getValueColor,
+      // @ts-ignore
+      hoverMulti: this.props.tooltip?.mode === TooltipDisplayMode.Multi,
     });
   };
 
