@@ -1,20 +1,24 @@
 import { css } from '@emotion/css';
 import React from 'react';
 
-import { LoadingPlaceholder, useStyles2 } from '@grafana/ui';
+import { GrafanaTheme2 } from '@grafana/data';
+import { useStyles2 } from '@grafana/ui';
+
+import { BouncingLoader } from '../components/BouncingLoader/BouncingLoader';
 
 export function GrafanaRouteLoading() {
   const styles = useStyles2(getStyles);
 
   return (
     <div className={styles.loadingPage}>
-      <LoadingPlaceholder text={'Loading...'} />
+      <BouncingLoader />
     </div>
   );
 }
 
-const getStyles = () => ({
+const getStyles = (theme: GrafanaTheme2) => ({
   loadingPage: css({
+    backgroundColor: theme.colors.background.primary,
     height: '100%',
     flexDrection: 'column',
     display: 'flex',
