@@ -1,6 +1,6 @@
-import { getFlotTickDecimals } from 'app/core/utils/ticks';
-import _ from 'lodash';
-import { getValueFormat, ValueFormatter, stringToJsRegex, DecimalCount, formattedValueToString } from '@grafana/data';
+import { isNumber, isFinite, escape } from 'lodash';
+
+import { DecimalCount, formattedValueToString, getValueFormat, stringToJsRegex, ValueFormatter } from '@grafana/data';
 
 function matchSeriesOverride(aliasOrRegex: string, seriesAlias: string) {
   if (!aliasOrRegex) {
@@ -44,38 +44,16 @@ export function updateLegendValues(data: TimeSeries[], panel: any, height: numbe
     const formatter = getValueFormat(axis.format);
 
     // decimal override
-    if (_.isNumber(panel.decimals)) {
-      series.updateLegendValues(formatter, panel.decimals, null);
-    } else if (_.isNumber(axis.decimals)) {
-      series.updateLegendValues(formatter, axis.decimals + 1, null);
+    if (isNumber(panel.decimals)) {
+      series.updateLegendValues(formatter, panel.decimals);
+    } else if (isNumber(axis.decimals)) {
+      series.updateLegendValues(formatter, axis.decimals + 1);
     } else {
-      // auto decimals
-      // legend and tooltip gets one more decimal precision
-      // than graph legend ticks
-      const { datamin, datamax } = getDataMinMax(data);
-      const { tickDecimals, scaledDecimals } = getFlotTickDecimals(datamin, datamax, axis, height);
-      const tickDecimalsPlusOne = (tickDecimals || -1) + 1;
-      series.updateLegendValues(formatter, tickDecimalsPlusOne, scaledDecimals + 2);
+      series.updateLegendValues(formatter, null);
     }
   }
 }
 
-export function getDataMinMax(data: TimeSeries[]) {
-  let datamin = null;
-  let datamax = null;
-
-  for (const series of data) {
-    if (datamax === null || datamax < series.stats.max) {
-      datamax = series.stats.max;
-    }
-    if (datamin === null || datamin > series.stats.min) {
-      datamin = series.stats.min;
-    }
-  }
-
-  return { datamin, datamax };
-}
-
 /**
  * @deprecated: This class should not be used in new panels
  *
@@ -91,20 +69,19 @@ export default class TimeSeries {
   label: string;
   alias: string;
   aliasEscaped: string;
-  color: string;
+  color?: string;
   valueFormater: any;
   stats: any;
   legend: boolean;
-  hideTooltip: boolean;
-  allIsNull: boolean;
-  allIsZero: boolean;
-  decimals: number;
-  scaledDecimals: number;
+  hideTooltip?: boolean;
+  allIsNull?: boolean;
+  allIsZero?: boolean;
+  decimals: DecimalCount;
   hasMsResolution: boolean;
-  isOutsideRange: boolean;
+  isOutsideRange?: boolean;
 
   lines: any;
-  hiddenSeries: boolean;
+  hiddenSeries?: boolean;
   dashes: any;
   bars: any;
   points: any;
@@ -122,7 +99,7 @@ export default class TimeSeries {
     this.label = opts.alias;
     this.id = opts.alias;
     this.alias = opts.alias;
-    this.aliasEscaped = _.escape(opts.alias);
+    this.aliasEscaped = escape(opts.alias);
     this.color = opts.color;
     this.bars = { fillColor: opts.color };
     this.valueFormater = getValueFormat('none');
@@ -232,6 +209,7 @@ export default class TimeSeries {
     this.stats.first = null;
     this.stats.delta = 0;
     this.stats.diff = null;
+    this.stats.diffperc = 0;
     this.stats.range = null;
     this.stats.timeStep = Number.MAX_VALUE;
     this.allIsNull = true;
@@ -270,7 +248,7 @@ export default class TimeSeries {
       }
 
       if (currentValue !== null) {
-        if (_.isNumber(currentValue)) {
+        if (isNumber(currentValue)) {
           this.stats.total += currentValue;
           this.allIsNull = false;
           nonNulls++;
@@ -336,23 +314,23 @@ export default class TimeSeries {
     }
     if (this.stats.current !== null && this.stats.first !== null) {
       this.stats.diff = this.stats.current - this.stats.first;
+      this.stats.diffperc = this.stats.diff / this.stats.first;
     }
 
     this.stats.count = result.length;
     return result;
   }
 
-  updateLegendValues(formater: ValueFormatter, decimals: DecimalCount, scaledDecimals: DecimalCount) {
+  updateLegendValues(formater: ValueFormatter, decimals: DecimalCount) {
     this.valueFormater = formater;
     this.decimals = decimals;
-    this.scaledDecimals = scaledDecimals;
   }
 
-  formatValue(value: number) {
-    if (!_.isFinite(value)) {
+  formatValue(value: number | null) {
+    if (!isFinite(value)) {
       value = null; // Prevent NaN formatting
     }
-    return formattedValueToString(this.valueFormater(value, this.decimals, this.scaledDecimals));
+    return formattedValueToString(this.valueFormater(value, this.decimals));
   }
 
   isMsResolutionNeeded() {
