@@ -1,4 +1,4 @@
-import { nanoid } from '@reduxjs/toolkit';
+import { customAlphabet } from 'nanoid';
 import { Unsubscribable } from 'rxjs';
 import { v4 as uuidv4 } from 'uuid';
 
@@ -34,6 +34,9 @@ export const DEFAULT_UI_STATE = {
   dedupStrategy: LogsDedupStrategy.none,
 };
 
+export const ID_ALPHABET = '0123456789abcdefghijklmnopqrstuvwxyz';
+const nanoid = customAlphabet(ID_ALPHABET, 3);
+
 const MAX_HISTORY_ITEMS = 100;
 
 const LAST_USED_DATASOURCE_KEY = 'grafana.explore.datasource';
@@ -52,7 +55,13 @@ export interface GetExploreUrlArguments {
 }
 
 export function generateExploreId() {
-  return nanoid(3);
+  while (true) {
+    const id = nanoid(3);
+
+    if (!/^\d+$/.test(id)) {
+      return id;
+    }
+  }
 }
 
 /**
@@ -92,6 +101,10 @@ export async function getExploreUrl(args: GetExploreUrlArguments): Promise<strin
   return urlUtil.renderUrl('/explore', { panes: exploreState, schemaVersion: 1 });
 }
 
+export function requestIdGenerator(exploreId: string) {
+  return `explore_${exploreId}`;
+}
+
 export function buildQueryTransaction(
   exploreId: string,
   queries: DataQuery[],
@@ -101,19 +114,9 @@ export function buildQueryTransaction(
   timeZone?: TimeZone,
   scopedVars?: ScopedVars
 ): QueryTransaction {
-  const key = queries.reduce((combinedKey, query) => {
-    combinedKey += query.key;
-    return combinedKey;
-  }, '');
-
+  const panelId = Number.parseInt(exploreId, 36);
   const { interval, intervalMs } = getIntervals(range, queryOptions.minInterval, queryOptions.maxDataPoints);
 
-  // Most datasource is using `panelId + query.refId` for cancellation logic.
-  // Using `format` here because it relates to the view panel that the request is for.
-  // However, some datasources don't use `panelId + query.refId`, but only `panelId`.
-  // Therefore panel id has to be unique.
-  const panelId = `${key}`;
-
   const request: DataQueryRequest = {
     app: CoreApp.Explore,
     // TODO probably should be taken from preferences but does not seem to be used anyway.
@@ -121,12 +124,10 @@ export function buildQueryTransaction(
     startTime: Date.now(),
     interval,
     intervalMs,
-    // TODO: the query request expects number and we are using string here. Seems like it works so far but can create
-    // issues down the road.
-    panelId: panelId as any,
+    panelId,
     targets: queries, // Datasources rely on DataQueries being passed under the targets key.
     range,
-    requestId: 'explore_' + exploreId,
+    requestId: requestIdGenerator(exploreId),
     rangeRaw: range.raw,
     scopedVars: {
       __interval: { text: interval, value: interval },
@@ -266,12 +267,11 @@ const validKeys = ['refId', 'key', 'context', 'datasource'];
 export function hasNonEmptyQuery<TQuery extends DataQuery>(queries: TQuery[]): boolean {
   return (
     queries &&
-    queries.some((query: any) => {
-      const keys = Object.keys(query)
-        .filter((key) => validKeys.indexOf(key) === -1)
-        .map((k) => query[k])
-        .filter((v) => v);
-      return keys.length > 0;
+    queries.some((query) => {
+      const entries = Object.entries(query)
+        .filter(([key, _]) => validKeys.indexOf(key) === -1)
+        .filter(([_, value]) => value);
+      return entries.length > 0;
     })
   );
 }
@@ -317,10 +317,6 @@ export const getQueryKeys = (queries: DataQuery[]): string[] => {
 export const getTimeRange = (timeZone: TimeZone, rawRange: RawTimeRange, fiscalYearStartMonth: number): TimeRange => {
   let range = rangeUtil.convertRawToRange(rawRange, timeZone, fiscalYearStartMonth);
 
-  if (range.to.isBefore(range.from)) {
-    range = rangeUtil.convertRawToRange({ from: range.raw.to, to: range.raw.from }, timeZone, fiscalYearStartMonth);
-  }
-
   return range;
 };
 
@@ -342,10 +338,14 @@ export function getIntervals(range: TimeRange, lowLimit?: string, resolution?: n
 }
 
 export const copyStringToClipboard = (string: string) => {
-  const el = document.createElement('textarea');
-  el.value = string;
-  document.body.appendChild(el);
-  el.select();
-  document.execCommand('copy');
-  document.body.removeChild(el);
+  if (navigator.clipboard && window.isSecureContext) {
+    navigator.clipboard.writeText(string);
+  } else {
+    const el = document.createElement('textarea');
+    el.value = string;
+    document.body.appendChild(el);
+    el.select();
+    document.execCommand('copy');
+    document.body.removeChild(el);
+  }
 };
