@@ -1,6 +1,6 @@
 import React from 'react';
 
-import Page from 'app/core/components/Page/Page';
+import { Page } from 'app/core/components/Page/Page';
 import { useNavModel } from 'app/core/hooks/useNavModel';
 
 export default function FeatureTogglePage() {
