@@ -1,4 +1,4 @@
-import { getBackendSrv, locationService } from '@grafana/runtime';
+import { getBackendSrv, isFetchError, locationService } from '@grafana/runtime';
 import { notifyApp } from 'app/core/actions';
 import { createErrorNotification, createSuccessNotification } from 'app/core/copy/appNotification';
 import { AlertRuleDTO, NotifierDTO, ThunkResult } from 'app/types';
@@ -26,9 +26,11 @@ export function createNotificationChannel(data: any): ThunkResult<Promise<void>>
     try {
       await getBackendSrv().post(`/api/alert-notifications`, data);
       dispatch(notifyApp(createSuccessNotification('Notification created')));
-      locationService.push('/alerting/notifications');
+      locationService.push('/alerting-legacy/notifications');
     } catch (error) {
-      dispatch(notifyApp(createErrorNotification(error.data.error)));
+      if (isFetchError(error)) {
+        dispatch(notifyApp(createErrorNotification(error.data.error)));
+      }
     }
   };
 }
@@ -39,7 +41,9 @@ export function updateNotificationChannel(data: any): ThunkResult<void> {
       await getBackendSrv().put(`/api/alert-notifications/${data.id}`, data);
       dispatch(notifyApp(createSuccessNotification('Notification updated')));
     } catch (error) {
-      dispatch(notifyApp(createErrorNotification(error.data.error)));
+      if (isFetchError(error)) {
+        dispatch(notifyApp(createErrorNotification(error.data.error)));
+      }
     }
   };
 }
@@ -53,7 +57,7 @@ export function testNotificationChannel(data: any): ThunkResult<void> {
 
 export function loadNotificationTypes(): ThunkResult<void> {
   return async (dispatch) => {
-    const alertNotifiers: NotifierDTO[] = await getBackendSrv().get(`/api/alert-notifiers`);
+    const alertNotifiers: NotifierDTO[] = await getBackendSrv().get(`/api/alert-notifiers-legacy`);
 
     const notificationTypes = alertNotifiers.sort((o1, o2) => {
       if (o1.name > o2.name) {
