@@ -12,6 +12,6 @@ interface Props extends Omit<TabProps, 'counter' | 'ref'> {
 
 // it will load rule count from backend
 export const PanelAlertTab = ({ panel, dashboard, ...otherProps }: Props) => {
-  const { rules, loading } = usePanelCombinedRules({ panel, dashboard });
+  const { rules, loading } = usePanelCombinedRules({ panelId: panel.id, dashboardUID: dashboard.uid });
   return <Tab {...otherProps} counter={loading ? null : rules.length} />;
 };
