@@ -1,9 +1,10 @@
 import React, { PropsWithChildren } from 'react';
 import { useLocation } from 'react-use';
 
-import { NavModelItem } from '@grafana/data';
 import { Page } from 'app/core/components/Page/Page';
+import { PageProps } from 'app/core/components/Page/types';
 
+import { UAPreviewNotice } from '../../components/UAPreviewNotice';
 import { AlertmanagerProvider, useAlertmanager } from '../state/AlertmanagerContext';
 
 import { AlertManagerPicker } from './AlertManagerPicker';
@@ -12,19 +13,20 @@ import { NoAlertManagerWarning } from './NoAlertManagerWarning';
 /**
  * This is the main alerting page wrapper, used by the alertmanager page wrapper and the alert rules list view
  */
-interface AlertingPageWrapperProps extends PropsWithChildren {
-  pageId?: string;
+interface AlertingPageWrapperProps extends PageProps {
   isLoading?: boolean;
-  pageNav?: NavModelItem;
-  actions?: React.ReactNode;
 }
-export const AlertingPageWrapper = ({ children, pageId, pageNav, actions, isLoading }: AlertingPageWrapperProps) => {
-  return (
-    <Page pageNav={pageNav} navId={pageId} actions={actions}>
-      <Page.Contents isLoading={isLoading}>{children}</Page.Contents>
-    </Page>
-  );
-};
+
+export const AlertingPageWrapper = ({ children, isLoading, ...rest }: AlertingPageWrapperProps) => (
+  <Page {...rest}>
+    <Page.Contents isLoading={isLoading}>
+      <div>
+        <UAPreviewNotice />
+        {children}
+      </div>
+    </Page.Contents>
+  </Page>
+);
 
 /**
  * This wrapper is for pages that use the Alertmanager API
