@@ -5,13 +5,18 @@ import { Icon, IconName, useStyles2, Text, Stack } from '@grafana/ui';
 
 interface Props extends HTMLAttributes<HTMLDivElement> {
   icon?: IconName;
+  direction?: 'row' | 'column';
   color?: ComponentProps<typeof Text>['color'];
 }
 
-const MetaText = ({ children, icon, color = 'secondary', ...rest }: Props) => {
+const MetaText = ({ children, icon, color = 'secondary', direction = 'row', ...rest }: Props) => {
   const styles = useStyles2(getStyles);
   const interactive = typeof rest.onClick === 'function';
 
+  const rowDirection = direction === 'row';
+  const alignItems = rowDirection ? 'center' : 'flex-start';
+  const gap = rowDirection ? 0.5 : 0;
+
   return (
     <div
       className={cx({
@@ -21,7 +26,7 @@ const MetaText = ({ children, icon, color = 'secondary', ...rest }: Props) => {
       {...rest}
     >
       <Text variant="bodySmall" color={color}>
-        <Stack direction="row" alignItems="center" gap={0.5} wrap={'wrap'}>
+        <Stack direction={direction} alignItems={alignItems} gap={gap} wrap={'wrap'}>
           {icon && <Icon size="sm" name={icon} />}
           {children}
         </Stack>
