@@ -3,13 +3,11 @@ import userEvent from '@testing-library/user-event';
 import lodash from 'lodash'; // eslint-disable-line lodash/import-scope
 import React from 'react';
 
-import * as runtime from '@grafana/runtime';
-
-import { LogMessages } from '../../Analytics';
+import * as analytics from '../../Analytics';
 
 import { MatcherFilter } from './MatcherFilter';
 
-const logInfoSpy = jest.spyOn(runtime, 'logInfo');
+const logInfoSpy = jest.spyOn(analytics, 'logInfo');
 
 describe('Analytics', () => {
   beforeEach(() => {
@@ -25,7 +23,7 @@ describe('Analytics', () => {
     const searchInput = screen.getByTestId('search-query-input');
     await userEvent.type(searchInput, 'job=');
 
-    expect(logInfoSpy).toHaveBeenCalledWith(LogMessages.filterByLabel);
+    expect(logInfoSpy).toHaveBeenCalledWith(analytics.LogMessages.filterByLabel);
   });
 
   it('should call onChange handler', async () => {
