@@ -1,11 +1,11 @@
-import React, { FC } from 'react';
+import React from 'react';
 
 import { RuleFormType } from '../../../types/rule-form';
 
 import { DisabledTooltip } from './DisabledTooltip';
 import { RuleType, SharedProps } from './RuleType';
 
-const RecordingRuleType: FC<SharedProps> = ({ selected = false, disabled = false, onClick }) => {
+const RecordingRuleType = ({ selected = false, disabled = false, onClick }: SharedProps) => {
   return (
     <DisabledTooltip visible={disabled}>
       <RuleType
