@@ -9,7 +9,7 @@ import {
   ThresholdsConfig,
   ThresholdsMode,
 } from '@grafana/data';
-import { GraphTresholdsStyleMode } from '@grafana/schema';
+import { GraphThresholdsStyleMode } from '@grafana/schema';
 import { config } from 'app/core/config';
 import { EvalFunction } from 'app/features/alerting/state/alertDef';
 import { isExpressionQuery } from 'app/features/expressions/guards';
@@ -136,7 +136,7 @@ export function warningFromSeries(series: DataFrame[]): Error | undefined {
 
 export type ThresholdDefinition = {
   config: ThresholdsConfig;
-  mode: GraphTresholdsStyleMode;
+  mode: GraphThresholdsStyleMode;
 };
 
 export type ThresholdDefinitions = Record<string, ThresholdDefinition>;
@@ -144,10 +144,14 @@ export type ThresholdDefinitions = Record<string, ThresholdDefinition>;
 /**
  * This function will retrieve threshold definitions for the given array of data and expression queries.
  */
-export function getThresholdsForQueries(queries: AlertQuery[]) {
+export function getThresholdsForQueries(queries: AlertQuery[], condition: string | null) {
   const thresholds: ThresholdDefinitions = {};
   const SUPPORTED_EXPRESSION_TYPES = [ExpressionQueryType.threshold, ExpressionQueryType.classic];
 
+  if (!condition) {
+    return thresholds;
+  }
+
   for (const query of queries) {
     if (!isExpressionQuery(query.model)) {
       continue;
@@ -162,6 +166,10 @@ export function getThresholdsForQueries(queries: AlertQuery[]) {
       continue;
     }
 
+    if (query.model.refId !== condition) {
+      continue;
+    }
+
     // if any of the conditions are a "range" we switch to an "area" threshold view and ignore single threshold values
     // the time series panel does not support both.
     const hasRangeThreshold = query.model.conditions.some(isRangeCondition);
@@ -202,7 +210,7 @@ export function getThresholdsForQueries(queries: AlertQuery[]) {
                 mode: ThresholdsMode.Absolute,
                 steps: [],
               },
-              mode: GraphTresholdsStyleMode.Line,
+              mode: GraphThresholdsStyleMode.Line,
             };
           }
 
@@ -210,7 +218,7 @@ export function getThresholdsForQueries(queries: AlertQuery[]) {
             appendSingleThreshold(originRefID, threshold[0]);
           } else if (originRefID && hasValidOrigin && isRangeThreshold) {
             appendRangeThreshold(originRefID, threshold, condition.evaluator.type);
-            thresholds[originRefID].mode = GraphTresholdsStyleMode.LineAndArea;
+            thresholds[originRefID].mode = GraphThresholdsStyleMode.LineAndArea;
           }
         });
       } catch (err) {
