@@ -1,10 +1,9 @@
 import { css } from '@emotion/css';
-import { produce } from 'immer';
-import React, { useCallback, useEffect, useMemo, useState } from 'react';
-import { useObservable, useToggle } from 'react-use';
+import React, { useMemo } from 'react';
+import { useToggle } from 'react-use';
 
-import { GrafanaTheme2, LoadingState, PanelData, RelativeTimeRange } from '@grafana/data';
-import { config, isFetchError } from '@grafana/runtime';
+import { GrafanaTheme2 } from '@grafana/data';
+import { isFetchError } from '@grafana/runtime';
 import {
   Alert,
   Button,
@@ -12,27 +11,25 @@ import {
   Icon,
   IconButton,
   LoadingPlaceholder,
-  Stack,
-  VerticalGroup,
   useStyles2,
+  VerticalGroup,
+  Stack,
+  Text,
 } from '@grafana/ui';
 import { GrafanaRouteComponentProps } from 'app/core/navigation/types';
 
 import { DEFAULT_PER_PAGE_PAGINATION } from '../../../../../core/constants';
-import { AlertQuery, GrafanaRuleDefinition } from '../../../../../types/unified-alerting-dto';
-import { GrafanaRuleQueryViewer, QueryPreview } from '../../GrafanaRuleQueryViewer';
-import { useAlertQueriesStatus } from '../../hooks/useAlertQueriesStatus';
+import { GrafanaRuleDefinition } from '../../../../../types/unified-alerting-dto';
 import { useCombinedRule } from '../../hooks/useCombinedRule';
-import { AlertingQueryRunner } from '../../state/AlertingQueryRunner';
 import { useCleanAnnotations } from '../../utils/annotations';
 import { getRulesSourceByName } from '../../utils/datasource';
-import { alertRuleToQueries } from '../../utils/query';
 import * as ruleId from '../../utils/rule-id';
 import { isFederatedRuleGroup, isGrafanaRulerRule } from '../../utils/rules';
 import { AlertLabels } from '../AlertLabels';
 import { DetailsField } from '../DetailsField';
 import { ProvisionedResource, ProvisioningAlert } from '../Provisioning';
-import { RuleViewerLayout, RuleViewerLayoutContent } from '../rule-viewer/RuleViewerLayout';
+import { decodeGrafanaNamespace } from '../expressions/util';
+import { RuleViewerLayout } from '../rule-viewer/RuleViewerLayout';
 import { RuleDetailsActionButtons } from '../rules/RuleDetailsActionButtons';
 import { RuleDetailsAnnotations } from '../rules/RuleDetailsAnnotations';
 import { RuleDetailsDataSources } from '../rules/RuleDetailsDataSources';
@@ -42,6 +39,8 @@ import { RuleDetailsMatchingInstances } from '../rules/RuleDetailsMatchingInstan
 import { RuleHealth } from '../rules/RuleHealth';
 import { RuleState } from '../rules/RuleState';
 
+import { QueryResults } from './tabs/Query';
+
 type RuleViewerProps = GrafanaRouteComponentProps<{ id?: string; sourceName?: string }>;
 
 const errorMessage = 'Could not find data source for rule';
@@ -63,58 +62,8 @@ export function RuleViewer({ match }: RuleViewerProps) {
 
   const { loading, error, result: rule } = useCombinedRule({ ruleIdentifier: identifier });
 
-  const runner = useMemo(() => new AlertingQueryRunner(), []);
-  const data = useObservable(runner.get());
-  const queries = useMemo(() => alertRuleToQueries(rule), [rule]);
   const annotations = useCleanAnnotations(rule?.annotations || {});
 
-  const [evaluationTimeRanges, setEvaluationTimeRanges] = useState<Record<string, RelativeTimeRange>>({});
-
-  const { allDataSourcesAvailable } = useAlertQueriesStatus(queries);
-
-  const onRunQueries = useCallback(() => {
-    if (queries.length > 0 && allDataSourcesAvailable) {
-      const evalCustomizedQueries = queries.map<AlertQuery>((q) => ({
-        ...q,
-        relativeTimeRange: evaluationTimeRanges[q.refId] ?? q.relativeTimeRange,
-      }));
-      let condition;
-      if (rule && isGrafanaRulerRule(rule.rulerRule)) {
-        condition = rule.rulerRule.grafana_alert.condition;
-      }
-      runner.run(evalCustomizedQueries, condition ?? 'A');
-    }
-  }, [queries, evaluationTimeRanges, runner, allDataSourcesAvailable, rule]);
-
-  useEffect(() => {
-    const alertQueries = alertRuleToQueries(rule);
-    const defaultEvalTimeRanges = Object.fromEntries(
-      alertQueries.map((q) => [q.refId, q.relativeTimeRange ?? { from: 0, to: 0 }])
-    );
-
-    setEvaluationTimeRanges(defaultEvalTimeRanges);
-  }, [rule]);
-
-  useEffect(() => {
-    if (allDataSourcesAvailable && expandQuery) {
-      onRunQueries();
-    }
-  }, [onRunQueries, allDataSourcesAvailable, expandQuery]);
-
-  useEffect(() => {
-    return () => runner.destroy();
-  }, [runner]);
-
-  const onQueryTimeRangeChange = useCallback(
-    (refId: string, timeRange: RelativeTimeRange) => {
-      const newEvalTimeRanges = produce(evaluationTimeRanges, (draft) => {
-        draft[refId] = timeRange;
-      });
-      setEvaluationTimeRanges(newEvalTimeRanges);
-    },
-    [evaluationTimeRanges, setEvaluationTimeRanges]
-  );
-
   if (!identifier?.ruleSourceName) {
     return (
       <RuleViewerLayout title={pageTitle}>
@@ -160,7 +109,17 @@ export function RuleViewer({ match }: RuleViewerProps) {
   const isProvisioned = isGrafanaRulerRule(rule.rulerRule) && Boolean(rule.rulerRule.grafana_alert.provenance);
 
   return (
-    <>
+    <RuleViewerLayout
+      wrapInContent={false}
+      title={pageTitle}
+      renderTitle={() => (
+        <Stack direction="row" alignItems="flex-start" gap={1}>
+          <Icon name="bell" size="xl" />
+          <Text variant="h3">{rule.name}</Text>
+          <RuleState rule={rule} isCreating={false} isDeleting={false} />
+        </Stack>
+      )}
+    >
       {isFederatedRule && (
         <Alert severity="info" title="This rule is part of a federated rule group.">
           <VerticalGroup>
@@ -174,14 +133,8 @@ export function RuleViewer({ match }: RuleViewerProps) {
         </Alert>
       )}
       {isProvisioned && <ProvisioningAlert resource={ProvisionedResource.AlertRule} />}
-      <RuleViewerLayoutContent>
-        <div>
-          <Stack direction="row" alignItems="center" gap={1}>
-            <Icon name="bell" size="lg" /> <span className={styles.title}>{rule.name}</span>
-          </Stack>
-          <RuleState rule={rule} isCreating={false} isDeleting={false} />
-          <RuleDetailsActionButtons rule={rule} rulesSource={rulesSource} isViewMode={true} />
-        </div>
+      <>
+        <RuleDetailsActionButtons rule={rule} rulesSource={rulesSource} isViewMode={true} />
         <div className={styles.details}>
           <div className={styles.leftSide}>
             {rule.promRule && (
@@ -201,63 +154,31 @@ export function RuleViewer({ match }: RuleViewerProps) {
             <RuleDetailsDataSources rule={rule} rulesSource={rulesSource} />
             {isFederatedRule && <RuleDetailsFederatedSources group={rule.group} />}
             <DetailsField label="Namespace / Group" className={styles.rightSideDetails}>
-              {rule.namespace.name} / {rule.group.name}
+              {decodeGrafanaNamespace(rule.namespace).name} / {rule.group.name}
             </DetailsField>
             {isGrafanaRulerRule(rule.rulerRule) && <GrafanaRuleUID rule={rule.rulerRule.grafana_alert} />}
           </div>
         </div>
         <div>
-          <RuleDetailsMatchingInstances
-            rule={rule}
-            pagination={{ itemsPerPage: DEFAULT_PER_PAGE_PAGINATION }}
-            enableFiltering
-          />
+          <DetailsField label="Matching instances" horizontal={true}>
+            <RuleDetailsMatchingInstances
+              rule={rule}
+              pagination={{ itemsPerPage: DEFAULT_PER_PAGE_PAGINATION }}
+              enableFiltering
+            />
+          </DetailsField>
         </div>
-      </RuleViewerLayoutContent>
+      </>
       <Collapse
         label="Query & Results"
         isOpen={expandQuery}
         onToggle={setExpandQuery}
-        loading={data && isLoading(data)}
         collapsible={true}
         className={styles.collapse}
       >
-        {isGrafanaRulerRule(rule.rulerRule) && !isFederatedRule && (
-          <GrafanaRuleQueryViewer
-            condition={rule.rulerRule.grafana_alert.condition}
-            queries={queries}
-            evalDataByQuery={data}
-            evalTimeRanges={evaluationTimeRanges}
-            onTimeRangeChange={onQueryTimeRangeChange}
-          />
-        )}
-
-        {!isGrafanaRulerRule(rule.rulerRule) && !isFederatedRule && data && Object.keys(data).length > 0 && (
-          <div className={styles.queries}>
-            {queries.map((query) => {
-              return (
-                <QueryPreview
-                  key={query.refId}
-                  refId={query.refId}
-                  model={query.model}
-                  dataSource={Object.values(config.datasources).find((ds) => ds.uid === query.datasourceUid)}
-                  queryData={data[query.refId]}
-                  relativeTimeRange={query.relativeTimeRange}
-                  evalTimeRange={evaluationTimeRanges[query.refId]}
-                  onEvalTimeRangeChange={(timeRange) => onQueryTimeRangeChange(query.refId, timeRange)}
-                  isAlertCondition={false}
-                />
-              );
-            })}
-          </div>
-        )}
-        {!isFederatedRule && !allDataSourcesAvailable && (
-          <Alert title="Query not available" severity="warning" className={styles.queryWarning}>
-            Cannot display the query preview. Some of the data sources used in the queries are not available.
-          </Alert>
-        )}
+        {expandQuery && <QueryResults rule={rule} />}
       </Collapse>
-    </>
+    </RuleViewerLayout>
   );
 }
 
@@ -272,10 +193,6 @@ function GrafanaRuleUID({ rule }: { rule: GrafanaRuleDefinition }) {
   );
 }
 
-function isLoading(data: Record<string, PanelData>): boolean {
-  return !!Object.values(data).find((d) => d.state === LoadingState.Loading);
-}
-
 const getStyles = (theme: GrafanaTheme2) => {
   return {
     errorMessage: css`
