@@ -4,8 +4,7 @@ import React, { useEffect, useMemo } from 'react';
 import { FormProvider, RegisterOptions, useForm, useFormContext } from 'react-hook-form';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { Stack } from '@grafana/experimental';
-import { Badge, Button, Field, Input, Label, LinkButton, Modal, useStyles2 } from '@grafana/ui';
+import { Badge, Button, Field, Input, Label, LinkButton, Modal, useStyles2, Stack } from '@grafana/ui';
 import { useAppNotification } from 'app/core/copy/appNotification';
 import { useCleanup } from 'app/core/hooks/useCleanup';
 import { useDispatch } from 'app/types';
@@ -21,6 +20,7 @@ import { AlertInfo, getAlertInfo, isRecordingRulerRule } from '../../utils/rules
 import { parsePrometheusDuration, safeParseDurationstr } from '../../utils/time';
 import { DynamicTable, DynamicTableColumnProps, DynamicTableItemProps } from '../DynamicTable';
 import { EvaluationIntervalLimitExceeded } from '../InvalidIntervalWarning';
+import { decodeGrafanaNamespace, encodeGrafanaNamespace } from '../expressions/util';
 import { MIN_TIME_RANGE_STEP_S } from '../rule-editor/GrafanaEvaluationBehavior';
 
 const ITEMS_PER_PAGE = 10;
@@ -83,7 +83,7 @@ export const RulesForGroupTable = ({ rulesWithoutRecordingRules }: { rulesWithou
       },
       {
         id: 'for',
-        label: 'For',
+        label: 'Pending period',
         renderCell: ({ data: { forDuration } }) => {
           return <>{forDuration}</>;
         },
@@ -159,11 +159,12 @@ export interface ModalProps {
   onClose: (saved?: boolean) => void;
   intervalEditOnly?: boolean;
   folderUrl?: string;
+  folderUid?: string;
   hideFolder?: boolean;
 }
 
 export function EditCloudGroupModal(props: ModalProps): React.ReactElement {
-  const { namespace, group, onClose, intervalEditOnly } = props;
+  const { namespace, group, onClose, intervalEditOnly, folderUid } = props;
 
   const styles = useStyles2(getStyles);
   const dispatch = useDispatch();
@@ -173,7 +174,7 @@ export function EditCloudGroupModal(props: ModalProps): React.ReactElement {
 
   const defaultValues = useMemo(
     (): FormValues => ({
-      namespaceName: namespace.name,
+      namespaceName: decodeGrafanaNamespace(namespace).name,
       groupName: group.name,
       groupInterval: group.interval ?? '',
     }),
@@ -183,6 +184,9 @@ export function EditCloudGroupModal(props: ModalProps): React.ReactElement {
   const rulesSourceName = getRulesSourceName(namespace.rulesSource);
   const isGrafanaManagedGroup = rulesSourceName === GRAFANA_RULES_SOURCE_NAME;
 
+  // parse any parent folders the alert rule might be stored in
+  const nestedFolderParents = decodeGrafanaNamespace(namespace).parents;
+
   const nameSpaceLabel = isGrafanaManagedGroup ? 'Folder' : 'Namespace';
 
   // close modal if successfully saved
@@ -194,14 +198,20 @@ export function EditCloudGroupModal(props: ModalProps): React.ReactElement {
 
   useCleanup((state) => (state.unifiedAlerting.updateLotexNamespaceAndGroup = initialAsyncRequestState));
   const onSubmit = (values: FormValues) => {
+    // make sure that when dealing with a nested folder for Grafana managed rules we encode the folder properly
+    const newNamespaceName = isGrafanaManagedGroup
+      ? encodeGrafanaNamespace(values.namespaceName, nestedFolderParents)
+      : values.namespaceName;
+
     dispatch(
       updateLotexNamespaceAndGroupAction({
         rulesSourceName: rulesSourceName,
         groupName: group.name,
         newGroupName: values.groupName,
         namespaceName: namespace.name,
-        newNamespaceName: values.namespaceName,
+        newNamespaceName: newNamespaceName,
         groupInterval: values.groupInterval || undefined,
+        folderUid,
       })
     );
   };
@@ -211,6 +221,7 @@ export function EditCloudGroupModal(props: ModalProps): React.ReactElement {
     defaultValues,
     shouldFocusError: true,
   });
+
   const {
     handleSubmit,
     register,
@@ -235,41 +246,41 @@ export function EditCloudGroupModal(props: ModalProps): React.ReactElement {
         <form onSubmit={(e) => e.preventDefault()} key={JSON.stringify(defaultValues)}>
           <>
             {!props.hideFolder && (
-              <Field
-                label={
-                  <Label
-                    htmlFor="namespaceName"
-                    description={
-                      !isGrafanaManagedGroup &&
-                      'Change the current namespace name. Moving groups between namespaces is not supported'
-                    }
-                  >
-                    {nameSpaceLabel}
-                  </Label>
-                }
-                invalid={!!errors.namespaceName}
-                error={errors.namespaceName?.message}
-              >
-                <Stack gap={1} direction="row">
+              <Stack gap={1} alignItems={'center'}>
+                <Field
+                  className={styles.formInput}
+                  label={
+                    <Label
+                      htmlFor="namespaceName"
+                      description={
+                        !isGrafanaManagedGroup &&
+                        'Change the current namespace name. Moving groups between namespaces is not supported'
+                      }
+                    >
+                      {nameSpaceLabel}
+                    </Label>
+                  }
+                  invalid={!!errors.namespaceName}
+                  error={errors.namespaceName?.message}
+                >
                   <Input
                     id="namespaceName"
                     readOnly={intervalEditOnly || isGrafanaManagedGroup}
                     {...register('namespaceName', {
                       required: 'Namespace name is required.',
                     })}
-                    className={styles.formInput}
                   />
-                  {isGrafanaManagedGroup && props.folderUrl && (
-                    <LinkButton
-                      href={props.folderUrl}
-                      title="Go to folder"
-                      variant="secondary"
-                      icon="folder-open"
-                      target="_blank"
-                    />
-                  )}
-                </Stack>
-              </Field>
+                </Field>
+                {isGrafanaManagedGroup && props.folderUrl && (
+                  <LinkButton
+                    href={props.folderUrl}
+                    title="Go to folder"
+                    variant="secondary"
+                    icon="folder-open"
+                    target="_blank"
+                  />
+                )}
+              </Stack>
             )}
             <Field
               label={<Label htmlFor="groupName">Evaluation group name</Label>}
