@@ -1,5 +1,5 @@
 import { css } from '@emotion/css';
-import React, { FC } from 'react';
+import React from 'react';
 
 import { TagList, useStyles2 } from '@grafana/ui';
 import { Matcher } from 'app/plugins/datasource/alertmanager/types';
@@ -8,7 +8,7 @@ import { matcherToOperator } from '../../utils/alertmanager';
 
 type MatchersProps = { matchers: Matcher[] };
 
-export const Matchers: FC<MatchersProps> = ({ matchers }) => {
+export const Matchers = ({ matchers }: MatchersProps) => {
   const styles = useStyles2(getStyles);
   return (
     <div>
