@@ -11,11 +11,17 @@ import {
   ScopedVars,
   TimeRange,
 } from '@grafana/data';
-import { getDataSourceSrv } from '@grafana/runtime';
+import { config, getDataSourceSrv } from '@grafana/runtime';
 import { ExpressionDatasourceRef } from '@grafana/runtime/src/utils/DataSourceWithBackend';
+import { sceneGraph, VizPanel } from '@grafana/scenes';
 import { DataSourceJsonData } from '@grafana/schema';
 import { getNextRefIdChar } from 'app/core/utils/query';
 import { DashboardModel, PanelModel } from 'app/features/dashboard/state';
+import {
+  getDashboardSceneFor,
+  getPanelIdForVizPanel,
+  getQueryRunnerFor,
+} from 'app/features/dashboard-scene/utils/utils';
 import { ExpressionDatasourceUID, ExpressionQuery, ExpressionQueryType } from 'app/features/expressions/types';
 import { LokiQuery } from 'app/plugins/datasource/loki/types';
 import { PromQuery } from 'app/plugins/datasource/prometheus/types';
@@ -25,6 +31,8 @@ import {
   AlertQuery,
   Annotations,
   GrafanaAlertStateDecision,
+  GrafanaNotificationSettings,
+  GrafanaRuleDefinition,
   Labels,
   PostableRuleGrafanaRuleDTO,
   RulerAlertingRuleDTO,
@@ -33,11 +41,11 @@ import {
 } from 'app/types/unified-alerting-dto';
 
 import { EvalFunction } from '../../state/alertDef';
-import { RuleFormType, RuleFormValues } from '../types/rule-form';
+import { AlertManagerManualRouting, ContactPoint, RuleFormType, RuleFormValues } from '../types/rule-form';
 
 import { getRulesAccess } from './access-control';
 import { Annotation, defaultAnnotations } from './constants';
-import { getDefaultOrFirstCompatibleDataSource, isGrafanaRulesSource } from './datasource';
+import { getDefaultOrFirstCompatibleDataSource, GRAFANA_RULES_SOURCE_NAME, isGrafanaRulesSource } from './datasource';
 import { arrayToRecord, recordToArray } from './misc';
 import { isAlertingRulerRule, isGrafanaRulerRule, isRecordingRulerRule } from './rules';
 import { parseInterval } from './time';
@@ -46,6 +54,8 @@ export type PromOrLokiQuery = PromQuery | LokiQuery;
 
 export const MINUTE = '1m';
 
+export const MANUAL_ROUTING_KEY = 'grafana.alerting.manualRouting';
+
 export const getDefaultFormValues = (): RuleFormValues => {
   const { canCreateGrafanaRules, canCreateCloudRules } = getRulesAccess();
 
@@ -67,8 +77,11 @@ export const getDefaultFormValues = (): RuleFormValues => {
     execErrState: GrafanaAlertStateDecision.Error,
     evaluateFor: '5m',
     evaluateEvery: MINUTE,
-    manualRouting: false, // let's decide this later
-    contactPoints: [],
+    manualRouting: getDefautManualRouting(), // we default to true if the feature toggle is enabled and the user hasn't set local storage to false
+    contactPoints: {},
+    overrideGrouping: false,
+    overrideTimings: false,
+    muteTimeIntervals: [],
 
     // cortex / loki
     namespace: '',
@@ -78,6 +91,18 @@ export const getDefaultFormValues = (): RuleFormValues => {
   });
 };
 
+export const getDefautManualRouting = () => {
+  // first check if feature toggle for simplified routing is enabled
+  const simplifiedRoutingToggleEnabled = config.featureToggles.alertingSimplifiedRouting ?? false;
+  if (!simplifiedRoutingToggleEnabled) {
+    return false;
+  }
+  //then, check in local storage if the user has enabled simplified routing
+  // if it's not set, we'll default to true
+  const manualRouting = localStorage.getItem(MANUAL_ROUTING_KEY);
+  return manualRouting !== 'false';
+};
+
 export function formValuesToRulerRuleDTO(values: RuleFormValues): RulerRuleDTO {
   const { name, expression, forTime, forTimeUnit, keepFiringForTime, keepFiringForTimeUnit, type } = values;
   if (type === RuleFormType.cloudAlerting) {
@@ -135,9 +160,41 @@ export function normalizeDefaultAnnotations(annotations: Array<{ key: string; va
   return orderedAnnotations;
 }
 
+export function getNotificationSettingsForDTO(
+  manualRouting: boolean,
+  contactPoints?: AlertManagerManualRouting
+): GrafanaNotificationSettings | undefined {
+  if (contactPoints?.grafana?.selectedContactPoint && manualRouting) {
+    return {
+      receiver: contactPoints?.grafana?.selectedContactPoint,
+      mute_time_intervals: contactPoints?.grafana?.muteTimeIntervals,
+      group_by: contactPoints?.grafana?.overrideGrouping ? contactPoints?.grafana?.groupBy : undefined,
+      group_wait:
+        contactPoints?.grafana?.overrideTimings && contactPoints?.grafana?.groupWaitValue
+          ? contactPoints?.grafana?.groupWaitValue
+          : undefined,
+      group_interval:
+        contactPoints?.grafana?.overrideTimings && contactPoints?.grafana?.groupIntervalValue
+          ? contactPoints?.grafana?.groupIntervalValue
+          : undefined,
+      repeat_interval:
+        contactPoints?.grafana?.overrideTimings && contactPoints?.grafana?.repeatIntervalValue
+          ? contactPoints?.grafana?.repeatIntervalValue
+          : undefined,
+    };
+  }
+  return undefined;
+}
+
 export function formValuesToRulerGrafanaRuleDTO(values: RuleFormValues): PostableRuleGrafanaRuleDTO {
-  const { name, condition, noDataState, execErrState, evaluateFor, queries, isPaused } = values;
+  const { name, condition, noDataState, execErrState, evaluateFor, queries, isPaused, contactPoints, manualRouting } =
+    values;
   if (condition) {
+    const notificationSettings: GrafanaNotificationSettings | undefined = getNotificationSettingsForDTO(
+      manualRouting,
+      contactPoints
+    );
+
     return {
       grafana_alert: {
         title: name,
@@ -146,6 +203,7 @@ export function formValuesToRulerGrafanaRuleDTO(values: RuleFormValues): Postabl
         exec_err_state: execErrState,
         data: queries.map(fixBothInstantAndRangeQuery),
         is_paused: Boolean(isPaused),
+        notification_settings: notificationSettings,
       },
       for: evaluateFor,
       annotations: arrayToRecord(values.annotations || []),
@@ -155,6 +213,32 @@ export function formValuesToRulerGrafanaRuleDTO(values: RuleFormValues): Postabl
   throw new Error('Cannot create rule without specifying alert condition');
 }
 
+export function getContactPointsFromDTO(ga: GrafanaRuleDefinition): AlertManagerManualRouting | undefined {
+  const contactPoint: ContactPoint | undefined = ga.notification_settings
+    ? {
+        selectedContactPoint: ga.notification_settings.receiver,
+        muteTimeIntervals: ga.notification_settings.mute_time_intervals ?? [],
+        overrideGrouping:
+          Array.isArray(ga.notification_settings.group_by) && ga.notification_settings.group_by.length > 0,
+        overrideTimings: [
+          ga.notification_settings.group_wait,
+          ga.notification_settings.group_interval,
+          ga.notification_settings.repeat_interval,
+        ].some(Boolean),
+        groupBy: ga.notification_settings.group_by || [],
+        groupWaitValue: ga.notification_settings.group_wait || '',
+        groupIntervalValue: ga.notification_settings.group_interval || '',
+        repeatIntervalValue: ga.notification_settings.repeat_interval || '',
+      }
+    : undefined;
+  const routingSettings: AlertManagerManualRouting | undefined = contactPoint
+    ? {
+        [GRAFANA_RULES_SOURCE_NAME]: contactPoint,
+      }
+    : undefined;
+  return routingSettings;
+}
+
 export function rulerRuleToFormValues(ruleWithLocation: RuleWithLocation): RuleFormValues {
   const { ruleSourceName, namespace, group, rule } = ruleWithLocation;
 
@@ -163,6 +247,8 @@ export function rulerRuleToFormValues(ruleWithLocation: RuleWithLocation): RuleF
     if (isGrafanaRulerRule(rule)) {
       const ga = rule.grafana_alert;
 
+      const routingSettings: AlertManagerManualRouting | undefined = getContactPointsFromDTO(ga);
+
       return {
         ...defaultFormValues,
         name: ga.title,
@@ -178,8 +264,9 @@ export function rulerRuleToFormValues(ruleWithLocation: RuleWithLocation): RuleF
         labels: listifyLabelsOrAnnotations(rule.labels, true),
         folder: { title: namespace, uid: ga.namespace_uid },
         isPaused: ga.is_paused,
-        // manualrouting: ?? //todo depending on the implementation of the manual routing
-        // contactPoints: ?? //todo depending on the implementation of the manual routing
+
+        contactPoints: routingSettings,
+        manualRouting: Boolean(routingSettings),
       };
     } else {
       throw new Error('Unexpected type of rule for grafana rules source');
@@ -245,9 +332,7 @@ export function alertingRulerRuleToRuleForm(
 > {
   const defaultFormValues = getDefaultFormValues();
 
-  const [forTime, forTimeUnit] = rule.for
-    ? parseInterval(rule.for)
-    : [defaultFormValues.forTime, defaultFormValues.forTimeUnit];
+  const [forTime, forTimeUnit] = rule.for ? parseInterval(rule.for) : [0, 's'];
 
   const [keepFiringForTime, keepFiringForTimeUnit] = rule.keep_firing_for
     ? parseInterval(rule.keep_firing_for)
@@ -417,7 +502,7 @@ const dataQueriesToGrafanaQueries = async (
     };
 
     const interpolatedTarget = datasource.interpolateVariablesInQueries
-      ? await datasource.interpolateVariablesInQueries([target], queryVariables)[0]
+      ? datasource.interpolateVariablesInQueries([target], queryVariables)[0]
       : target;
 
     // expressions
@@ -514,6 +599,77 @@ export const panelToRuleFormValues = async (
   return formValues;
 };
 
+export const scenesPanelToRuleFormValues = async (vizPanel: VizPanel): Promise<Partial<RuleFormValues> | undefined> => {
+  if (!vizPanel.state.key) {
+    return undefined;
+  }
+
+  const timeRange = sceneGraph.getTimeRange(vizPanel);
+  const queryRunner = getQueryRunnerFor(vizPanel);
+  if (!queryRunner) {
+    return undefined;
+  }
+  const { queries, datasource, maxDataPoints, minInterval } = queryRunner.state;
+
+  const dashboard = getDashboardSceneFor(vizPanel);
+  if (!dashboard || !dashboard.state.uid) {
+    return undefined;
+  }
+
+  const grafanaQueries = await dataQueriesToGrafanaQueries(
+    queries,
+    rangeUtil.timeRangeToRelative(rangeUtil.convertRawToRange(timeRange.state.value.raw)),
+    { __sceneObject: { value: vizPanel } },
+    datasource,
+    maxDataPoints,
+    minInterval
+  );
+
+  // if no alerting capable queries are found, can't create a rule
+  if (!grafanaQueries.length || !grafanaQueries.find((query) => query.datasourceUid !== ExpressionDatasourceUID)) {
+    return undefined;
+  }
+
+  if (!grafanaQueries.find((query) => query.datasourceUid === ExpressionDatasourceUID)) {
+    const [reduceExpression, _thresholdExpression] = getDefaultExpressions(getNextRefIdChar(grafanaQueries), '-');
+    grafanaQueries.push(reduceExpression);
+
+    const [_reduceExpression, thresholdExpression] = getDefaultExpressions(
+      reduceExpression.refId,
+      getNextRefIdChar(grafanaQueries)
+    );
+    grafanaQueries.push(thresholdExpression);
+  }
+
+  const { folderTitle, folderUid } = dashboard.state.meta;
+
+  const formValues = {
+    type: RuleFormType.grafana,
+    folder:
+      folderUid && folderTitle
+        ? {
+            uid: folderUid,
+            title: folderTitle,
+          }
+        : undefined,
+    queries: grafanaQueries,
+    name: vizPanel.state.title,
+    condition: grafanaQueries[grafanaQueries.length - 1].refId,
+    annotations: [
+      {
+        key: Annotation.dashboardUID,
+        value: dashboard.state.uid,
+      },
+      {
+        key: Annotation.panelID,
+
+        value: String(getPanelIdForVizPanel(vizPanel)),
+      },
+    ],
+  };
+  return formValues;
+};
+
 export function getIntervals(range: TimeRange, lowLimit?: string, resolution?: number): IntervalValues {
   if (!resolution) {
     if (lowLimit && rangeUtil.intervalToMs(lowLimit) > 1000) {
