@@ -6,7 +6,7 @@ import {
   RulerRuleGroupDTO,
 } from 'app/types/unified-alerting-dto';
 
-import { deleteRulerRulesGroup, fetchRulerRulesGroup, fetchRulerRules, setRulerRuleGroup } from '../api/ruler';
+import { deleteRulerRulesGroup, fetchRulerRules, fetchRulerRulesGroup, setRulerRuleGroup } from '../api/ruler';
 import { RuleFormValues } from '../types/rule-form';
 import * as ruleId from '../utils/rule-id';
 
@@ -41,6 +41,7 @@ export function getRulerClient(rulerConfig: RulerDataSourceConfig): RulerClient
               group,
               ruleSourceName: GRAFANA_RULES_SOURCE_NAME,
               namespace: namespace,
+              namespace_uid: (isGrafanaRulerRule(rule) && rule.grafana_alert.namespace_uid) || undefined,
               rule,
             };
           }
@@ -81,15 +82,15 @@ export function getRulerClient(rulerConfig: RulerDataSourceConfig): RulerClient
   };
 
   const deleteRule = async (ruleWithLocation: RuleWithLocation): Promise<void> => {
-    const { namespace, group, rule } = ruleWithLocation;
+    const { namespace, group, rule, namespace_uid } = ruleWithLocation;
 
     // it was the last rule, delete the entire group
     if (group.rules.length === 1) {
-      await deleteRulerRulesGroup(rulerConfig, namespace, group.name);
+      await deleteRulerRulesGroup(rulerConfig, namespace_uid || namespace, group.name);
       return;
     }
     // post the group with rule removed
-    await setRulerRuleGroup(rulerConfig, namespace, {
+    await setRulerRuleGroup(rulerConfig, namespace_uid || namespace, {
       ...group,
       rules: group.rules.filter((r) => r !== rule),
     });
@@ -159,11 +160,11 @@ export function getRulerClient(rulerConfig: RulerDataSourceConfig): RulerClient
     }
 
     const newRule = formValuesToRulerGrafanaRuleDTO(values);
-    const namespace = folder.title;
+    const namespaceUID = folder.uid;
     const groupSpec = { name: group, interval: evaluateEvery };
 
     if (!existingRule) {
-      return addRuleToNamespaceAndGroup(namespace, groupSpec, newRule);
+      return addRuleToNamespaceAndGroup(namespaceUID, groupSpec, newRule);
     }
 
     // we'll fetch the existing group again, someone might have updated it while we were editing a rule
@@ -172,7 +173,7 @@ export function getRulerClient(rulerConfig: RulerDataSourceConfig): RulerClient
       throw new Error('Rule not found.');
     }
 
-    const sameNamespace = freshExisting.namespace === namespace;
+    const sameNamespace = freshExisting.namespace_uid === namespaceUID;
     const sameGroup = freshExisting.group.name === values.group;
     const sameLocation = sameNamespace && sameGroup;
 
@@ -181,16 +182,16 @@ export function getRulerClient(rulerConfig: RulerDataSourceConfig): RulerClient
       return updateGrafanaRule(freshExisting, newRule, evaluateEvery);
     } else {
       // we're moving a rule to either a different group or namespace
-      return moveGrafanaRule(namespace, groupSpec, freshExisting, newRule);
+      return moveGrafanaRule(namespaceUID, groupSpec, freshExisting, newRule);
     }
   };
 
   const addRuleToNamespaceAndGroup = async (
-    namespace: string,
+    namespaceUID: string,
     group: { name: string; interval: string },
     newRule: PostableRuleGrafanaRuleDTO
   ): Promise<RuleIdentifier> => {
-    const existingGroup = await fetchRulerRulesGroup(rulerConfig, namespace, group.name);
+    const existingGroup = await fetchRulerRulesGroup(rulerConfig, namespaceUID, group.name);
     if (!existingGroup) {
       throw new Error(`No group found with name "${group.name}"`);
     }
@@ -201,7 +202,7 @@ export function getRulerClient(rulerConfig: RulerDataSourceConfig): RulerClient
       rules: (existingGroup.rules ?? []).concat(newRule as RulerGrafanaRuleDTO),
     };
 
-    await setRulerRuleGroup(rulerConfig, namespace, payload);
+    await setRulerRuleGroup(rulerConfig, namespaceUID, payload);
 
     return { uid: newRule.grafana_alert.uid ?? '', ruleSourceName: GRAFANA_RULES_SOURCE_NAME };
   };
@@ -242,7 +243,7 @@ export function getRulerClient(rulerConfig: RulerDataSourceConfig): RulerClient
       return rule;
     });
 
-    await setRulerRuleGroup(rulerConfig, existingRule.namespace, {
+    await setRulerRuleGroup(rulerConfig, existingRule.namespace_uid ?? '', {
       name: existingRule.group.name,
       interval: interval,
       rules: newRules,
