@@ -1,6 +1,6 @@
-import 'whatwg-fetch'; // fetch polyfill
+import 'whatwg-fetch';
 import { render as rtlRender, screen } from '@testing-library/react';
-import { rest } from 'msw';
+import { http, HttpResponse } from 'msw';
 import { SetupServer, setupServer } from 'msw/node';
 import React from 'react';
 import { TestProvider } from 'test/helpers/TestProvider';
@@ -47,20 +47,17 @@ describe('browse-dashboards BrowseFolderAlertingPage', () => {
 
   beforeAll(() => {
     server = setupServer(
-      rest.get('/api/folders/:uid', (_, res, ctx) => {
-        return res(
-          ctx.status(200),
-          ctx.json({
-            title: mockFolderName,
-            uid: mockFolderUid,
-          })
-        );
+      http.get('/api/folders/:uid', () => {
+        return HttpResponse.json({
+          title: mockFolderName,
+          uid: mockFolderUid,
+        });
       }),
-      rest.get('api/ruler/grafana/api/v1/rules', (_, res, ctx) => {
-        return res(ctx.status(200), ctx.json(mockRulerRulesResponse));
+      http.get('api/ruler/grafana/api/v1/rules', () => {
+        return HttpResponse.json(mockRulerRulesResponse);
       }),
-      rest.get('api/prometheus/grafana/api/v1/rules', (_, res, ctx) => {
-        return res(ctx.status(200), ctx.json(mockPrometheusRulesResponse));
+      http.get('api/prometheus/grafana/api/v1/rules', () => {
+        return HttpResponse.json(mockPrometheusRulesResponse);
       })
     );
     server.listen();
