@@ -8,26 +8,31 @@ import { t } from 'app/core/internationalization';
 
 import { DashboardsTreeCellProps, SelectionState } from '../types';
 
+import { isSharedWithMe } from './utils';
+
 export default function CheckboxCell({
   row: { original: row },
   isSelected,
   onItemSelectionChange,
 }: DashboardsTreeCellProps) {
-  const styles = useStyles2(getStyles);
   const item = row.item;
 
   if (!isSelected) {
-    return <span className={styles.checkboxSpacer} />;
+    return <CheckboxSpacer />;
   }
 
   if (item.kind === 'ui') {
     if (item.uiKind === 'pagination-placeholder') {
       return <Checkbox disabled value={false} />;
     } else {
-      return <span className={styles.checkboxSpacer} />;
+      return <CheckboxSpacer />;
     }
   }
 
+  if (isSharedWithMe(item.uid)) {
+    return <CheckboxSpacer />;
+  }
+
   const state = isSelected(item);
 
   return (
@@ -41,6 +46,11 @@ export default function CheckboxCell({
   );
 }
 
+function CheckboxSpacer() {
+  const styles = useStyles2(getStyles);
+  return <span className={styles.checkboxSpacer} />;
+}
+
 const getStyles = (theme: GrafanaTheme2) => ({
   // Should be the same size as the <IconButton /> so Dashboard name is aligned to Folder name siblings
   checkboxSpacer: css({
