@@ -5,8 +5,14 @@ import { TestProvider } from 'test/helpers/TestProvider';
 import { assertIsDefined } from 'test/helpers/asserts';
 
 import { selectors } from '@grafana/e2e-selectors';
+import { config } from '@grafana/runtime';
 
-import { wellFormedDashboard, wellFormedEmptyFolder, wellFormedFolder } from '../fixtures/dashboardsTreeItem.fixture';
+import {
+  sharedWithMeFolder,
+  wellFormedDashboard,
+  wellFormedEmptyFolder,
+  wellFormedFolder,
+} from '../fixtures/dashboardsTreeItem.fixture';
 import { SelectionState } from '../types';
 
 import { DashboardsTree } from './DashboardsTree';
@@ -27,6 +33,10 @@ describe('browse-dashboards DashboardsTree', () => {
   const allItemsAreLoaded = () => true;
   const requestLoadMore = () => Promise.resolve();
 
+  beforeAll(() => {
+    config.sharedWithMeFolderUID = 'sharedwithme';
+  });
+
   it('renders a dashboard item', () => {
     render(
       <DashboardsTree
@@ -82,9 +92,73 @@ describe('browse-dashboards DashboardsTree', () => {
         requestLoadMore={requestLoadMore}
       />
     );
+
     expect(screen.queryByText(folder.item.title)).toBeInTheDocument();
   });
 
+  it('renders a folder link', () => {
+    render(
+      <DashboardsTree
+        canSelect
+        items={[folder]}
+        isSelected={isSelected}
+        width={WIDTH}
+        height={HEIGHT}
+        onFolderClick={noop}
+        onItemSelectionChange={noop}
+        onAllSelectionChange={noop}
+        isItemLoaded={allItemsAreLoaded}
+        requestLoadMore={requestLoadMore}
+      />
+    );
+
+    expect(screen.queryByText(folder.item.title)).toHaveAttribute('href', folder.item.url);
+  });
+
+  it("doesn't link to the sharedwithme pseudo-folder", () => {
+    const sharedWithMe = sharedWithMeFolder(2);
+
+    render(
+      <DashboardsTree
+        canSelect
+        items={[sharedWithMe, folder]}
+        isSelected={isSelected}
+        width={WIDTH}
+        height={HEIGHT}
+        onFolderClick={noop}
+        onItemSelectionChange={noop}
+        onAllSelectionChange={noop}
+        isItemLoaded={allItemsAreLoaded}
+        requestLoadMore={requestLoadMore}
+      />
+    );
+
+    expect(screen.queryByText(sharedWithMe.item.title)).not.toHaveAttribute('href');
+  });
+
+  it("doesn't render a checkbox for the sharedwithme pseudo-folder", () => {
+    const sharedWithMe = sharedWithMeFolder(2);
+
+    render(
+      <DashboardsTree
+        canSelect
+        items={[sharedWithMe, folder]}
+        isSelected={isSelected}
+        width={WIDTH}
+        height={HEIGHT}
+        onFolderClick={noop}
+        onItemSelectionChange={noop}
+        onAllSelectionChange={noop}
+        isItemLoaded={allItemsAreLoaded}
+        requestLoadMore={requestLoadMore}
+      />
+    );
+
+    expect(
+      screen.queryByTestId(selectors.pages.BrowseDashboards.table.checkbox(sharedWithMe.item.uid))
+    ).not.toBeInTheDocument();
+  });
+
   it('calls onFolderClick when a folder button is clicked', async () => {
     const handler = jest.fn();
     render(
