@@ -5,6 +5,7 @@ import { buttonItem } from './elements/button';
 import { droneFrontItem } from './elements/droneFront';
 import { droneSideItem } from './elements/droneSide';
 import { droneTopItem } from './elements/droneTop';
+import { ellipseItem } from './elements/ellipse';
 import { iconItem } from './elements/icon';
 import { metricValueItem } from './elements/metricValue';
 import { rectangleItem } from './elements/rectangle';
@@ -22,6 +23,7 @@ export const DEFAULT_CANVAS_ELEMENT_CONFIG: CanvasElementOptions = {
 export const defaultElementItems = [
   metricValueItem, // default for now
   textItem,
+  ellipseItem,
   rectangleItem,
   iconItem,
   serverItem,
