@@ -19,6 +19,7 @@ import { reportInteraction } from '@grafana/runtime';
 import { Icon, LoadingBar, useStyles2 } from '@grafana/ui';
 import { t } from 'app/core/internationalization';
 
+import { EmptyState } from './EmptyState';
 import { KBarResults } from './KBarResults';
 import { ResultItem } from './ResultItem';
 import { useSearchResults } from './actions/dashboardActions';
@@ -68,7 +69,7 @@ export function CommandPalette() {
                 </div>
               </div>
               <div className={styles.resultsContainer}>
-                <RenderResults searchResults={searchResults} />
+                <RenderResults isFetchingSearchResults={isFetchingSearchResults} searchResults={searchResults} />
               </div>
             </div>
           </FocusScope>
@@ -79,10 +80,11 @@ export function CommandPalette() {
 }
 
 interface RenderResultsProps {
+  isFetchingSearchResults: boolean;
   searchResults: CommandPaletteAction[];
 }
 
-const RenderResults = ({ searchResults }: RenderResultsProps) => {
+const RenderResults = ({ isFetchingSearchResults, searchResults }: RenderResultsProps) => {
   const { results: kbarResults, rootActionId } = useMatches();
   const styles = useStyles2(getSearchStyles);
   const dashboardsSectionTitle = t('command-palette.section.dashboard-search-results', 'Dashboards');
@@ -117,7 +119,11 @@ const RenderResults = ({ searchResults }: RenderResultsProps) => {
     return results;
   }, [kbarResults, dashboardsSectionTitle, dashboardResultItems, foldersSectionTitle, folderResultItems]);
 
-  return (
+  const showEmptyState = !isFetchingSearchResults && items.length === 0;
+
+  return showEmptyState ? (
+    <EmptyState />
+  ) : (
     <KBarResults
       items={items}
       maxHeight={650}
