@@ -1,12 +1,12 @@
-import { fireEvent, render, RenderResult, screen, waitFor } from '@testing-library/react';
+import { render, RenderResult, screen, waitFor } from '@testing-library/react';
+import userEvent from '@testing-library/user-event';
 import React from 'react';
-import { Provider } from 'react-redux';
+import { TestProvider } from 'test/helpers/TestProvider';
 
 import { PluginType } from '@grafana/data';
 import { contextSrv } from 'app/core/core';
 import { getCatalogPluginMock, getPluginsStateMock } from 'app/features/plugins/admin/__mocks__';
 import { CatalogPlugin } from 'app/features/plugins/admin/types';
-import { configureStore } from 'app/store/configureStore';
 import { AccessControlAction } from 'app/types';
 
 import { AddNewConnection } from './ConnectData';
@@ -14,13 +14,10 @@ import { AddNewConnection } from './ConnectData';
 jest.mock('app/features/datasources/api');
 
 const renderPage = (plugins: CatalogPlugin[] = []): RenderResult => {
-  // @ts-ignore
-  const store = configureStore({ plugins: getPluginsStateMock(plugins) });
-
   return render(
-    <Provider store={store}>
+    <TestProvider storeState={{ plugins: getPluginsStateMock(plugins) }}>
       <AddNewConnection />
-    </Provider>
+    </TestProvider>
   );
 };
 
@@ -30,8 +27,6 @@ const mockCatalogDataSourcePlugin = getCatalogPluginMock({
   id: 'sample-data-source',
 });
 
-const originalHasPermission = contextSrv.hasPermission;
-
 describe('Angular badge', () => {
   test('does not show angular badge for non-angular plugins', async () => {
     renderPage([
@@ -65,10 +60,6 @@ describe('Angular badge', () => {
 });
 
 describe('Add new connection', () => {
-  beforeEach(() => {
-    contextSrv.hasPermission = originalHasPermission;
-  });
-
   test('renders no results if the plugins list is empty', async () => {
     renderPage();
 
@@ -91,15 +82,19 @@ describe('Add new connection', () => {
     renderPage([getCatalogPluginMock(), mockCatalogDataSourcePlugin]);
     const searchField = await screen.findByRole('textbox');
 
-    fireEvent.change(searchField, { target: { value: 'ampl' } });
+    await userEvent.type(searchField, 'ampl');
     expect(await screen.findByText('Sample data source')).toBeVisible();
 
-    fireEvent.change(searchField, { target: { value: 'cramp' } });
+    await userEvent.clear(searchField);
+    await userEvent.type(searchField, 'cramp');
     expect(screen.queryByText('No results matching your query were found.')).toBeInTheDocument();
+
+    await userEvent.clear(searchField);
+    expect(await screen.findByText('Sample data source')).toBeVisible();
   });
 
   test('shows a "No access" modal if the user does not have permissions to create datasources', async () => {
-    (contextSrv.hasPermission as jest.Mock) = jest.fn().mockImplementation((permission: string) => {
+    jest.spyOn(contextSrv, 'hasPermission').mockImplementation((permission: string) => {
       if (permission === AccessControlAction.DataSourcesCreate) {
         return false;
       }
@@ -114,21 +109,7 @@ describe('Add new connection', () => {
     expect(screen.queryByText(new RegExp(exampleSentenceInModal))).not.toBeInTheDocument();
 
     // Should show the modal if the user has no permissions
-    fireEvent.click(await screen.findByText('Sample data source'));
+    await userEvent.click(await screen.findByText('Sample data source'));
     expect(screen.queryByText(new RegExp(exampleSentenceInModal))).toBeInTheDocument();
   });
-
-  test('does not show a "No access" modal but displays the details page if the user has the right permissions', async () => {
-    (contextSrv.hasPermission as jest.Mock) = jest.fn().mockReturnValue(true);
-
-    renderPage([getCatalogPluginMock(), mockCatalogDataSourcePlugin]);
-    const exampleSentenceInModal = 'Editors cannot add new connections.';
-
-    // Should not show the modal by default
-    expect(screen.queryByText(new RegExp(exampleSentenceInModal))).not.toBeInTheDocument();
-
-    // Should not show the modal when clicking a card
-    fireEvent.click(await screen.findByText('Sample data source'));
-    expect(screen.queryByText(new RegExp(exampleSentenceInModal))).not.toBeInTheDocument();
-  });
 });
