@@ -1,6 +1,7 @@
 import React from 'react';
 
 import { Button, HorizontalGroup } from '@grafana/ui';
+import { Trans, t } from 'app/core/internationalization';
 
 import { useWizardContext } from '../components/Wizard/wizardContext';
 
@@ -11,14 +12,16 @@ export const CorrelationFormNavigation = () => {
   const { readOnly, loading, correlation } = useCorrelationsFormContext();
 
   const LastPageNext = !readOnly && (
-    <Button variant="primary" icon={loading ? 'fa fa-spinner' : 'save'} type="submit" disabled={loading}>
-      {correlation === undefined ? 'Add' : 'Save'}
+    <Button variant="primary" icon={loading ? 'spinner' : 'save'} type="submit" disabled={loading}>
+      {correlation === undefined
+        ? t('correlations.navigation-form.add-button', 'Add')
+        : t('correlations.navigation-form.save-button', 'Save')}
     </Button>
   );
 
   const NextPage = (
     <Button variant="primary" type="submit">
-      Next
+      <Trans i18nKey="correlations.navigation-form.next-button">Next</Trans>
     </Button>
   );
 
@@ -26,7 +29,7 @@ export const CorrelationFormNavigation = () => {
     <HorizontalGroup justify="flex-start">
       {currentPage > 0 ? (
         <Button variant="secondary" onClick={prevPage}>
-          Back
+          <Trans i18nKey="correlations.navigation-form.back-button">Back</Trans>
         </Button>
       ) : undefined}
 
