@@ -1,9 +1,7 @@
 import React from 'react';
 
 import { SceneObjectState, SceneObject, SceneObjectBase, SceneComponentProps } from '@grafana/scenes';
-import { Box, Stack, ToolbarButton } from '@grafana/ui';
-
-import { getDashboardSceneFor } from '../utils/utils';
+import { Box, Stack } from '@grafana/ui';
 
 import { DashboardLinksControls } from './DashboardLinksControls';
 
@@ -11,15 +9,14 @@ interface DashboardControlsState extends SceneObjectState {
   variableControls: SceneObject[];
   timeControls: SceneObject[];
   linkControls: DashboardLinksControls;
+  hideTimeControls?: boolean;
 }
 export class DashboardControls extends SceneObjectBase<DashboardControlsState> {
   static Component = DashboardControlsRenderer;
 }
 
 function DashboardControlsRenderer({ model }: SceneComponentProps<DashboardControls>) {
-  const dashboard = getDashboardSceneFor(model);
-  const { variableControls, linkControls, timeControls } = model.useState();
-  const { isEditing } = dashboard.useState();
+  const { variableControls, linkControls, timeControls, hideTimeControls } = model.useState();
 
   return (
     <Stack
@@ -37,12 +34,7 @@ function DashboardControlsRenderer({ model }: SceneComponentProps<DashboardContr
         <linkControls.Component model={linkControls} />
       </Stack>
       <Stack justifyContent={'flex-end'}>
-        {isEditing && (
-          <ToolbarButton variant="canvas" icon="cog" tooltip="Dashboard settings" onClick={dashboard.onOpenSettings} />
-        )}
-        {timeControls.map((c) => (
-          <c.Component model={c} key={c.state.key} />
-        ))}
+        {!hideTimeControls && timeControls.map((c) => <c.Component model={c} key={c.state.key} />)}
       </Stack>
     </Stack>
   );
