@@ -1,10 +1,13 @@
 import React from 'react';
 
-import { LinkModel } from '@grafana/data';
-import { SceneComponentProps, SceneObjectBase, SceneObjectState } from '@grafana/scenes';
-import { Dropdown, Menu, ToolbarButton } from '@grafana/ui';
+import { DataLink, LinkModel } from '@grafana/data';
+import { SceneComponentProps, SceneObjectBase, SceneObjectState, VizPanel } from '@grafana/scenes';
+import { Dropdown, Icon, Menu, PanelChrome, ToolbarButton } from '@grafana/ui';
+
+import { getPanelLinks } from './PanelMenuBehavior';
 
 interface VizPanelLinksState extends SceneObjectState {
+  rawLinks?: DataLink[];
   links?: LinkModel[];
   menu: VizPanelLinksMenu;
 }
@@ -14,7 +17,24 @@ export class VizPanelLinks extends SceneObjectBase<VizPanelLinksState> {
 }
 
 function VizPanelLinksRenderer({ model }: SceneComponentProps<VizPanelLinks>) {
-  const { menu } = model.useState();
+  const { menu, rawLinks } = model.useState();
+
+  if (!(model.parent instanceof VizPanel)) {
+    throw new Error('VizPanelLinks must be a child of VizPanel');
+  }
+
+  if (!rawLinks || rawLinks.length === 0) {
+    return null;
+  }
+
+  if (rawLinks.length === 1) {
+    const link = getPanelLinks(model.parent)[0];
+    return (
+      <PanelChrome.TitleItem href={link.href} onClick={link.onClick} target={link.target} title={link.title}>
+        <Icon name="external-link-alt" size="md" />
+      </PanelChrome.TitleItem>
+    );
+  }
 
   return (
     <Dropdown
@@ -27,7 +47,7 @@ function VizPanelLinksRenderer({ model }: SceneComponentProps<VizPanelLinks>) {
   );
 }
 
-export class VizPanelLinksMenu extends SceneObjectBase<Omit<VizPanelLinksState, 'menu'>> {
+export class VizPanelLinksMenu extends SceneObjectBase<Omit<VizPanelLinksState, 'menu' | 'rawLinks'>> {
   static Component = VizPanelLinksMenuRenderer;
 }
 
