@@ -7,14 +7,17 @@ import {
   IntervalVariableModel,
   TypedVariableModel,
   TextBoxVariableModel,
+  GroupByVariableModel,
 } from '@grafana/data';
 import { getPanelPlugin } from '@grafana/data/test/__mocks__/pluginMocks';
 import { config } from '@grafana/runtime';
 import {
-  AdHocFilterSet,
+  AdHocFiltersVariable,
   behaviors,
+  ConstantVariable,
   CustomVariable,
   DataSourceVariable,
+  GroupByVariable,
   QueryVariable,
   SceneDataLayerControls,
   SceneDataLayers,
@@ -22,9 +25,19 @@ import {
   SceneGridItem,
   SceneGridLayout,
   SceneGridRow,
+  SceneQueryRunner,
+  SceneRefreshPicker,
+  SceneTimePicker,
   VizPanel,
 } from '@grafana/scenes';
-import { DashboardCursorSync, defaultDashboard, Panel, RowPanel, VariableType } from '@grafana/schema';
+import {
+  DashboardCursorSync,
+  defaultDashboard,
+  defaultTimePickerConfig,
+  Panel,
+  RowPanel,
+  VariableType,
+} from '@grafana/schema';
 import { DashboardModel, PanelModel } from 'app/features/dashboard/state';
 import { createPanelSaveModel } from 'app/features/dashboard/state/__fixtures__/dashboardFixtures';
 import { SHARED_DASHBOARD_QUERY } from 'app/plugins/datasource/dashboard';
@@ -35,9 +48,10 @@ import { DashboardControls } from '../scene/DashboardControls';
 import { PanelRepeaterGridItem } from '../scene/PanelRepeaterGridItem';
 import { PanelTimeRange } from '../scene/PanelTimeRange';
 import { RowRepeaterBehavior } from '../scene/RowRepeaterBehavior';
-import { ShareQueryDataProvider } from '../scene/ShareQueryDataProvider';
+import { NEW_LINK } from '../settings/links/utils';
 import { getQueryRunnerFor } from '../utils/utils';
 
+import { buildNewDashboardSaveModel } from './buildNewDashboardSaveModel';
 import dashboard_to_load1 from './testfiles/dashboard_to_load1.json';
 import repeatingRowsAndPanelsDashboardJson from './testfiles/repeating_rows_and_panels.json';
 import {
@@ -58,6 +72,11 @@ describe('transformSaveModelToScene', () => {
         weekStart: 'saturday',
         fiscalYearStartMonth: 2,
         timezone: 'America/New_York',
+        timepicker: {
+          ...defaultTimePickerConfig,
+          hidden: true,
+        },
+        links: [{ ...NEW_LINK, title: 'Link 1' }],
         templating: {
           list: [
             {
@@ -93,20 +112,29 @@ describe('transformSaveModelToScene', () => {
       const oldModel = new DashboardModel(dash);
 
       const scene = createDashboardSceneFromDashboardModel(oldModel);
+      const dashboardControls = scene.state.controls![0] as DashboardControls;
 
       expect(scene.state.title).toBe('test');
       expect(scene.state.uid).toBe('test-uid');
+      expect(scene.state.links).toHaveLength(1);
+      expect(scene.state.links![0].title).toBe('Link 1');
       expect(scene.state?.$timeRange?.state.value.raw).toEqual(dash.time);
       expect(scene.state?.$timeRange?.state.fiscalYearStartMonth).toEqual(2);
       expect(scene.state?.$timeRange?.state.timeZone).toEqual('America/New_York');
       expect(scene.state?.$timeRange?.state.weekStart).toEqual('saturday');
-      expect(scene.state?.$variables?.state.variables).toHaveLength(1);
-      expect(scene.state.controls).toBeDefined();
-      expect(scene.state.controls![0]).toBeInstanceOf(DashboardControls);
-      expect((scene.state.controls![0] as DashboardControls).state.variableControls[1]).toBeInstanceOf(AdHocFilterSet);
-      expect(
-        ((scene.state.controls![0] as DashboardControls).state.variableControls[1] as AdHocFilterSet).state.name
-      ).toBe('CoolFilters');
+
+      expect(scene.state?.$variables?.state.variables).toHaveLength(2);
+      expect(scene.state?.$variables?.getByName('constant')).toBeInstanceOf(ConstantVariable);
+      expect(scene.state?.$variables?.getByName('CoolFilters')).toBeInstanceOf(AdHocFiltersVariable);
+      expect(dashboardControls).toBeDefined();
+      expect(dashboardControls).toBeInstanceOf(DashboardControls);
+      expect(dashboardControls.state.timeControls).toHaveLength(2);
+      expect(dashboardControls.state.timeControls[0]).toBeInstanceOf(SceneTimePicker);
+      expect(dashboardControls.state.timeControls[1]).toBeInstanceOf(SceneRefreshPicker);
+      expect((dashboardControls.state.timeControls[1] as SceneRefreshPicker).state.intervals).toEqual(
+        defaultTimePickerConfig.refresh_intervals
+      );
+      expect(dashboardControls.state.hideTimeControls).toBe(true);
     });
 
     it('should apply cursor sync behavior', () => {
@@ -118,9 +146,38 @@ describe('transformSaveModelToScene', () => {
 
       const scene = createDashboardSceneFromDashboardModel(oldModel);
 
-      expect(scene.state.$behaviors).toHaveLength(3);
-      expect(scene.state.$behaviors![1]).toBeInstanceOf(behaviors.CursorSync);
-      expect((scene.state.$behaviors![1] as behaviors.CursorSync).state.sync).toEqual(DashboardCursorSync.Crosshair);
+      expect(scene.state.$behaviors).toHaveLength(5);
+      expect(scene.state.$behaviors![0]).toBeInstanceOf(behaviors.CursorSync);
+      expect((scene.state.$behaviors![0] as behaviors.CursorSync).state.sync).toEqual(DashboardCursorSync.Crosshair);
+    });
+
+    it('should initialize the Dashboard Scene with empty template variables', () => {
+      const dash = {
+        ...defaultDashboard,
+        title: 'test empty dashboard with no variables',
+        uid: 'test-uid',
+        time: { from: 'now-10h', to: 'now' },
+        weekStart: 'saturday',
+        fiscalYearStartMonth: 2,
+        timezone: 'America/New_York',
+        templating: {
+          list: [],
+        },
+      };
+      const oldModel = new DashboardModel(dash);
+
+      const scene = createDashboardSceneFromDashboardModel(oldModel);
+      expect(scene.state.$variables?.state.variables).toBeDefined();
+    });
+  });
+
+  describe('When creating a new dashboard', () => {
+    it('should initialize the DashboardScene in edit mode and dirty', () => {
+      const rsp = buildNewDashboardSaveModel();
+      const scene = transformSaveModelToScene(rsp);
+
+      expect(scene.state.isEditing).toBe(true);
+      expect(scene.state.isDirty).toBe(true);
     });
   });
 
@@ -343,7 +400,9 @@ describe('transformSaveModelToScene', () => {
       };
 
       const { vizPanel } = buildGridItemForTest(panel);
-      expect(vizPanel.state.$data).toBeInstanceOf(ShareQueryDataProvider);
+      expect(vizPanel.state.$data).toBeInstanceOf(SceneDataTransformer);
+      expect(vizPanel.state.$data?.state.$data).toBeInstanceOf(SceneQueryRunner);
+      expect((vizPanel.state.$data?.state.$data as SceneQueryRunner).state.queries).toEqual(panel.targets);
     });
 
     it('should not set SceneQueryRunner for plugins with skipDataQuery', () => {
@@ -384,6 +443,22 @@ describe('transformSaveModelToScene', () => {
       expect(repeater.state.repeatDirection).toBe('v');
       expect(repeater.state.maxPerRow).toBe(8);
     });
+
+    it('should apply query caching options to SceneQueryRunner', () => {
+      const panel = {
+        title: '',
+        type: 'test-plugin',
+        gridPos: { x: 0, y: 0, w: 12, h: 8 },
+        transparent: true,
+        cacheTimeout: '10',
+        queryCachingTTL: 200000,
+      };
+
+      const { vizPanel } = buildGridItemForTest(panel);
+      const runner = getQueryRunnerFor(vizPanel)!;
+      expect(runner.state.cacheTimeout).toBe('10');
+      expect(runner.state.queryCachingTTL).toBe(200000);
+    });
   });
 
   describe('when creating variables objects', () => {
@@ -733,6 +808,170 @@ describe('transformSaveModelToScene', () => {
       });
     });
 
+    it('should migrate adhoc variable', () => {
+      const variable: TypedVariableModel = {
+        id: 'adhoc',
+        global: false,
+        index: 0,
+        state: LoadingState.Done,
+        error: null,
+        name: 'adhoc',
+        label: 'Adhoc Label',
+        description: 'Adhoc Description',
+        type: 'adhoc',
+        rootStateKey: 'N4XLmH5Vz',
+        datasource: {
+          uid: 'gdev-prometheus',
+          type: 'prometheus',
+        },
+        filters: [
+          {
+            key: 'filterTest',
+            operator: '=',
+            value: 'test',
+          },
+        ],
+        baseFilters: [
+          {
+            key: 'baseFilterTest',
+            operator: '=',
+            value: 'test',
+          },
+        ],
+        hide: 0,
+        skipUrlSync: false,
+      };
+
+      const migrated = createSceneVariableFromVariableModel(variable) as AdHocFiltersVariable;
+      const filterVarState = migrated.state;
+
+      expect(migrated).toBeInstanceOf(AdHocFiltersVariable);
+      expect(filterVarState).toEqual({
+        key: expect.any(String),
+        description: 'Adhoc Description',
+        hide: 0,
+        label: 'Adhoc Label',
+        name: 'adhoc',
+        skipUrlSync: false,
+        type: 'adhoc',
+        filterExpression: 'filterTest="test"',
+        filters: [{ key: 'filterTest', operator: '=', value: 'test' }],
+        baseFilters: [{ key: 'baseFilterTest', operator: '=', value: 'test' }],
+        datasource: { uid: 'gdev-prometheus', type: 'prometheus' },
+        applyMode: 'auto',
+      });
+    });
+
+    describe('when groupByVariable feature toggle is enabled', () => {
+      beforeAll(() => {
+        config.featureToggles.groupByVariable = true;
+      });
+
+      afterAll(() => {
+        config.featureToggles.groupByVariable = false;
+      });
+
+      it('should migrate groupby variable', () => {
+        const variable: GroupByVariableModel = {
+          id: 'groupby',
+          global: false,
+          index: 0,
+          state: LoadingState.Done,
+          error: null,
+          name: 'groupby',
+          label: 'GroupBy Label',
+          description: 'GroupBy Description',
+          type: 'groupby',
+          rootStateKey: 'N4XLmH5Vz',
+          datasource: {
+            uid: 'gdev-prometheus',
+            type: 'prometheus',
+          },
+          multi: true,
+          options: [
+            {
+              selected: false,
+              text: 'Foo',
+              value: 'foo',
+            },
+            {
+              selected: false,
+              text: 'Bar',
+              value: 'bar',
+            },
+          ],
+          current: {},
+          query: '',
+          hide: 0,
+          skipUrlSync: false,
+        };
+
+        const migrated = createSceneVariableFromVariableModel(variable) as GroupByVariable;
+        const groupbyVarState = migrated.state;
+
+        expect(migrated).toBeInstanceOf(GroupByVariable);
+        expect(groupbyVarState).toEqual({
+          key: expect.any(String),
+          description: 'GroupBy Description',
+          hide: 0,
+          defaultOptions: [
+            {
+              selected: false,
+              text: 'Foo',
+              value: 'foo',
+            },
+            {
+              selected: false,
+              text: 'Bar',
+              value: 'bar',
+            },
+          ],
+          isMulti: true,
+          layout: 'horizontal',
+          noValueOnClear: true,
+          label: 'GroupBy Label',
+          name: 'groupby',
+          skipUrlSync: false,
+          type: 'groupby',
+          baseFilters: [],
+          options: [],
+          text: [],
+          value: [],
+          datasource: { uid: 'gdev-prometheus', type: 'prometheus' },
+          applyMode: 'auto',
+        });
+      });
+    });
+
+    describe('when groupByVariable feature toggle is disabled', () => {
+      it('should not migrate groupby variable and throw an error instead', () => {
+        const variable: GroupByVariableModel = {
+          id: 'groupby',
+          global: false,
+          index: 0,
+          state: LoadingState.Done,
+          error: null,
+          name: 'groupby',
+          label: 'GroupBy Label',
+          description: 'GroupBy Description',
+          type: 'groupby',
+          rootStateKey: 'N4XLmH5Vz',
+          datasource: {
+            uid: 'gdev-prometheus',
+            type: 'prometheus',
+          },
+          multi: true,
+          options: [],
+          current: {},
+          query: '',
+          hide: 0,
+          skipUrlSync: false,
+        };
+
+        expect(() => createSceneVariableFromVariableModel(variable)).toThrow('Scenes: Unsupported variable type');
+      });
+    });
+
     it.each(['system'])('should throw for unsupported (yet) variables', (type) => {
       const variable = {
         name: 'query0',
@@ -800,7 +1039,7 @@ describe('transformSaveModelToScene', () => {
       const scene = transformSaveModelToScene({ dashboard: dashboard_to_load1 as any, meta: {} });
 
       expect(scene.state.$data).toBeInstanceOf(SceneDataLayers);
-      expect((scene.state.controls![0] as DashboardControls)!.state.variableControls[2]).toBeInstanceOf(
+      expect((scene.state.controls![0] as DashboardControls)!.state.variableControls[1]).toBeInstanceOf(
         SceneDataLayerControls
       );
 
@@ -830,7 +1069,7 @@ describe('transformSaveModelToScene', () => {
       const scene = transformSaveModelToScene({ dashboard: dashboard_to_load1 as any, meta: {} });
 
       expect(scene.state.$data).toBeInstanceOf(SceneDataLayers);
-      expect((scene.state.controls![0] as DashboardControls)!.state.variableControls[2]).toBeInstanceOf(
+      expect((scene.state.controls![0] as DashboardControls)!.state.variableControls[1]).toBeInstanceOf(
         SceneDataLayerControls
       );
 
@@ -846,7 +1085,7 @@ describe('transformSaveModelToScene', () => {
       const scene = transformSaveModelToScene({ dashboard: dashboard_to_load1 as any, meta: {} });
 
       expect(scene.state.$data).toBeInstanceOf(SceneDataLayers);
-      expect((scene.state.controls![0] as DashboardControls)!.state.variableControls[2]).toBeInstanceOf(
+      expect((scene.state.controls![0] as DashboardControls)!.state.variableControls[1]).toBeInstanceOf(
         SceneDataLayerControls
       );
 
