@@ -1,6 +1,5 @@
 import React from 'react';
 
-import { config } from '@grafana/runtime';
 import { Permissions } from 'app/core/components/AccessControl';
 import { Page } from 'app/core/components/Page/Page';
 import { contextSrv } from 'app/core/core';
@@ -10,7 +9,7 @@ import { SettingsPageProps } from '../DashboardSettings/types';
 
 export const AccessControlDashboardPermissions = ({ dashboard, sectionNav }: SettingsPageProps) => {
   const canSetPermissions = contextSrv.hasPermission(AccessControlAction.DashboardsPermissionsWrite);
-  const pageNav = config.featureToggles.dockedMegaMenu ? sectionNav.node.parentItem : undefined;
+  const pageNav = sectionNav.node.parentItem;
 
   return (
     <Page navModel={sectionNav} pageNav={pageNav}>
