@@ -1,11 +1,12 @@
 import React, { useCallback, useEffect, useMemo, useState } from 'react';
 
 import { Input, defaultIntervals, Field } from '@grafana/ui';
+import { t } from 'app/core/internationalization';
 
 import { getTimeSrv } from '../../services/TimeSrv';
 
 export interface Props {
-  refreshIntervals: string[];
+  refreshIntervals?: string[];
   onRefreshIntervalChange: (interval: string[]) => void;
   getIntervalsFunc?: typeof getValidIntervals;
   validateIntervalsFunc?: typeof validateIntervals;
@@ -58,8 +59,11 @@ export const AutoRefreshIntervals = ({
 
   return (
     <Field
-      label="Auto refresh"
-      description="Define the auto refresh intervals that should be available in the auto refresh list."
+      label={t('dashboard-settings.general.auto-refresh-label', 'Auto refresh')}
+      description={t(
+        'dashboard-settings.general.auto-refresh-description',
+        'Define the auto refresh intervals that should be available in the auto refresh list.'
+      )}
       error={invalidIntervalsMessage}
       invalid={!!invalidIntervalsMessage}
     >
