@@ -8,7 +8,7 @@ import { locationService } from '@grafana/runtime';
 import { Button, ToolbarButtonRow } from '@grafana/ui';
 import { AppChromeUpdate } from 'app/core/components/AppChrome/AppChromeUpdate';
 import { Page } from 'app/core/components/Page/Page';
-import config from 'app/core/config';
+import { t } from 'app/core/internationalization';
 import { contextSrv } from 'app/core/services/context_srv';
 import { AccessControlAction } from 'app/types';
 import { DashboardMetaChangedEvent } from 'app/types/events';
@@ -16,7 +16,6 @@ import { DashboardMetaChangedEvent } from 'app/types/events';
 import { VariableEditorContainer } from '../../../variables/editor/VariableEditorContainer';
 import { DashboardModel } from '../../state/DashboardModel';
 import { AccessControlDashboardPermissions } from '../DashboardPermissions/AccessControlDashboardPermissions';
-import { DashboardPermissions } from '../DashboardPermissions/DashboardPermissions';
 import { SaveDashboardAsButton, SaveDashboardButton } from '../SaveDashboard/SaveDashboardButton';
 
 import { AnnotationsSettings } from './AnnotationsSettings';
@@ -91,16 +90,18 @@ export function DashboardSettings({ dashboard, editview, pageNav, sectionNav }:
 function getSettingsPages(dashboard: DashboardModel) {
   const pages: SettingsPage[] = [];
 
+  const generalTitle = t('dashboard-settings.general.title', 'General');
+
   if (dashboard.meta.canEdit) {
     pages.push({
-      title: 'General',
+      title: generalTitle,
       id: 'settings',
       icon: 'sliders-v-alt',
       component: GeneralSettings,
     });
 
     pages.push({
-      title: 'Annotations',
+      title: t('dashboard-settings.annotations.title', 'Annotations'),
       id: 'annotations',
       icon: 'comment-alt',
       component: AnnotationsSettings,
@@ -109,7 +110,7 @@ function getSettingsPages(dashboard: DashboardModel) {
     });
 
     pages.push({
-      title: 'Variables',
+      title: t('dashboard-settings.variables.title', 'Variables'),
       id: 'templating',
       icon: 'calculator-alt',
       component: VariableEditorContainer,
@@ -117,7 +118,7 @@ function getSettingsPages(dashboard: DashboardModel) {
     });
 
     pages.push({
-      title: 'Links',
+      title: t('dashboard-settings.links.title', 'Links'),
       id: 'links',
       icon: 'link',
       component: LinksSettings,
@@ -126,7 +127,7 @@ function getSettingsPages(dashboard: DashboardModel) {
 
   if (dashboard.meta.canMakeEditable) {
     pages.push({
-      title: 'General',
+      title: generalTitle,
       icon: 'sliders-v-alt',
       id: 'settings',
       component: MakeEditable,
@@ -135,24 +136,19 @@ function getSettingsPages(dashboard: DashboardModel) {
 
   if (dashboard.id && dashboard.meta.canSave) {
     pages.push({
-      title: 'Versions',
+      title: t('dashboard-settings.versions.title', 'Versions'),
       id: 'versions',
       icon: 'history',
       component: VersionsSettings,
     });
   }
 
+  const permissionsTitle = t('dashboard-settings.permissions.title', 'Permissions');
+
   if (dashboard.id && dashboard.meta.canAdmin) {
-    if (!config.rbacEnabled) {
+    if (contextSrv.hasPermission(AccessControlAction.DashboardsPermissionsRead)) {
       pages.push({
-        title: 'Permissions',
-        id: 'permissions',
-        icon: 'lock',
-        component: DashboardPermissions,
-      });
-    } else if (contextSrv.hasPermission(AccessControlAction.DashboardsPermissionsRead)) {
-      pages.push({
-        title: 'Permissions',
+        title: permissionsTitle,
         id: 'permissions',
         icon: 'lock',
         component: AccessControlDashboardPermissions,
@@ -161,7 +157,7 @@ function getSettingsPages(dashboard: DashboardModel) {
   }
 
   pages.push({
-    title: 'JSON Model',
+    title: t('dashboard-settings.json-editor.title', 'JSON Model'),
     id: 'dashboard_json',
     icon: 'arrow',
     component: JsonEditorSettings,
@@ -185,10 +181,11 @@ function getSectionNav(
   location: H.Location
 ): NavModel {
   const main: NavModelItem = {
-    text: 'Settings',
+    text: t('dashboard-settings.settings.title', 'Settings'),
     children: [],
     icon: 'apps',
-    hideFromBreadcrumbs: true,
+    hideFromBreadcrumbs: false,
+    url: locationUtil.getUrlForPartial(location, { editview: 'settings', editIndex: null }),
   };
 
   main.children = pages.map((page) => ({
