@@ -22,7 +22,7 @@ export interface OptionsPaneCategoryProps {
   sandboxId?: string;
 }
 
-const CATEGORY_PARAM_NAME = 'showCategory';
+const CATEGORY_PARAM_NAME = 'showCategory' as const;
 
 export const OptionsPaneCategory = React.memo(
   ({
@@ -30,23 +30,21 @@ export const OptionsPaneCategory = React.memo(
     title,
     children,
     forceOpen,
-    isOpenDefault,
+    isOpenDefault = true,
     renderTitle,
     className,
     itemsCount,
     isNested = false,
     sandboxId,
   }: OptionsPaneCategoryProps) => {
-    const initialIsExpanded = isOpenDefault !== false;
     const [savedState, setSavedState] = useLocalStorage(getOptionGroupStorageKey(id), {
-      isExpanded: initialIsExpanded,
+      isExpanded: isOpenDefault,
     });
 
-    const styles = useStyles2(getStyles);
-    const [queryParams, updateQueryParams] = useQueryParams();
-    const [isExpanded, setIsExpanded] = useState(savedState?.isExpanded ?? initialIsExpanded);
+    const [isExpanded, setIsExpanded] = useState(savedState?.isExpanded ?? isOpenDefault);
     const manualClickTime = useRef(0);
     const ref = useRef<HTMLDivElement>(null);
+    const [queryParams, updateQueryParams] = useQueryParams();
     const isOpenFromUrl = queryParams[CATEGORY_PARAM_NAME] === id;
 
     useEffect(() => {
@@ -92,13 +90,13 @@ export const OptionsPaneCategory = React.memo(
       };
     }
 
+    const styles = useStyles2(getStyles);
     const boxStyles = cx(
       {
         [styles.box]: true,
         [styles.boxNestedExpanded]: isNested && isExpanded,
       },
-      className,
-      'options-group'
+      className
     );
 
     const headerStyles = cx(styles.header, {
@@ -149,61 +147,60 @@ export const OptionsPaneCategory = React.memo(
 
 OptionsPaneCategory.displayName = 'OptionsPaneCategory';
 
-const getStyles = (theme: GrafanaTheme2) => {
-  return {
-    box: css`
-      border-top: 1px solid ${theme.colors.border.weak};
-    `,
-    boxNestedExpanded: css`
-      margin-bottom: ${theme.spacing(2)};
-    `,
-    title: css`
-      flex-grow: 1;
-      overflow: hidden;
-      line-height: 1.5;
-      font-size: 1rem;
-      padding-left: 6px;
-      font-weight: ${theme.typography.fontWeightMedium};
-      margin: 0;
-    `,
-    header: css`
-      display: flex;
-      cursor: pointer;
-      align-items: center;
-      padding: ${theme.spacing(0.5)};
-      color: ${theme.colors.text.primary};
-      font-weight: ${theme.typography.fontWeightMedium};
+const getStyles = (theme: GrafanaTheme2) => ({
+  box: css({
+    borderTop: `1px solid ${theme.colors.border.weak}`,
+  }),
+  boxNestedExpanded: css({
+    marginBottom: theme.spacing(2),
+  }),
+  title: css({
+    flexGrow: 1,
+    overflow: 'hidden',
+    lineHeight: 1.5,
+    fontSize: '1rem',
+    paddingLeft: '6px',
+    fontWeight: theme.typography.fontWeightMedium,
+    margin: 0,
+  }),
+  header: css({
+    display: 'flex',
+    cursor: 'pointer',
+    alignItems: 'center',
+    padding: theme.spacing(0.5),
+    color: theme.colors.text.primary,
+    fontWeight: theme.typography.fontWeightMedium,
 
-      &:hover {
-        background: ${theme.colors.emphasize(theme.colors.background.primary, 0.03)};
-      }
-    `,
-    toggleButton: css`
-      align-self: baseline;
-    `,
-    headerExpanded: css`
-      color: ${theme.colors.text.primary};
-    `,
-    headerNested: css`
-      padding: ${theme.spacing(0.5, 0, 0.5, 0)};
-    `,
-    body: css`
-      padding: ${theme.spacing(1, 2, 1, 4)};
-    `,
-    bodyNested: css`
-      position: relative;
-      padding-right: 0;
-      &:before {
-        content: '';
-        position: absolute;
-        top: 0;
-        left: 8px;
-        width: 1px;
-        height: 100%;
-        background: ${theme.colors.border.weak};
-      }
-    `,
-  };
-};
+    '&:hover': {
+      background: theme.colors.emphasize(theme.colors.background.primary, 0.03),
+    },
+  }),
+  toggleButton: css({
+    alignSelf: 'baseline',
+  }),
+  headerExpanded: css({
+    color: theme.colors.text.primary,
+  }),
+  headerNested: css({
+    padding: theme.spacing(0.5, 0, 0.5, 0),
+  }),
+  body: css({
+    padding: theme.spacing(1, 2, 1, 4),
+  }),
+  bodyNested: css({
+    position: 'relative',
+    paddingRight: 0,
 
-const getOptionGroupStorageKey = (id: string): string => `${PANEL_EDITOR_UI_STATE_STORAGE_KEY}.optionGroup[${id}]`;
+    '&:before': {
+      content: "''",
+      position: 'absolute',
+      top: 0,
+      left: '8px',
+      width: '1px',
+      height: '100%',
+      background: theme.colors.border.weak,
+    },
+  }),
+});
+
+const getOptionGroupStorageKey = (id: string) => `${PANEL_EDITOR_UI_STATE_STORAGE_KEY}.optionGroup[${id}]`;
