@@ -1,10 +1,12 @@
 import { css } from '@emotion/css';
-import React, { useEffect } from 'react';
+import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { FetchError } from '@grafana/runtime';
+import { Dashboard } from '@grafana/schema';
 import { Button, ConfirmModal, Modal, useStyles2 } from '@grafana/ui';
-import { DashboardModel } from 'app/features/dashboard/state';
+
+import { DashboardModel } from '../../state/DashboardModel';
 
 import { SaveDashboardAsButton } from './SaveDashboardButton';
 import { SaveDashboardModalProps } from './types';
@@ -14,9 +16,10 @@ interface SaveDashboardErrorProxyProps {
   /** original dashboard */
   dashboard: DashboardModel;
   /** dashboard save model with applied modifications, i.e. title */
-  dashboardSaveModel: DashboardModel;
+  dashboardSaveModel: Dashboard;
   error: FetchError;
   onDismiss: () => void;
+  setErrorIsHandled: React.Dispatch<React.SetStateAction<boolean>>;
 }
 
 export const SaveDashboardErrorProxy = ({
@@ -24,14 +27,9 @@ export const SaveDashboardErrorProxy = ({
   dashboardSaveModel,
   error,
   onDismiss,
+  setErrorIsHandled,
 }: SaveDashboardErrorProxyProps) => {
-  const { onDashboardSave } = useDashboardSave(dashboard);
-
-  useEffect(() => {
-    if (error.data && proxyHandlesError(error.data.status)) {
-      error.isHandled = true;
-    }
-  }, [error]);
+  const { onDashboardSave } = useDashboardSave();
 
   return (
     <>
@@ -71,14 +69,20 @@ export const SaveDashboardErrorProxy = ({
         />
       )}
       {error.data && error.data.status === 'plugin-dashboard' && (
-        <ConfirmPluginDashboardSaveModal dashboard={dashboard} onDismiss={onDismiss} />
+        <ConfirmPluginDashboardSaveModal
+          dashboard={dashboard}
+          onDismiss={() => {
+            setErrorIsHandled(true);
+            onDismiss();
+          }}
+        />
       )}
     </>
   );
 };
 
 const ConfirmPluginDashboardSaveModal = ({ onDismiss, dashboard }: SaveDashboardModalProps) => {
-  const { onDashboardSave } = useDashboardSave(dashboard);
+  const { onDashboardSave } = useDashboardSave();
   const styles = useStyles2(getConfirmPluginDashboardSaveModalStyles);
 
   return (
@@ -94,7 +98,7 @@ const ConfirmPluginDashboardSaveModal = ({ onDismiss, dashboard }: SaveDashboard
         <Button variant="secondary" onClick={onDismiss} fill="outline">
           Cancel
         </Button>
-        <SaveDashboardAsButton dashboard={dashboard} onSaveSuccess={onDismiss} />
+        <SaveDashboardAsButton onClick={onDismiss} dashboard={dashboard} onSaveSuccess={onDismiss} />
         <Button
           variant="destructive"
           onClick={async () => {
