@@ -6,7 +6,8 @@ import { setEchoSrv } from '@grafana/runtime/src';
 import config from 'app/core/config';
 
 import { Echo } from '../../../../core/services/echo/Echo';
-import { DashboardModel, PanelModel } from '../../state';
+import { PanelModel } from '../../state';
+import { createDashboardModelFixture } from '../../state/__fixtures__/dashboardFixtures';
 
 import { ShareEmbed } from './ShareEmbed';
 
@@ -68,7 +69,7 @@ describe('ShareEmbed', () => {
   });
 
   it('generates the correct embed url for a dashboard', () => {
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
@@ -86,7 +87,7 @@ describe('ShareEmbed', () => {
 
   it('generates the correct embed url for a dashboard set to the homepage in the grafana config', () => {
     mockLocationHref('http://dashboards.grafana.com/?orgId=1');
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
@@ -104,7 +105,7 @@ describe('ShareEmbed', () => {
   it('generates the correct embed url for a snapshot', () => {
     const mockSlug = 'mockSlug';
     mockLocationHref(`http://dashboards.grafana.com/dashboard/snapshot/${mockSlug}?orgId=1`);
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
@@ -122,7 +123,7 @@ describe('ShareEmbed', () => {
   it('generates the correct embed url for a scripted dashboard', () => {
     const mockSlug = 'scripted.js';
     mockLocationHref(`http://dashboards.grafana.com/dashboard/script/${mockSlug}?orgId=1`);
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
