@@ -5,6 +5,7 @@ import React from 'react';
 import { GrafanaTheme2 } from '@grafana/data/src';
 import { selectors as e2eSelectors } from '@grafana/e2e-selectors/src';
 import { Alert, useStyles2 } from '@grafana/ui/src';
+import { Trans, t } from 'app/core/internationalization';
 
 const selectors = e2eSelectors.pages.ShareDashboardModal.PublicDashboard;
 
@@ -14,19 +15,23 @@ export const UnsupportedDataSourcesAlert = ({ unsupportedDataSources }: { unsupp
   return (
     <Alert
       severity="warning"
-      title="Unsupported data sources"
+      title={t('public-dashboard.modal-alerts.unsupported-data-source-alert-title', 'Unsupported data sources')}
       data-testid={selectors.UnsupportedDataSourcesWarningAlert}
       bottomSpacing={0}
     >
       <p className={styles.unsupportedDataSourceDescription}>
-        There are data sources in this dashboard that are unsupported for public dashboards. Panels that use these data
-        sources may not function properly: {unsupportedDataSources}.
+        <Trans i18nKey="public-dashboard.modal-alerts.unsupported-data-source-alert-desc">
+          There are data sources in this dashboard that are unsupported for public dashboards. Panels that use these
+          data sources may not function properly: {{ unsupportedDataSources }}.
+        </Trans>
       </p>
       <a
         href="https://grafana.com/docs/grafana/next/dashboards/dashboard-public/"
         className={cx('text-link', styles.unsupportedDataSourceDescription)}
       >
-        Read more about supported data sources
+        <Trans i18nKey="public-dashboard.modal-alerts.unsupport-data-source-alert-readmore-link">
+          Read more about supported data sources
+        </Trans>
       </a>
     </Alert>
   );
