@@ -1,6 +1,7 @@
 import React from 'react';
-import { PanelModel } from '@grafana/data';
-import { DashboardModel } from 'app/features/dashboard/state';
+
+import { NavModelItem } from '@grafana/data';
+import { DashboardModel, PanelModel } from 'app/features/dashboard/state';
 
 export interface ShareModalTabProps {
   dashboard: DashboardModel;
@@ -8,10 +9,9 @@ export interface ShareModalTabProps {
   onDismiss?(): void;
 }
 
-export type ShareModalTab = React.ComponentType<ShareModalTabProps>;
-
 export interface ShareModalTabModel {
   label: string;
   value: string;
-  component: ShareModalTab;
+  tabSuffix?: NavModelItem['tabSuffix'];
+  component: React.ComponentType<ShareModalTabProps>;
 }
