@@ -18,4 +18,6 @@ export type DashboardPageRouteSearchParams = {
   to?: string;
   refresh?: string;
   kiosk?: string | true;
+  scenes?: boolean;
+  shareView?: string;
 };
