@@ -20,7 +20,7 @@ describe('<BasicSettings>', () => {
   it('should render component', () => {
     setup();
 
-    expect(screen.getByRole('textbox', { name: selectors.pages.DataSource.name })).toBeInTheDocument();
+    expect(screen.getByTestId(selectors.pages.DataSource.name)).toBeInTheDocument();
     expect(screen.getByRole('checkbox', { name: /Default/ })).toBeInTheDocument();
   });
 });
