@@ -1,4 +1,4 @@
-import React, { FC, useState, useEffect } from 'react';
+import React, { useState, useEffect } from 'react';
 import { useInterval } from 'react-use';
 
 import { Time, TimeProps } from './Time';
@@ -8,10 +8,10 @@ const INTERVAL = 150;
 export interface ElapsedTimeProps extends Omit<TimeProps, 'timeInMs'> {
   // Use this to reset the timer. Any value is allowed just need to be !== from the previous.
   // Keep in mind things like [] !== [] or {} !== {}.
-  resetKey?: any;
+  resetKey?: unknown;
 }
 
-export const ElapsedTime: FC<ElapsedTimeProps> = ({ resetKey, humanize, className }) => {
+export const ElapsedTime = ({ resetKey, humanize, className }: ElapsedTimeProps) => {
   const [elapsed, setElapsed] = useState(0); // the current value of elapsed
 
   // hook that will schedule a interval and then update the elapsed value on every tick.
