@@ -2,26 +2,22 @@ import { css } from '@emotion/css';
 import React, { useEffect, useMemo, useRef } from 'react';
 import { connect } from 'react-redux';
 
-import { EventBusSrv, GrafanaTheme2 } from '@grafana/data';
+import { EventBusSrv } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { useStyles2, CustomScrollbar } from '@grafana/ui';
+import { CustomScrollbar } from '@grafana/ui';
 import { stopQueryState } from 'app/core/utils/explore';
 import { StoreState, useSelector } from 'app/types';
 
 import Explore from './Explore';
 import { getExploreItemSelector } from './state/selectors';
 
-const getStyles = (theme: GrafanaTheme2) => {
-  return {
-    explore: css`
-      label: explorePaneContainer;
-      display: flex;
-      flex-direction: column;
-      min-width: 600px;
-      height: 100%;
-    `,
-  };
-};
+const containerStyles = css({
+  label: 'explorePaneContainer',
+  display: 'flex',
+  flexDirection: 'column',
+  minWidth: '600px',
+  height: '100%',
+});
 
 interface Props {
   exploreId: string;
@@ -38,7 +34,6 @@ interface Props {
 */
 function ExplorePaneContainerUnconnected({ exploreId }: Props) {
   useStopQueries(exploreId);
-  const styles = useStyles2(getStyles);
   const eventBus = useRef(new EventBusSrv());
   const ref = useRef(null);
 
@@ -49,7 +44,7 @@ function ExplorePaneContainerUnconnected({ exploreId }: Props) {
 
   return (
     <CustomScrollbar hideVerticalTrack>
-      <div className={styles.explore} ref={ref} data-testid={selectors.pages.Explore.General.container}>
+      <div className={containerStyles} ref={ref} data-testid={selectors.pages.Explore.General.container}>
         <Explore exploreId={exploreId} eventBus={eventBus.current} />
       </div>
     </CustomScrollbar>
