@@ -16,18 +16,17 @@ import {
 } from '@grafana/ui';
 import { AppChromeUpdate } from 'app/core/components/AppChrome/AppChromeUpdate';
 import { t, Trans } from 'app/core/internationalization';
-import { createAndCopyShortLink } from 'app/core/utils/shortLinks';
 import { DataSourcePicker } from 'app/features/datasources/components/picker/DataSourcePicker';
 import { CORRELATION_EDITOR_POST_CONFIRM_ACTION } from 'app/types/explore';
 import { StoreState, useDispatch, useSelector } from 'app/types/store';
 
 import { contextSrv } from '../../core/core';
-import { DashNavButton } from '../dashboard/components/DashNav/DashNavButton';
 import { updateFiscalYearStartMonthForSession, updateTimeZoneForSession } from '../profile/state/reducers';
 import { getFiscalYearStartMonth, getTimeZone } from '../profile/state/selectors';
 
 import { ExploreTimeControls } from './ExploreTimeControls';
 import { LiveTailButton } from './LiveTailButton';
+import { ShortLinkButtonMenu } from './ShortLinkButtonMenu';
 import { ToolbarExtensionPoint } from './extensions/ToolbarExtensionPoint';
 import { changeDatasource } from './state/datasource';
 import { changeCorrelationHelperData } from './state/explorePane';
@@ -99,14 +98,9 @@ export function ExploreToolbar({ exploreId, onChangeTime, onContentOutlineToogle
     ? t('explore.toolbar.refresh-picker-cancel', 'Cancel')
     : t('explore.toolbar.refresh-picker-run', 'Run query');
 
-  const onCopyShortLink = () => {
-    createAndCopyShortLink(global.location.href);
-    reportInteraction('grafana_explore_shortened_link_clicked');
-  };
-
   const onChangeDatasource = async (dsSettings: DataSourceInstanceSettings) => {
     if (!isCorrelationsEditorMode) {
-      dispatch(changeDatasource(exploreId, dsSettings.uid, { importQueries: true }));
+      dispatch(changeDatasource({ exploreId, datasource: dsSettings.uid, options: { importQueries: true } }));
     } else {
       if (correlationDetails?.correlationDirty || correlationDetails?.queryEditorDirty) {
         // prompt will handle datasource change if needed
@@ -134,7 +128,7 @@ export function ExploreToolbar({ exploreId, onChangeTime, onContentOutlineToogle
           });
         }
 
-        dispatch(changeDatasource(exploreId, dsSettings.uid, { importQueries: true }));
+        dispatch(changeDatasource({ exploreId, datasource: dsSettings.uid, options: { importQueries: true } }));
       }
     }
   };
@@ -206,16 +200,7 @@ export function ExploreToolbar({ exploreId, onChangeTime, onContentOutlineToogle
     dispatch(changeRefreshInterval({ exploreId, refreshInterval }));
   };
 
-  const navBarActions = [
-    <DashNavButton
-      key="share"
-      tooltip={t('explore.toolbar.copy-shortened-link', 'Copy shortened link')}
-      icon="share-alt"
-      onClick={onCopyShortLink}
-      aria-label={t('explore.toolbar.copy-shortened-link', 'Copy shortened link')}
-    />,
-    <div style={{ flex: 1 }} key="spacer0" />,
-  ];
+  const navBarActions = [<ShortLinkButtonMenu key="share" />, <div style={{ flex: 1 }} key="spacer0" />];
 
   return (
     <div>
