@@ -1,5 +1,6 @@
 import { identity } from 'lodash';
 import React, { useEffect, useMemo, useState } from 'react';
+import { usePrevious } from 'react-use';
 
 import {
   AbsoluteTimeRange,
@@ -12,7 +13,6 @@ import {
   getFrameDisplayName,
   LoadingState,
   SplitOpen,
-  TimeZone,
   ThresholdsConfig,
   DashboardCursorSync,
   EventBus,
@@ -24,6 +24,8 @@ import {
   TooltipDisplayMode,
   SortOrder,
   GraphThresholdsStyleConfig,
+  TimeZone,
+  VizLegendOptions,
 } from '@grafana/schema';
 import { PanelContext, PanelContextProvider, SeriesVisibilityChangeMode, useTheme2 } from '@grafana/ui';
 import { GraphFieldConfig } from 'app/plugins/panel/graph/types';
@@ -55,6 +57,7 @@ interface Props {
   thresholdsConfig?: ThresholdsConfig;
   thresholdsStyle?: GraphThresholdsStyleConfig;
   eventBus: EventBus;
+  vizLegendOverrides?: Partial<VizLegendOptions>;
 }
 
 export function ExploreGraph({
@@ -75,19 +78,21 @@ export function ExploreGraph({
   thresholdsConfig,
   thresholdsStyle,
   eventBus,
+  vizLegendOverrides,
 }: Props) {
   const theme = useTheme2();
-
+  const previousTimeRange = usePrevious(absoluteRange);
+  const baseTimeRange = loadingState === LoadingState.Loading && previousTimeRange ? previousTimeRange : absoluteRange;
   const timeRange = useMemo(
     () => ({
-      from: dateTime(absoluteRange.from),
-      to: dateTime(absoluteRange.to),
+      from: dateTime(baseTimeRange.from),
+      to: dateTime(baseTimeRange.to),
       raw: {
-        from: dateTime(absoluteRange.from),
-        to: dateTime(absoluteRange.to),
+        from: dateTime(baseTimeRange.from),
+        to: dateTime(baseTimeRange.to),
       },
     }),
-    [absoluteRange.from, absoluteRange.to]
+    [baseTimeRange.from, baseTimeRange.to]
   );
 
   const fieldConfigRegistry = useMemo(
@@ -163,7 +168,8 @@ export function ExploreGraph({
   const panelContext: PanelContext = {
     eventsScope: 'explore',
     eventBus,
-    sync: () => DashboardCursorSync.Crosshair,
+    // TODO: Re-enable DashboardCursorSync.Crosshair when #81505 is fixed
+    sync: () => DashboardCursorSync.Off,
     onToggleSeriesVisibility(label: string, mode: SeriesVisibilityChangeMode) {
       setFieldConfig(seriesVisibilityConfigFactory(label, mode, fieldConfig, data));
     },
@@ -178,9 +184,10 @@ export function ExploreGraph({
         showLegend: true,
         placement: 'bottom',
         calcs: [],
+        ...vizLegendOverrides,
       },
     }),
-    [tooltipDisplayMode]
+    [tooltipDisplayMode, vizLegendOverrides]
   );
 
   return (
