@@ -10,15 +10,16 @@ import {
   LoadingState,
   LogLevel,
   LogRowModel,
-  MutableDataFrame,
   standardTransformersRegistry,
   toUtc,
+  createDataFrame,
 } from '@grafana/data';
 import { organizeFieldsTransformer } from '@grafana/data/src/transformations/transformers/organize';
 import { config } from '@grafana/runtime';
 import { extractFieldsTransformer } from 'app/features/transformers/extractFields/extractFields';
 
 import { Logs } from './Logs';
+import { visualisationTypeKey } from './utils/logs';
 import { getMockElasticFrame, getMockLokiFrame } from './utils/testMocks.test';
 
 const reportInteraction = jest.fn();
@@ -162,65 +163,24 @@ describe('Logs', () => {
       window.innerHeight = originalInnerHeight;
     });
 
-    describe('when `exploreScrollableLogsContainer` is set', () => {
-      let featureToggle: boolean | undefined;
-      beforeEach(() => {
-        featureToggle = config.featureToggles.exploreScrollableLogsContainer;
-        config.featureToggles.exploreScrollableLogsContainer = true;
-      });
-      afterEach(() => {
-        config.featureToggles.exploreScrollableLogsContainer = featureToggle;
-        jest.clearAllMocks();
-      });
+    it('should call `scrollElement.scroll`', () => {
+      const logs = [];
+      for (let i = 0; i < 50; i++) {
+        logs.push(makeLog({ uid: `uid${i}`, rowId: `id${i}`, timeEpochMs: i }));
+      }
+      const scrollElementMock = {
+        scroll: jest.fn(),
+        scrollTop: 920,
+      };
+      setup(
+        { scrollElement: scrollElementMock as unknown as HTMLDivElement, panelState: { logs: { id: 'uid47' } } },
+        undefined,
+        logs
+      );
 
-      it('should call `this.state.logsContainer.scroll`', () => {
-        const scrollIntoViewSpy = jest.spyOn(window.HTMLElement.prototype, 'scrollIntoView');
-        jest.spyOn(window.HTMLElement.prototype, 'scrollTop', 'get').mockReturnValue(920);
-        const scrollSpy = jest.spyOn(window.HTMLElement.prototype, 'scroll');
-
-        const logs = [];
-        for (let i = 0; i < 50; i++) {
-          logs.push(makeLog({ uid: `uid${i}`, rowId: `id${i}`, timeEpochMs: i }));
-        }
-
-        setup({ panelState: { logs: { id: 'uid47' } } }, undefined, logs);
-
-        expect(scrollIntoViewSpy).toBeCalledTimes(1);
-        // element.getBoundingClientRect().top will always be 0 for jsdom
-        // calc will be `this.state.logsContainer.scrollTop - window.innerHeight / 2` -> 920 - 500 = 420
-        expect(scrollSpy).toBeCalledWith({ behavior: 'smooth', top: 420 });
-      });
-    });
-
-    describe('when `exploreScrollableLogsContainer` is not set', () => {
-      let featureToggle: boolean | undefined;
-      beforeEach(() => {
-        featureToggle = config.featureToggles.exploreScrollableLogsContainer;
-        config.featureToggles.exploreScrollableLogsContainer = false;
-      });
-      afterEach(() => {
-        config.featureToggles.exploreScrollableLogsContainer = featureToggle;
-      });
-
-      it('should call `scrollElement.scroll`', () => {
-        const logs = [];
-        for (let i = 0; i < 50; i++) {
-          logs.push(makeLog({ uid: `uid${i}`, rowId: `id${i}`, timeEpochMs: i }));
-        }
-        const scrollElementMock = {
-          scroll: jest.fn(),
-          scrollTop: 920,
-        };
-        setup(
-          { scrollElement: scrollElementMock as unknown as HTMLDivElement, panelState: { logs: { id: 'uid47' } } },
-          undefined,
-          logs
-        );
-
-        // element.getBoundingClientRect().top will always be 0 for jsdom
-        // calc will be `scrollElement.scrollTop - window.innerHeight / 2` -> 920 - 500 = 420
-        expect(scrollElementMock.scroll).toBeCalledWith({ behavior: 'smooth', top: 420 });
-      });
+      // element.getBoundingClientRect().top will always be 0 for jsdom
+      // calc will be `scrollElement.scrollTop - window.innerHeight / 2` -> 920 - 500 = 420
+      expect(scrollElementMock.scroll).toBeCalledWith({ behavior: 'smooth', top: 420 });
     });
   });
 
@@ -480,6 +440,20 @@ describe('Logs', () => {
       expect(table).toBeInTheDocument();
     });
 
+    it('should use default state from localstorage - table', async () => {
+      localStorage.setItem(visualisationTypeKey, 'table');
+      setup({});
+      const table = await screen.findByTestId('logRowsTable');
+      expect(table).toBeInTheDocument();
+    });
+
+    it('should use default state from localstorage - logs', async () => {
+      localStorage.setItem(visualisationTypeKey, 'logs');
+      setup({});
+      const table = await screen.findByTestId('logRows');
+      expect(table).toBeInTheDocument();
+    });
+
     it('should change visualisation to table on toggle (elastic)', async () => {
       setup({}, getMockElasticFrame());
       const logsSection = screen.getByRole('radio', { name: 'Show results in table visualisation' });
@@ -498,7 +472,7 @@ const makeLog = (overrides: Partial<LogRowModel>): LogRowModel => {
     uid,
     entryFieldIndex: 0,
     rowIndex: 0,
-    dataFrame: new MutableDataFrame(),
+    dataFrame: createDataFrame({ fields: [] }),
     logLevel: LogLevel.debug,
     entry,
     hasAnsi: false,
