@@ -16,20 +16,20 @@ export const NoData = () => {
 };
 
 const getStyles = (theme: GrafanaTheme2) => ({
-  wrapper: css`
-    label: no-data-card;
-    padding: ${theme.spacing(3)};
-    background: ${theme.colors.background.primary};
-    border-radius: ${theme.shape.radius.default};
-    display: flex;
-    flex-direction: column;
-    align-items: center;
-    justify-content: center;
-    flex-grow: 1;
-  `,
-  message: css`
-    font-size: ${theme.typography.h2.fontSize};
-    padding: ${theme.spacing(4)};
-    color: ${theme.colors.text.disabled};
-  `,
+  wrapper: css({
+    label: 'no-data-card',
+    padding: theme.spacing(3),
+    background: theme.colors.background.primary,
+    borderRadius: theme.shape.radius.default,
+    display: 'flex',
+    flexDirection: 'column',
+    alignItems: 'center',
+    justifyContent: 'center',
+    flexGrow: 1,
+  }),
+  message: css({
+    fontSize: theme.typography.h2.fontSize,
+    padding: theme.spacing(4),
+    color: theme.colors.text.disabled,
+  }),
 });
