@@ -1,12 +1,21 @@
 import { css } from '@emotion/css';
 import React from 'react';
 
-import { LinkButton, CallToActionCard, Icon, useTheme2 } from '@grafana/ui';
+import { GrafanaTheme2 } from '@grafana/data';
+import { LinkButton, CallToActionCard, Icon, useStyles2 } from '@grafana/ui';
 import { contextSrv } from 'app/core/core';
 import { AccessControlAction } from 'app/types';
 
+function getCardStyles(theme: GrafanaTheme2) {
+  return css({
+    maxWidth: `${theme.breakpoints.values.lg}px`,
+    marginTop: theme.spacing(2),
+    alignSelf: 'center',
+  });
+}
+
 export const NoDataSourceCallToAction = () => {
-  const theme = useTheme2();
+  const cardStyles = useStyles2(getCardStyles);
 
   const canCreateDataSource =
     contextSrv.hasPermission(AccessControlAction.DataSourcesCreate) &&
@@ -35,13 +44,5 @@ export const NoDataSourceCallToAction = () => {
     </LinkButton>
   );
 
-  const cardClassName = css`
-    max-width: ${theme.breakpoints.values.lg}px;
-    margin-top: ${theme.spacing(2)};
-    align-self: center;
-  `;
-
-  return (
-    <CallToActionCard callToActionElement={ctaElement} className={cardClassName} footer={footer} message={message} />
-  );
+  return <CallToActionCard callToActionElement={ctaElement} className={cardStyles} footer={footer} message={message} />;
 };
