@@ -65,7 +65,7 @@ export const clearPanes = createAction('explore/clearPanes');
  */
 export const splitOpen = createAsyncThunk(
   'explore/splitOpen',
-  async (options: SplitOpenOptions | undefined, { getState, dispatch, requestId }) => {
+  async (options: SplitOpenOptions | undefined, { getState, dispatch }) => {
     // we currently support showing only 2 panes in explore, so if this action is dispatched we know it has been dispatched from the "first" pane.
     const originState = Object.values(getState().explore.panes)[0];
 
@@ -80,9 +80,15 @@ export const splitOpen = createAsyncThunk(
 
     const splitRange = options?.range || originState?.range.raw || DEFAULT_RANGE;
 
+    let newPaneId = generateExploreId();
+    // in case we have a duplicate id, generate a new one
+    while (getState().explore.panes[newPaneId]) {
+      newPaneId = generateExploreId();
+    }
+
     await dispatch(
       createNewSplitOpenPane({
-        exploreId: requestId,
+        exploreId: newPaneId,
         datasource: options?.datasourceUid || originState?.datasourceInstance?.getRef(),
         queries: withUniqueRefIds(queries),
         range: splitRange,
@@ -95,9 +101,6 @@ export const splitOpen = createAsyncThunk(
     if (originState?.range) {
       await dispatch(syncTimesAction({ syncedTimes: isEqual(originState.range.raw, splitRange) })); // if time ranges are equal, mark times as synced
     }
-  },
-  {
-    idGenerator: generateExploreId,
   }
 );
 
