@@ -130,6 +130,9 @@ export interface ExpressionQuery extends DataQuery {
   settings?: ExpressionQuerySettings;
 }
 
+export interface ThresholdExpressionQuery extends ExpressionQuery {
+  conditions: ClassicCondition[];
+}
 export interface ExpressionQuerySettings {
   mode?: ReducerMode;
   replaceWithValue?: number;
@@ -140,6 +143,10 @@ export interface ClassicCondition {
     params: number[];
     type: EvalFunction;
   };
+  unloadEvaluator?: {
+    params: number[];
+    type: EvalFunction;
+  };
   operator?: {
     type: string;
   };
