@@ -1,11 +1,5 @@
-import {
-  Field,
-  FieldType,
-  FrameGeometrySource,
-  FrameGeometrySourceMode,
-  PanelOptionsEditorBuilder,
-  DataFrame,
-} from '@grafana/data';
+import { Field, FieldType, PanelOptionsEditorBuilder, DataFrame } from '@grafana/data';
+import { FrameGeometrySource, FrameGeometrySourceMode } from '@grafana/schema';
 import { GazetteerPathEditor } from 'app/features/geo/editor/GazetteerPathEditor';
 
 import { LocationModeEditor } from './locationModeEditor';
