@@ -7,7 +7,7 @@ interface InspectMetadataTabProps {
   data: PanelData;
   metadataDatasource?: DataSourceApi;
 }
-export const InspectMetadataTab: React.FC<InspectMetadataTabProps> = ({ data, metadataDatasource }) => {
+export const InspectMetadataTab = ({ data, metadataDatasource }: InspectMetadataTabProps) => {
   if (!metadataDatasource || !metadataDatasource.components?.MetadataInspector) {
     return <Trans i18nKey="dashboard.inspect-meta.no-inspector">No Metadata Inspector</Trans>;
   }
