@@ -1,42 +1,48 @@
 import React, { useCallback, useEffect, useState } from 'react';
 import { useAsync, useDebounce } from 'react-use';
 
-import { isFetchError } from '@grafana/runtime';
+import { FetchError, isFetchError } from '@grafana/runtime';
 import { Button, Field, Input, Modal } from '@grafana/ui';
-import { FolderPicker } from 'app/core/components/Select/FolderPicker';
+import { OldFolderPicker } from 'app/core/components/Select/OldFolderPicker';
 import { t, Trans } from 'app/core/internationalization';
 
 import { PanelModel } from '../../../dashboard/state';
 import { getLibraryPanelByName } from '../../state/api';
+import { LibraryElementDTO } from '../../types';
 import { usePanelSave } from '../../utils/usePanelSave';
 
 interface AddLibraryPanelContentsProps {
-  onDismiss: () => void;
+  onDismiss?: () => void;
   panel: PanelModel;
-  initialFolderId?: number;
+  initialFolderUid?: string;
 }
 
-export const AddLibraryPanelContents = ({ panel, initialFolderId, onDismiss }: AddLibraryPanelContentsProps) => {
-  const [folderId, setFolderId] = useState(initialFolderId);
+export const AddLibraryPanelContents = ({ panel, initialFolderUid, onDismiss }: AddLibraryPanelContentsProps) => {
+  const [folderUid, setFolderUid] = useState(initialFolderUid);
   const [panelName, setPanelName] = useState(panel.title);
   const [debouncedPanelName, setDebouncedPanelName] = useState(panel.title);
   const [waiting, setWaiting] = useState(false);
 
+  console.log('folderUid', folderUid);
   useEffect(() => setWaiting(true), [panelName]);
   useDebounce(() => setDebouncedPanelName(panelName), 350, [panelName]);
 
   const { saveLibraryPanel } = usePanelSave();
+
   const onCreate = useCallback(() => {
     panel.libraryPanel = { uid: '', name: panelName };
-    saveLibraryPanel(panel, folderId!).then((res) => {
-      if (!(res instanceof Error)) {
-        onDismiss();
+    saveLibraryPanel(panel, folderUid!).then((res: LibraryElementDTO | FetchError) => {
+      if (!isFetchError(res)) {
+        onDismiss?.();
+      } else {
+        panel.libraryPanel = undefined;
       }
     });
-  }, [panel, panelName, folderId, onDismiss, saveLibraryPanel]);
+  }, [panel, panelName, folderUid, onDismiss, saveLibraryPanel]);
+
   const isValidName = useAsync(async () => {
     try {
-      return !(await getLibraryPanelByName(panelName)).some((lp) => lp.folderId === folderId);
+      return !(await getLibraryPanelByName(panelName)).some((lp) => lp.folderUid === folderUid);
     } catch (err) {
       if (isFetchError(err)) {
         err.isHandled = true;
@@ -45,8 +51,9 @@ export const AddLibraryPanelContents = ({ panel, initialFolderId, onDismiss }: A
     } finally {
       setWaiting(false);
     }
-  }, [debouncedPanelName, folderId]);
+  }, [debouncedPanelName, folderUid]);
 
+  console.log('isValidName:', isValidName);
   const invalidInput =
     !isValidName?.value && isValidName.value !== undefined && panelName === debouncedPanelName && !waiting;
 
@@ -71,9 +78,9 @@ export const AddLibraryPanelContents = ({ panel, initialFolderId, onDismiss }: A
           'Library panel permissions are derived from the folder permissions'
         )}
       >
-        <FolderPicker
-          onChange={({ id }) => setFolderId(id)}
-          initialFolderId={initialFolderId}
+        <OldFolderPicker
+          onChange={({ uid }) => setFolderUid(uid)}
+          initialFolderUid={initialFolderUid}
           inputId="share-panel-library-panel-folder-picker"
         />
       </Field>
@@ -94,10 +101,10 @@ interface Props extends AddLibraryPanelContentsProps {
   isOpen?: boolean;
 }
 
-export const AddLibraryPanelModal = ({ isOpen = false, panel, initialFolderId, ...props }: Props) => {
+export const AddLibraryPanelModal = ({ isOpen = false, panel, initialFolderUid, ...props }: Props) => {
   return (
     <Modal title="Create library panel" isOpen={isOpen} onDismiss={props.onDismiss}>
-      <AddLibraryPanelContents panel={panel} initialFolderId={initialFolderId} onDismiss={props.onDismiss} />
+      <AddLibraryPanelContents panel={panel} initialFolderUid={initialFolderUid} onDismiss={props.onDismiss} />
     </Modal>
   );
 };
