@@ -2,6 +2,8 @@ import React from 'react';
 
 import { PluginMeta } from '@grafana/data';
 import { Button } from '@grafana/ui';
+import { contextSrv } from 'app/core/core';
+import { AccessControlAction } from 'app/types';
 
 import { updatePluginSettings } from '../../api';
 import { usePluginConfig } from '../../hooks/usePluginConfig';
@@ -18,6 +20,11 @@ export function GetStartedWithApp({ plugin }: Props): React.ReactElement | null
     return null;
   }
 
+  // Enforce RBAC
+  if (!contextSrv.hasPermissionInMetadata(AccessControlAction.PluginsWrite, plugin)) {
+    return null;
+  }
+
   const { enabled, jsonData } = pluginConfig?.meta;
 
   const enable = () =>
