@@ -1,3 +1,5 @@
+import uFuzzy from '@leeoniya/ufuzzy';
+
 import { PluginSignatureStatus, dateTimeParse, PluginError, PluginType, PluginErrorCode } from '@grafana/data';
 import { config, featureEnabled } from '@grafana/runtime';
 import configCore, { Settings } from 'app/core/config';
@@ -47,7 +49,9 @@ export function mergeLocalsAndRemotes({
 
       // for managed instances, check if plugin is installed, but not yet present in the current instance
       if (configCore.featureToggles.managedPluginsInstall && config.pluginAdminExternalManageEnabled) {
-        catalogPlugin.isFullyInstalled = instancesSet.has(remotePlugin.slug) && catalogPlugin.isInstalled;
+        catalogPlugin.isFullyInstalled = catalogPlugin.isCore
+          ? true
+          : instancesSet.has(remotePlugin.slug) && catalogPlugin.isInstalled;
         catalogPlugin.isInstalled = instancesSet.has(remotePlugin.slug) || catalogPlugin.isInstalled;
       }
 
@@ -84,6 +88,7 @@ export function mapRemoteToCatalog(plugin: RemotePlugin, error?: PluginError): C
     createdAt: publishedAt,
     status,
     angularDetected,
+    keywords,
   } = plugin;
 
   const isDisabled = !!error || isDisabledSecretsPlugin(typeCode);
@@ -96,6 +101,7 @@ export function mapRemoteToCatalog(plugin: RemotePlugin, error?: PluginError): C
         small: `https://grafana.com/api/plugins/${id}/versions/${version}/logos/small`,
         large: `https://grafana.com/api/plugins/${id}/versions/${version}/logos/large`,
       },
+      keywords,
     },
     name,
     orgName,
@@ -121,7 +127,7 @@ export function mapRemoteToCatalog(plugin: RemotePlugin, error?: PluginError): C
 export function mapLocalToCatalog(plugin: LocalPlugin, error?: PluginError): CatalogPlugin {
   const {
     name,
-    info: { description, version, logos, updated, author },
+    info: { description, version, logos, updated, author, keywords },
     id,
     dev,
     type,
@@ -138,7 +144,7 @@ export function mapLocalToCatalog(plugin: LocalPlugin, error?: PluginError): Cat
     description,
     downloads: 0,
     id,
-    info: { logos },
+    info: { logos, keywords },
     name,
     orgName: author.name,
     popularity: 0,
@@ -161,6 +167,7 @@ export function mapLocalToCatalog(plugin: LocalPlugin, error?: PluginError): Cat
     accessControl: accessControl,
     angularDetected,
     isFullyInstalled: true,
+    iam: plugin.iam,
   };
 }
 
@@ -170,6 +177,7 @@ export function mapToCatalogPlugin(local?: LocalPlugin, remote?: RemotePlugin, e
   const id = remote?.slug || local?.id || '';
   const type = local?.type || remote?.typeCode;
   const isDisabled = !!error || isDisabledSecretsPlugin(type);
+  const keywords = remote?.keywords || local?.info.keywords || [];
 
   let logos = {
     small: `/public/img/icn-${type}.svg`,
@@ -192,6 +200,7 @@ export function mapToCatalogPlugin(local?: LocalPlugin, remote?: RemotePlugin, e
     id,
     info: {
       logos,
+      keywords,
     },
     isCore: Boolean(remote?.internal || local?.signature === PluginSignatureStatus.internal),
     isDev: Boolean(local?.dev),
@@ -218,6 +227,7 @@ export function mapToCatalogPlugin(local?: LocalPlugin, remote?: RemotePlugin, e
     accessControl: local?.accessControl,
     angularDetected: local?.angularDetected || remote?.angularDetected,
     isFullyInstalled: Boolean(local) || isDisabled,
+    iam: local?.iam,
   };
 }
 
@@ -341,3 +351,26 @@ function isDisabledSecretsPlugin(type?: PluginType): boolean {
 export function isLocalCorePlugin(local?: LocalPlugin): boolean {
   return Boolean(local?.signature === 'internal');
 }
+
+function getId(inputString: string): string {
+  const parts = inputString.split(' - ');
+  return parts[0];
+}
+
+function getPluginDetailsForFuzzySearch(plugins: CatalogPlugin[]): string[] {
+  return plugins.reduce((result: string[], { id, name, type, orgName, info }: CatalogPlugin) => {
+    const keywordsForSearch = info.keywords?.join(' ').toLowerCase();
+    const pluginString = `${id} - ${name} - ${type} - ${orgName} - ${keywordsForSearch}`;
+    result.push(pluginString);
+    return result;
+  }, []);
+}
+export function filterByKeyword(plugins: CatalogPlugin[], query: string) {
+  const dataArray = getPluginDetailsForFuzzySearch(plugins);
+  let uf = new uFuzzy({});
+  let idxs = uf.filter(dataArray, query);
+  if (idxs === null) {
+    return null;
+  }
+  return idxs.map((id) => getId(dataArray[id]));
+}
