@@ -62,6 +62,7 @@ export interface CatalogPlugin extends WithAccessControlMetadata {
   // instance plugins may not be fully installed, which means a new instance
   // running the plugin didn't started yet
   isFullyInstalled?: boolean;
+  iam?: IdentityAccessManagement;
 }
 
 export interface CatalogPluginDetails {
@@ -74,6 +75,7 @@ export interface CatalogPluginDetails {
   grafanaDependency?: string;
   pluginDependencies?: PluginDependencies['plugins'];
   statusContext?: string;
+  iam?: IdentityAccessManagement;
 }
 
 export interface CatalogPluginInfo {
@@ -81,6 +83,7 @@ export interface CatalogPluginInfo {
     large: string;
     small: string;
   };
+  keywords: string[];
 }
 
 export type RemotePlugin = {
@@ -91,8 +94,10 @@ export type RemotePlugin = {
   featured: number;
   id: number;
   internal: boolean;
+  keywords: string[];
   json?: {
     dependencies: PluginDependencies;
+    iam?: IdentityAccessManagement;
     info: {
       links: Array<{
         name: string;
@@ -158,6 +163,7 @@ export type LocalPlugin = WithAccessControlMetadata & {
       small: string;
       large: string;
     };
+    keywords: string[];
     build: Build;
     screenshots?: Array<{
       path: string;
@@ -175,8 +181,18 @@ export type LocalPlugin = WithAccessControlMetadata & {
   type: PluginType;
   dependencies: PluginDependencies;
   angularDetected: boolean;
+  iam?: IdentityAccessManagement;
 };
 
+interface IdentityAccessManagement {
+  permissions: Permission[];
+}
+
+export interface Permission {
+  action: string;
+  scope: string;
+}
+
 interface Rel {
   name: string;
   url: string;
@@ -231,6 +247,7 @@ export enum PluginTabLabels {
   CONFIG = 'Config',
   DASHBOARDS = 'Dashboards',
   USAGE = 'Usage',
+  IAM = 'IAM',
 }
 
 export enum PluginTabIds {
@@ -239,6 +256,7 @@ export enum PluginTabIds {
   CONFIG = 'config',
   DASHBOARDS = 'dashboards',
   USAGE = 'usage',
+  IAM = 'iam',
 }
 
 export enum RequestStatus {
