@@ -28,3 +28,15 @@ export function buildImportMap(importMap: Record<string, System.Module>) {
 export function isHostedOnCDN(path: string) {
   return Boolean(config.pluginsCDNBaseURL) && path.startsWith(config.pluginsCDNBaseURL);
 }
+
+// This function is used to dynamically prepend the appSubUrl in the frontend.
+// This is required because if serve_from_sub_path is false the Image Renderer sets the subpath
+// to an empty string and sets appurl to localhost which causes plugins to fail to load.
+// https://github.com/grafana/grafana/issues/76180
+export function resolveModulePath(path: string) {
+  if (path.startsWith('http') || path.startsWith('/')) {
+    return path;
+  }
+
+  return `${config.appSubUrl ?? ''}/${path}`;
+}
