@@ -87,6 +87,32 @@ export function markDomElementStyleAsALiveTarget(el: Element) {
   }
 }
 
+export function recursivePatchObjectAsLiveTarget(obj: unknown) {
+  if (!obj) {
+    return;
+  }
+  if (Array.isArray(obj)) {
+    obj.forEach(recursivePatchObjectAsLiveTarget);
+    unconditionallyPatchObjectAsLiveTarget(obj);
+  } else if (typeof obj === 'object') {
+    Object.values(obj).forEach(recursivePatchObjectAsLiveTarget);
+    unconditionallyPatchObjectAsLiveTarget(obj);
+  }
+}
+
+function unconditionallyPatchObjectAsLiveTarget(obj: unknown) {
+  if (!obj) {
+    return;
+  }
+  // do not patch it twice
+  if (Object.hasOwn(obj, SANDBOX_LIVE_VALUE)) {
+    return obj;
+  }
+
+  Reflect.defineProperty(obj, SANDBOX_LIVE_VALUE, {});
+  return obj;
+}
+
 /**
  * Some specific near membrane proxies interfere with plugins
  * an example of this is React class components state and their fast life cycles
