@@ -2,4 +2,4 @@
  * Map with all dependencies that are exposed to plugins sandbox
  * e.g.: @grafana/ui, @grafana/data, etc...
  */
-export const sandboxPluginDependencies = new Map<string, unknown>([]);
+export const sandboxPluginDependencies = new Map<string, System.Module>([]);
