@@ -1,7 +1,19 @@
-import { PanelData } from '@grafana/data';
+import { PanelData, RawTimeRange } from '@grafana/data';
 import { getDashboardSrv } from 'app/features/dashboard/services/DashboardSrv';
 import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 
+import { DashboardModel } from '../dashboard/state';
+
+declare global {
+  interface Window {
+    grafanaRuntime?: {
+      getDashboardSaveModel: () => DashboardModel | undefined;
+      getDashboardTimeRange: () => { from: number; to: number; raw: RawTimeRange };
+      getPanelData: () => Record<number, PanelData | undefined> | undefined;
+    };
+  }
+}
+
 /**
  * This will setup features that are accessible through the root window location
  *
@@ -10,14 +22,14 @@ import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
  * @internal and subject to change
  */
 export function initWindowRuntime() {
-  (window as any).grafanaRuntime = {
+  window.grafanaRuntime = {
     /** Get info for the current dashboard.  This will include the migrated dashboard JSON */
     getDashboardSaveModel: () => {
       const d = getDashboardSrv().getCurrent();
       if (!d) {
         return undefined;
       }
-      return d.getSaveModelClone();
+      return d.getSaveModelCloneOld();
     },
 
     /** The selected time range */
@@ -36,10 +48,10 @@ export function initWindowRuntime() {
       if (!d) {
         return undefined;
       }
-      return d.panels.reduce((acc, panel) => {
+      return d.panels.reduce<Record<number, PanelData | undefined>>((acc, panel) => {
         acc[panel.id] = panel.getQueryRunner().getLastResult();
         return acc;
-      }, {} as Record<number, PanelData | undefined>);
+      }, {});
     },
   };
 }
