@@ -1,8 +1,9 @@
-import React, { useState } from 'react';
+import React, { JSX, useState } from 'react';
+import { useForm } from 'react-hook-form';
 
 import { NavModelItem } from '@grafana/data';
 import { getBackendSrv, locationService } from '@grafana/runtime';
-import { Button, Form, Field, Input, FieldSet } from '@grafana/ui';
+import { Button, Field, Input, FieldSet } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { TeamRolePicker } from 'app/core/components/RolePicker/TeamRolePicker';
 import { updateTeamRoles } from 'app/core/components/RolePicker/api';
@@ -21,7 +22,11 @@ export const CreateTeam = (): JSX.Element => {
   const currentOrgId = contextSrv.user.orgId;
   const [pendingRoles, setPendingRoles] = useState<Role[]>([]);
   const [{ roleOptions }] = useRoleOptions(currentOrgId);
-
+  const {
+    handleSubmit,
+    register,
+    formState: { errors },
+  } = useForm<TeamDTO>();
   const canUpdateRoles =
     contextSrv.hasPermission(AccessControlAction.ActionUserRolesAdd) &&
     contextSrv.hasPermission(AccessControlAction.ActionUserRolesRemove);
@@ -44,39 +49,36 @@ export const CreateTeam = (): JSX.Element => {
   return (
     <Page navId="teams" pageNav={pageNav}>
       <Page.Contents>
-        <Form onSubmit={createTeam}>
-          {({ register, errors }) => (
-            <FieldSet>
-              <Field label="Name" required invalid={!!errors.name} error="Team name is required">
-                <Input {...register('name', { required: true })} id="team-name" />
+        <form onSubmit={handleSubmit(createTeam)} style={{ maxWidth: '600px' }}>
+          <FieldSet>
+            <Field label="Name" required invalid={!!errors.name} error="Team name is required">
+              <Input {...register('name', { required: true })} id="team-name" />
+            </Field>
+            {contextSrv.licensedAccessControlEnabled() && (
+              <Field label="Role">
+                <TeamRolePicker
+                  teamId={0}
+                  roleOptions={roleOptions}
+                  disabled={false}
+                  apply={true}
+                  onApplyRoles={setPendingRoles}
+                  pendingRoles={pendingRoles}
+                  maxWidth="100%"
+                />
               </Field>
-              {contextSrv.licensedAccessControlEnabled() && (
-                <Field label="Role">
-                  <TeamRolePicker
-                    teamId={0}
-                    roleOptions={roleOptions}
-                    disabled={false}
-                    apply={true}
-                    onApplyRoles={setPendingRoles}
-                    pendingRoles={pendingRoles}
-                    maxWidth="100%"
-                  />
-                </Field>
-              )}
-              <Field
-                label={'Email'}
-                description={'This is optional and is primarily used for allowing custom team avatars.'}
-              >
-                <Input {...register('email')} type="email" id="team-email" placeholder="email@test.com" />
-              </Field>
-              <div className="gf-form-button-row">
-                <Button type="submit" variant="primary">
-                  Create
-                </Button>
-              </div>
-            </FieldSet>
-          )}
-        </Form>
+            )}
+            <Field
+              label={'Email'}
+              description={'This is optional and is primarily used for allowing custom team avatars.'}
+            >
+              <Input {...register('email')} type="email" id="team-email" placeholder="email@test.com" />
+            </Field>
+          </FieldSet>
+
+          <Button type="submit" variant="primary">
+            Create
+          </Button>
+        </form>
       </Page.Contents>
     </Page>
   );
