@@ -14,15 +14,17 @@ import { createOrderFieldsComparer } from '@grafana/data/src/transformations/tra
 import { OrganizeFieldsTransformerOptions } from '@grafana/data/src/transformations/transformers/organize';
 import { Input, IconButton, Icon, FieldValidationMessage, useStyles2 } from '@grafana/ui';
 
+import { getTransformationContent } from '../docs/getTransformationContent';
 import { useAllFieldNamesFromDataFrames } from '../utils';
 
 interface OrganizeFieldsTransformerEditorProps extends TransformerUIProps<OrganizeFieldsTransformerOptions> {}
 
 const OrganizeFieldsTransformerEditor = ({ options, input, onChange }: OrganizeFieldsTransformerEditorProps) => {
-  const { indexByName, excludeByName, renameByName } = options;
+  const { indexByName, excludeByName, renameByName, includeByName } = options;
 
   const fieldNames = useAllFieldNamesFromDataFrames(input);
   const orderedFieldNames = useMemo(() => orderFieldNamesByIndex(fieldNames, indexByName), [fieldNames, indexByName]);
+  const filterType = includeByName && Object.keys(includeByName).length > 0 ? 'include' : 'exclude';
 
   const onToggleVisibility = useCallback(
     (field: string, shouldExclude: boolean) => {
@@ -37,6 +39,20 @@ const OrganizeFieldsTransformerEditor = ({ options, input, onChange }: OrganizeF
     [onChange, options, excludeByName]
   );
 
+  const onToggleVisibilityInclude = useCallback(
+    (field: string, shouldInclude: boolean) => {
+      const pendingState = {
+        ...options,
+        includeByName: {
+          ...includeByName,
+          [field]: !shouldInclude,
+        },
+      };
+      onChange(pendingState);
+    },
+    [onChange, options, includeByName]
+  );
+
   const onDragEnd = useCallback(
     (result: DropResult) => {
       if (!result || !result.destination) {
@@ -87,14 +103,18 @@ const OrganizeFieldsTransformerEditor = ({ options, input, onChange }: OrganizeF
         {(provided) => (
           <div ref={provided.innerRef} {...provided.droppableProps}>
             {orderedFieldNames.map((fieldName, index) => {
+              const isIncludeFilter = includeByName && fieldName in includeByName ? includeByName[fieldName] : false;
+              const isVisible = filterType === 'include' ? isIncludeFilter : !excludeByName[fieldName];
+              const onToggleFunction = filterType === 'include' ? onToggleVisibilityInclude : onToggleVisibility;
+
               return (
                 <DraggableFieldName
                   fieldName={fieldName}
                   renamedFieldName={renameByName[fieldName]}
                   index={index}
-                  onToggleVisibility={onToggleVisibility}
+                  onToggleVisibility={onToggleFunction}
                   onRenameField={onRenameField}
-                  visible={!excludeByName[fieldName]}
+                  visible={isVisible}
                   key={fieldName}
                 />
               );
@@ -134,13 +154,9 @@ const DraggableFieldName = ({
         <div className="gf-form-inline" ref={provided.innerRef} {...provided.draggableProps}>
           <div className="gf-form gf-form--grow">
             <div className="gf-form-label gf-form-label--justify-left width-30">
-              <Icon
-                name="draggabledots"
-                title="Drag and drop to reorder"
-                size="lg"
-                className={styles.draggable}
-                {...provided.dragHandleProps}
-              />
+              <span {...provided.dragHandleProps}>
+                <Icon name="draggabledots" title="Drag and drop to reorder" size="lg" className={styles.draggable} />
+              </span>
               <IconButton
                 className={styles.toggle}
                 size="md"
@@ -192,13 +208,10 @@ const reorderToIndex = (fieldNames: string[], startIndex: number, endIndex: numb
   const [removed] = result.splice(startIndex, 1);
   result.splice(endIndex, 0, removed);
 
-  return result.reduce(
-    (nameByIndex, fieldName, index) => {
-      nameByIndex[fieldName] = index;
-      return nameByIndex;
-    },
-    {} as Record<string, number>
-  );
+  return result.reduce<Record<string, number>>((nameByIndex, fieldName, index) => {
+    nameByIndex[fieldName] = index;
+    return nameByIndex;
+  }, {});
 };
 
 const orderFieldNamesByIndex = (fieldNames: string[], indexByName: Record<string, number> = {}): string[] => {
@@ -213,8 +226,9 @@ export const organizeFieldsTransformRegistryItem: TransformerRegistryItem<Organi
   id: DataTransformerID.organize,
   editor: OrganizeFieldsTransformerEditor,
   transformation: standardTransformers.organizeFieldsTransformer,
-  name: 'Organize fields',
+  name: standardTransformers.organizeFieldsTransformer.name,
   description:
     "Allows the user to re-order, hide, or rename fields / columns. Useful when data source doesn't allow overrides for visualizing data.",
   categories: new Set([TransformerCategory.ReorderAndRename]),
+  help: getTransformationContent(DataTransformerID.organize).helperDocs,
 };
