@@ -11,10 +11,12 @@ import {
   TransformerUIProps,
   TransformerCategory,
 } from '@grafana/data';
-import { FrameGeometrySource, FrameGeometrySourceMode } from '@grafana/schema';
+import { FrameGeometrySourceMode } from '@grafana/schema';
 import { useTheme2 } from '@grafana/ui';
 import { addLocationFields } from 'app/features/geo/editor/locationEditor';
 
+import { getTransformationContent } from '../docs/getTransformationContent';
+
 import { SpatialCalculation, SpatialOperation, SpatialAction, SpatialTransformOptions } from './models.gen';
 import { getDefaultOptions, getTransformerOptionPane } from './optionsHelper';
 import { isLineBuilderOption, spatialTransformer } from './spatialTransformer';
@@ -90,10 +92,9 @@ const supplier = (
       category: ['Source'],
       path: 'source',
       build: (b, c) => {
-        const loc = (options.source ?? {}) as FrameGeometrySource;
-        if (!loc.mode) {
-          loc.mode = FrameGeometrySourceMode.Auto;
-        }
+        const loc = options.source ?? {
+          mode: FrameGeometrySourceMode.Auto,
+        };
         addLocationFields('Point', '', b, loc);
       },
     });
@@ -102,10 +103,9 @@ const supplier = (
       category: ['Target'],
       path: 'modify',
       build: (b, c) => {
-        const loc = (options.modify?.target ?? {}) as FrameGeometrySource;
-        if (!loc.mode) {
-          loc.mode = FrameGeometrySourceMode.Auto;
-        }
+        const loc = options.modify?.target ?? {
+          mode: FrameGeometrySourceMode.Auto,
+        };
         addLocationFields('Point', 'target.', b, loc);
       },
     });
@@ -167,4 +167,5 @@ export const spatialTransformRegistryItem: TransformerRegistryItem<SpatialTransf
   description: spatialTransformer.description,
   state: PluginState.alpha,
   categories: new Set([TransformerCategory.PerformSpatialOperations]),
+  help: getTransformationContent(DataTransformerID.spatial).helperDocs,
 };
