@@ -7,7 +7,7 @@ import { configureStore } from 'app/store/configureStore';
 import { Invitee, OrgUser } from 'app/types';
 
 import { Props, UsersListPageUnconnected } from './UsersListPage';
-import { pageChanged } from './state/reducers';
+import { pageChanged, sortChanged } from './state/reducers';
 
 jest.mock('../../core/app_events', () => ({
   emit: jest.fn(),
@@ -16,7 +16,7 @@ jest.mock('../../core/app_events', () => ({
 jest.mock('app/core/core', () => ({
   contextSrv: {
     user: { orgId: 1 },
-    hasAccess: () => false,
+    hasPermission: () => false,
     licensedAccessControlEnabled: () => false,
   },
 }));
@@ -36,7 +36,9 @@ const setup = (propOverrides?: object) => {
     updateUser: jest.fn(),
     removeUser: jest.fn(),
     changePage: mockToolkitActionCreator(pageChanged),
+    changeSort: mockToolkitActionCreator(sortChanged),
     isLoading: false,
+    rolesLoading: false,
   };
 
   Object.assign(props, propOverrides);
