@@ -1,7 +1,8 @@
 import React from 'react';
 
-import { DataSourceRef, MetricFindValue, SelectableValue } from '@grafana/data';
+import { AdHocVariableFilter, DataSourceRef, MetricFindValue, SelectableValue } from '@grafana/data';
 import { SegmentAsync } from '@grafana/ui';
+import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 
 import { getDatasourceSrv } from '../../../plugins/datasource_srv';
 
@@ -12,10 +13,19 @@ interface Props {
   onChange: (item: SelectableValue<string>) => void;
   placeHolder?: string;
   disabled?: boolean;
+  allFilters: AdHocVariableFilter[];
 }
 
-export const AdHocFilterValue = ({ datasource, disabled, onChange, filterKey, filterValue, placeHolder }: Props) => {
-  const loadValues = () => fetchFilterValues(datasource, filterKey);
+export const AdHocFilterValue = ({
+  datasource,
+  disabled,
+  onChange,
+  filterKey,
+  filterValue,
+  placeHolder,
+  allFilters,
+}: Props) => {
+  const loadValues = () => fetchFilterValues(datasource, filterKey, allFilters);
 
   return (
     <div className="gf-form" data-testid="AdHocFilterValue-value-wrapper">
@@ -31,13 +41,20 @@ export const AdHocFilterValue = ({ datasource, disabled, onChange, filterKey, fi
   );
 };
 
-const fetchFilterValues = async (datasource: DataSourceRef, key: string): Promise<Array<SelectableValue<string>>> => {
+const fetchFilterValues = async (
+  datasource: DataSourceRef,
+  key: string,
+  allFilters: AdHocVariableFilter[]
+): Promise<Array<SelectableValue<string>>> => {
   const ds = await getDatasourceSrv().get(datasource);
 
   if (!ds || !ds.getTagValues) {
     return [];
   }
 
-  const metrics = await ds.getTagValues({ key });
+  const timeRange = getTimeSrv().timeRange();
+  // Filter out the current filter key from the list of all filters
+  const otherFilters = allFilters.filter((f) => f.key !== key);
+  const metrics = await ds.getTagValues({ key, filters: otherFilters, timeRange });
   return metrics.map((m: MetricFindValue) => ({ label: m.text, value: m.text }));
 };
