@@ -1,4 +1,4 @@
-import { TypedVariableModel, VariableSupportType, VariableType } from '@grafana/data';
+import { DataSourceApi, TypedVariableModel, VariableSupportType, VariableType } from '@grafana/data';
 
 import { LegacyVariableQueryEditor } from './editor/LegacyVariableQueryEditor';
 import { StandardVariableQueryEditor } from './editor/getVariableQueryEditor';
@@ -19,6 +19,7 @@ import {
   createCustomVariable,
   createDashboardVariable,
   createDatasourceVariable,
+  createGroupByVariable,
   createIntervalVariable,
   createOrgVariable,
   createQueryVariable,
@@ -30,21 +31,21 @@ describe('type guards', () => {
   describe('hasLegacyVariableSupport', () => {
     describe('when called with a legacy data source', () => {
       it('should return true', () => {
-        const datasource: any = { metricFindQuery: () => undefined };
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
         expect(hasLegacyVariableSupport(datasource)).toBe(true);
       });
     });
 
     describe('when called with data source without metricFindQuery function', () => {
       it('should return false', () => {
-        const datasource: any = {};
+        const datasource = {} as DataSourceApi;
         expect(hasLegacyVariableSupport(datasource)).toBe(false);
       });
     });
 
     describe('when called with a legacy data source with variable support', () => {
       it('should return false', () => {
-        const datasource: any = { metricFindQuery: () => undefined, variables: {} };
+        const datasource = { metricFindQuery: () => undefined, variables: {} } as unknown as DataSourceApi;
         expect(hasLegacyVariableSupport(datasource)).toBe(false);
       });
     });
@@ -53,23 +54,23 @@ describe('type guards', () => {
   describe('hasStandardVariableSupport', () => {
     describe('when called with a data source with standard variable support', () => {
       it('should return true', () => {
-        const datasource: any = {
+        const datasource = {
           metricFindQuery: () => undefined,
           variables: { getType: () => VariableSupportType.Standard, toDataQuery: () => undefined },
-        };
+        } as unknown as DataSourceApi;
         expect(hasStandardVariableSupport(datasource)).toBe(true);
       });
 
       describe('and with a custom query', () => {
         it('should return true', () => {
-          const datasource: any = {
+          const datasource = {
             metricFindQuery: () => undefined,
             variables: {
               getType: () => VariableSupportType.Standard,
               toDataQuery: () => undefined,
               query: () => undefined,
             },
-          };
+          } as unknown as DataSourceApi;
           expect(hasStandardVariableSupport(datasource)).toBe(true);
         });
       });
@@ -77,17 +78,17 @@ describe('type guards', () => {
 
     describe('when called with a data source with partial standard variable support', () => {
       it('should return false', () => {
-        const datasource: any = {
+        const datasource = {
           metricFindQuery: () => undefined,
           variables: { getType: () => VariableSupportType.Standard, query: () => undefined },
-        };
+        } as unknown as DataSourceApi;
         expect(hasStandardVariableSupport(datasource)).toBe(false);
       });
     });
 
     describe('when called with a data source without standard variable support', () => {
       it('should return false', () => {
-        const datasource: any = { metricFindQuery: () => undefined };
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
         expect(hasStandardVariableSupport(datasource)).toBe(false);
       });
     });
@@ -96,37 +97,37 @@ describe('type guards', () => {
   describe('hasCustomVariableSupport', () => {
     describe('when called with a data source with custom variable support', () => {
       it('should return true', () => {
-        const datasource: any = {
+        const datasource = {
           metricFindQuery: () => undefined,
           variables: { getType: () => VariableSupportType.Custom, query: () => undefined, editor: {} },
-        };
+        } as unknown as DataSourceApi;
         expect(hasCustomVariableSupport(datasource)).toBe(true);
       });
     });
 
     describe('when called with a data source with custom variable support but without editor', () => {
       it('should return false', () => {
-        const datasource: any = {
+        const datasource = {
           metricFindQuery: () => undefined,
           variables: { getType: () => VariableSupportType.Custom, query: () => undefined },
-        };
+        } as unknown as DataSourceApi;
         expect(hasCustomVariableSupport(datasource)).toBe(false);
       });
     });
 
     describe('when called with a data source with custom variable support but without query', () => {
       it('should return false', () => {
-        const datasource: any = {
+        const datasource = {
           metricFindQuery: () => undefined,
           variables: { getType: () => VariableSupportType.Custom, editor: {} },
-        };
+        } as unknown as DataSourceApi;
         expect(hasCustomVariableSupport(datasource)).toBe(false);
       });
     });
 
     describe('when called with a data source without custom variable support', () => {
       it('should return false', () => {
-        const datasource: any = { metricFindQuery: () => undefined };
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
         expect(hasCustomVariableSupport(datasource)).toBe(false);
       });
     });
@@ -135,17 +136,17 @@ describe('type guards', () => {
   describe('hasDatasourceVariableSupport', () => {
     describe('when called with a data source with datasource variable support', () => {
       it('should return true', () => {
-        const datasource: any = {
+        const datasource = {
           metricFindQuery: () => undefined,
           variables: { getType: () => VariableSupportType.Datasource },
-        };
+        } as unknown as DataSourceApi;
         expect(hasDatasourceVariableSupport(datasource)).toBe(true);
       });
     });
 
     describe('when called with a data source without datasource variable support', () => {
       it('should return false', () => {
-        const datasource: any = { metricFindQuery: () => undefined };
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
         expect(hasDatasourceVariableSupport(datasource)).toBe(false);
       });
     });
@@ -164,6 +165,7 @@ describe('type guards', () => {
   const variableFactsObj: Record<VariableType | ExtraVariableTypes, VariableFacts> = {
     query:      { variable: createQueryVariable(),      isMulti: true,  hasOptions: true,  hasCurrent: true },
     adhoc:      { variable: createAdhocVariable(),      isMulti: false, hasOptions: false, hasCurrent: false },
+    groupby:    { variable: createGroupByVariable(),    isMulti: true,  hasOptions: true, hasCurrent: true },
     constant:   { variable: createConstantVariable(),   isMulti: false, hasOptions: true,  hasCurrent: true },
     datasource: { variable: createDatasourceVariable(), isMulti: true,  hasOptions: true,  hasCurrent: true },
     interval:   { variable: createIntervalVariable(),   isMulti: false, hasOptions: true,  hasCurrent: true },
@@ -203,8 +205,8 @@ describe('isLegacyQueryEditor', () => {
   describe('happy cases', () => {
     describe('when called with a legacy query editor but without a legacy data source', () => {
       it('then is should return true', () => {
-        const component: any = LegacyVariableQueryEditor;
-        const datasource: any = {};
+        const component = LegacyVariableQueryEditor;
+        const datasource = {} as DataSourceApi;
 
         expect(isLegacyQueryEditor(component, datasource)).toBe(true);
       });
@@ -212,8 +214,8 @@ describe('isLegacyQueryEditor', () => {
 
     describe('when called with a legacy data source but without a legacy query editor', () => {
       it('then is should return true', () => {
-        const component: any = StandardVariableQueryEditor;
-        const datasource: any = { metricFindQuery: () => undefined };
+        const component = StandardVariableQueryEditor;
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
 
         expect(isLegacyQueryEditor(component, datasource)).toBe(true);
       });
@@ -223,8 +225,8 @@ describe('isLegacyQueryEditor', () => {
   describe('negative cases', () => {
     describe('when called without component', () => {
       it('then is should return false', () => {
-        const component: any = null;
-        const datasource: any = { metricFindQuery: () => undefined };
+        const component = null;
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
 
         expect(isLegacyQueryEditor(component, datasource)).toBe(false);
       });
@@ -232,8 +234,8 @@ describe('isLegacyQueryEditor', () => {
 
     describe('when called without a legacy query editor and without a legacy data source', () => {
       it('then is should return false', () => {
-        const component: any = StandardVariableQueryEditor;
-        const datasource: any = {};
+        const component = StandardVariableQueryEditor;
+        const datasource = {} as unknown as DataSourceApi;
 
         expect(isLegacyQueryEditor(component, datasource)).toBe(false);
       });
@@ -245,10 +247,10 @@ describe('isQueryEditor', () => {
   describe('happy cases', () => {
     describe('when called without a legacy editor and with a data source with standard variable support', () => {
       it('then is should return true', () => {
-        const component: any = StandardVariableQueryEditor;
-        const datasource: any = {
+        const component = StandardVariableQueryEditor;
+        const datasource = {
           variables: { getType: () => VariableSupportType.Standard, toDataQuery: () => undefined },
-        };
+        } as unknown as DataSourceApi;
 
         expect(isQueryEditor(component, datasource)).toBe(true);
       });
@@ -256,10 +258,10 @@ describe('isQueryEditor', () => {
 
     describe('when called without a legacy editor and with a data source with custom variable support', () => {
       it('then is should return true', () => {
-        const component: any = StandardVariableQueryEditor;
-        const datasource: any = {
+        const component = StandardVariableQueryEditor;
+        const datasource = {
           variables: { getType: () => VariableSupportType.Custom, query: () => undefined, editor: {} },
-        };
+        } as unknown as DataSourceApi;
 
         expect(isQueryEditor(component, datasource)).toBe(true);
       });
@@ -267,8 +269,8 @@ describe('isQueryEditor', () => {
 
     describe('when called without a legacy editor and with a data source with datasource variable support', () => {
       it('then is should return true', () => {
-        const component: any = StandardVariableQueryEditor;
-        const datasource: any = { variables: { getType: () => VariableSupportType.Datasource } };
+        const component = StandardVariableQueryEditor;
+        const datasource = { variables: { getType: () => VariableSupportType.Datasource } } as unknown as DataSourceApi;
 
         expect(isQueryEditor(component, datasource)).toBe(true);
       });
@@ -278,8 +280,8 @@ describe('isQueryEditor', () => {
   describe('negative cases', () => {
     describe('when called without component', () => {
       it('then is should return false', () => {
-        const component: any = null;
-        const datasource: any = { metricFindQuery: () => undefined };
+        const component = null;
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
 
         expect(isQueryEditor(component, datasource)).toBe(false);
       });
@@ -287,8 +289,8 @@ describe('isQueryEditor', () => {
 
     describe('when called with a legacy query editor', () => {
       it('then is should return false', () => {
-        const component: any = LegacyVariableQueryEditor;
-        const datasource: any = { variables: { getType: () => VariableSupportType.Datasource } };
+        const component = LegacyVariableQueryEditor;
+        const datasource = { variables: { getType: () => VariableSupportType.Datasource } } as unknown as DataSourceApi;
 
         expect(isQueryEditor(component, datasource)).toBe(false);
       });
@@ -296,8 +298,8 @@ describe('isQueryEditor', () => {
 
     describe('when called without a legacy query editor but with a legacy data source', () => {
       it('then is should return false', () => {
-        const component: any = StandardVariableQueryEditor;
-        const datasource: any = { metricFindQuery: () => undefined };
+        const component = StandardVariableQueryEditor;
+        const datasource = { metricFindQuery: () => undefined } as unknown as DataSourceApi;
 
         expect(isQueryEditor(component, datasource)).toBe(false);
       });
