@@ -7,6 +7,7 @@ import { useMediaQueryChange } from 'app/core/hooks/useMediaQueryChange';
 interface Props {
   onChange: (option: VariableRefresh) => void;
   refresh: VariableRefresh;
+  testId?: string;
 }
 
 const REFRESH_OPTIONS = [
@@ -14,7 +15,7 @@ const REFRESH_OPTIONS = [
   { label: 'On time range change', value: VariableRefresh.onTimeRangeChanged },
 ];
 
-export function QueryVariableRefreshSelect({ onChange, refresh }: PropsWithChildren<Props>) {
+export function QueryVariableRefreshSelect({ onChange, refresh, testId }: PropsWithChildren<Props>) {
   const theme = useTheme2();
 
   const [isSmallScreen, setIsSmallScreen] = useState(false);
@@ -31,7 +32,7 @@ export function QueryVariableRefreshSelect({ onChange, refresh }: PropsWithChild
   );
 
   return (
-    <Field label="Refresh" description="When to update the values of this variable">
+    <Field label="Refresh" description="When to update the values of this variable" data-testid={testId}>
       <RadioButtonGroup
         options={REFRESH_OPTIONS}
         onChange={onChange}
