@@ -131,7 +131,7 @@ describe('processVariable', () => {
 
           expect(dispatchedActions[0]).toEqual(toKeyedAction(key, variableStateFetching(toVariablePayload(custom))));
           expect(dispatchedActions[1]).toEqual(
-            toKeyedAction(key, createCustomOptionsFromQuery(toVariablePayload(custom)))
+            toKeyedAction(key, createCustomOptionsFromQuery(toVariablePayload(custom, 'A,B,C')))
           );
           expect(dispatchedActions[2].type).toEqual('templating/keyed/shared/setCurrentVariableValue');
           expect(dispatchedActions[3]).toEqual(toKeyedAction(key, variableStateCompleted(toVariablePayload(custom))));
