@@ -71,7 +71,7 @@ export type GrafanaManagedReceiverConfig = {
   disableResolveMessage: boolean;
   secureFields?: Record<string, boolean>;
   secureSettings?: Record<string, any>;
-  settings: Record<string, any>;
+  settings?: Record<string, any>; // sometimes settings are optional for security reasons (RBAC)
   type: string;
   name: string;
   updated?: string;
@@ -99,7 +99,7 @@ export type Receiver = GrafanaManagedContactPoint | AlertmanagerReceiver;
 export type ObjectMatcher = [name: string, operator: MatcherOperator, value: string];
 
 export type Route = {
-  receiver?: string;
+  receiver?: string | null;
   group_by?: string[];
   continue?: boolean;
   object_matchers?: ObjectMatcher[];
