@@ -424,135 +424,236 @@ export const multiResourceCompatibleTypes: { [ns: string]: boolean } = {
 };
 
 export const resourceTypes = [
+  'microsoft.aad/domainservices',
+  'microsoft.aadiam/azureadmetrics',
   'microsoft.analysisservices/servers',
   'microsoft.apimanagement/service',
-  'microsoft.network/applicationgateways',
-  'microsoft.insights/components',
-  'microsoft.web/hostingenvironments',
-  'microsoft.web/serverfarms',
-  'microsoft.web/sites',
-  'microsoft.automation/automationaccounts',
-  'microsoft.aad/domainservices',
-  'microsoft.botservice/botservices',
+  'microsoft.app/containerapps',
+  'microsoft.app/managedenvironments',
+  'microsoft.appconfiguration/configurationstores',
   'microsoft.appplatform/spring',
-  'microsoft.dataprotection/backupvaults',
-  'microsoft.network/bastionhosts',
+  'microsoft.automation/automationaccounts',
+  'microsoft.avs/privateclouds',
+  'microsoft.azuresphere/catalogs',
+  'microsoft.azurestackhci/clusters',
+  'microsoft.azurestackresourcemonitor/storageaccountmonitor',
   'microsoft.batch/batchaccounts',
   'microsoft.batchai/workspaces',
-  'microsoft.cdn/profiles',
+  'microsoft.bing/accounts',
+  'microsoft.botservice/botservices',
+  'microsoft.botservice/botservices/channels',
+  'microsoft.botservice/botservices/connections',
+  'microsoft.botservice/checknameavailability',
+  'microsoft.botservice/hostsettings',
+  'microsoft.botservice/listauthserviceproviders',
+  'microsoft.botservice/listqnamakerendpointkeys',
+  'microsoft.cache/redis',
+  'microsoft.cache/redisenterprise',
   'microsoft.cdn/cdnwebapplicationfirewallpolicies',
+  'microsoft.cdn/profiles',
   'microsoft.classiccompute/domainnames',
+  'microsoft.classiccompute/domainnames/slots/roles',
   'microsoft.classiccompute/virtualmachines',
-  'microsoft.compute/cloudservices',
-  'microsoft.vmwarecloudsimple/virtualmachines',
+  'microsoft.classicstorage/storageaccounts',
+  'microsoft.classicstorage/storageaccounts/blobservices',
+  'microsoft.classicstorage/storageaccounts/fileservices',
+  'microsoft.classicstorage/storageaccounts/queueservices',
+  'microsoft.classicstorage/storageaccounts/tableservices',
+  'microsoft.cloudtest/hostedpools',
+  'microsoft.cloudtest/pools',
+  'microsoft.clusterstor/nodes',
   'microsoft.codesigning/codesigningaccounts',
   'microsoft.cognitiveservices/accounts',
-  'microsoft.voiceservices/communicationsgateways',
-  'microsoft.appconfiguration/configurationstores',
-  'microsoft.network/connections',
+  'microsoft.communication/communicationservices',
+  'microsoft.compute/cloudservices',
+  'microsoft.compute/cloudservices/roles',
+  'microsoft.compute/disks',
+  'microsoft.compute/virtualmachines',
+  'microsoft.compute/virtualmachinescalesets',
+  'microsoft.compute/virtualmachinescalesets/virtualmachines',
+  'microsoft.connectedcache/cachenodes',
+  'microsoft.connectedcache/enterprisemcccustomers',
+  'microsoft.connectedcache/ispcustomers',
   'microsoft.connectedvehicle/platformaccounts',
   'microsoft.containerinstance/containergroups',
+  'microsoft.containerinstance/containerscalesets',
   'microsoft.containerregistry/registries',
   'microsoft.containerservice/managedclusters',
-  'microsoft.documentdb/databaseaccounts',
+  'microsoft.customerinsights/hubs',
+  'microsoft.customproviders/resourceproviders',
+  'microsoft.dashboard/grafana',
   'microsoft.databoxedge/databoxedgedevices',
+  'microsoft.datacollaboration/workspaces',
   'microsoft.datafactory/datafactories',
   'microsoft.datafactory/factories',
   'microsoft.datalakeanalytics/accounts',
   'microsoft.datalakestore/accounts',
+  'microsoft.dataprotection/backupvaults',
   'microsoft.datashare/accounts',
-  'microsoft.dbformysql/servers',
-  'microsoft.devices/provisioningservices',
-  'microsoft.compute/disks',
-  'microsoft.network/dnszones',
-  'microsoft.network/dnsresolvers',
-  'microsoft.network/dnsforwardingrulesets',
-  'microsoft.enterpriseknowledgegraph/services',
-  'microsoft.eventgrid/domains',
-  'microsoft.eventgrid/topics',
-  'microsoft.eventgrid/systemtopics',
-  'microsoft.eventhub/namespaces',
-  'microsoft.eventhub/clusters',
-  'microsoft.network/expressroutecircuits',
-  'microsoft.network/expressrouteports',
-  'microsoft.network/azurefirewalls',
-  'microsoft.network/frontdoors',
-  'microsoft.hdinsight/clusters',
-  'microsoft.iotcentral/iotapps',
-  'microsoft.devices/iothubs',
-  'microsoft.iotspaces/graph',
-  'microsoft.keyvault/vaults',
-  'microsoft.kubernetes/connectedclusters',
-  'microsoft.kusto/clusters',
-  'microsoft.network/loadbalancers',
-  'microsoft.operationalinsights/workspaces',
-  'microsoft.logic/workflows',
-  'microsoft.logic/integrationserviceenvironments',
-  'microsoft.machinelearningservices/workspaces',
-  'microsoft.managednetworkfabric/networkdevices',
   'microsoft.dbformariadb/servers',
-  'microsoft.media/mediaservices',
-  'microsoft.monitor/accounts',
   'microsoft.dbformysql/flexibleservers',
-  'microsoft.network/natgateways',
-  'microsoft.netapp/netappaccounts/capacitypools',
-  'microsoft.network/networkinterfaces',
-  'nginx.nginxplus/nginxdeployments',
-  'microsoft.notificationhubs/namespaces/notificationhubs',
-  'microsoft.orbital/l2connections',
-  'microsoft.peering/peeringservices',
-  'microsoft.playfab/titles',
+  'microsoft.dbformysql/servers',
+  'microsoft.dbforpostgresql/flexibleservers',
+  'microsoft.dbforpostgresql/servergroupsv2',
   'microsoft.dbforpostgresql/servers',
   'microsoft.dbforpostgresql/serversv2',
-  'microsoft.powerbidedicated/capacities',
+  'microsoft.devices/iothubs',
+  'microsoft.devices/provisioningservices',
+  'microsoft.digitaltwins/digitaltwinsinstances',
+  'microsoft.documentdb/cassandraclusters',
+  'microsoft.documentdb/databaseaccounts',
+  'microsoft.documentdb/mongoclusters',
+  'microsoft.edgezones/edgezones',
+  'microsoft.enterpriseknowledgegraph/services',
+  'microsoft.eventgrid/domains',
+  'microsoft.eventgrid/eventsubscriptions',
+  'microsoft.eventgrid/extensiontopics',
+  'microsoft.eventgrid/namespaces',
+  'microsoft.eventgrid/partnernamespaces',
+  'microsoft.eventgrid/partnertopics',
+  'microsoft.eventgrid/systemtopics',
+  'microsoft.eventgrid/topics',
+  'microsoft.eventhub/clusters',
+  'microsoft.eventhub/namespaces',
+  'microsoft.fabric.admin/fabriclocations',
+  'microsoft.hdinsight/clusters',
+  'microsoft.healthcareapis/services',
+  'microsoft.healthcareapis/workspaces/dicomservices',
+  'microsoft.healthcareapis/workspaces/fhirservices',
+  'microsoft.healthcareapis/workspaces/iotconnectors',
+  'microsoft.healthmodel/healthmodels',
+  'microsoft.hybridcontainerservice/provisionedclusters',
+  'microsoft.hybridnetwork/networkfunctions',
+  'microsoft.hybridnetwork/virtualnetworkfunctions',
+  'microsoft.insights/autoscalesettings',
+  'microsoft.insights/components',
+  'microsoft.iotcentral/iotapps',
+  'microsoft.iotspaces/graph',
+  'microsoft.keyvault/managedhsms',
+  'microsoft.keyvault/vaults',
+  'microsoft.kubernetes/connectedclusters',
+  'microsoft.kubernetesconfiguration/extensions',
+  'microsoft.kusto/clusters',
+  'microsoft.logic/integrationserviceenvironments',
+  'microsoft.logic/workflows',
+  'microsoft.machinelearningservices/workspaces',
+  'microsoft.machinelearningservices/workspaces/onlineendpoints',
+  'microsoft.machinelearningservices/workspaces/onlineendpoints/deployments',
+  'microsoft.managednetworkfabric/internetgateways',
+  'microsoft.managednetworkfabric/l3isolationdomains',
+  'microsoft.managednetworkfabric/networkdevices',
+  'microsoft.maps/accounts',
+  'microsoft.media/mediaservices',
+  'microsoft.media/mediaservices/liveevents',
+  'microsoft.media/mediaservices/streamingendpoints',
+  'microsoft.media/videoanalyzers',
+  'microsoft.mixedreality/remoterenderingaccounts',
+  'microsoft.mixedreality/spatialanchorsaccounts',
+  'microsoft.mobilenetwork/packetcorecontrolplanes',
+  'microsoft.mobilenetwork/packetcorecontrolplanes/packetcoredataplanes',
+  'microsoft.monitor/accounts',
+  'microsoft.netapp/netappaccounts/capacitypools',
+  'microsoft.netapp/netappaccounts/capacitypools/volumes',
+  'microsoft.network/applicationgateways',
+  'microsoft.network/azurefirewalls',
+  'microsoft.network/bastionhosts',
+  'microsoft.network/connections',
+  'microsoft.network/dnsforwardingrulesets',
+  'microsoft.network/dnsresolvers',
+  'microsoft.network/dnszones',
+  'microsoft.network/expressroutecircuits',
+  'microsoft.network/expressroutecircuits/peerings',
+  'microsoft.network/expressroutegateways',
+  'microsoft.network/expressrouteports',
+  'microsoft.network/frontdoors',
+  'microsoft.network/loadbalancers',
+  'microsoft.network/natgateways',
+  'microsoft.network/networkinterfaces',
+  'microsoft.network/networkmanagers/ipampools',
+  'microsoft.network/networkvirtualappliances',
+  'microsoft.network/networkwatchers',
+  'microsoft.network/networkwatchers/connectionmonitors',
+  'microsoft.network/p2svpngateways',
+  'microsoft.network/privatednszones',
   'microsoft.network/privateendpoints',
   'microsoft.network/privatelinkservices',
-  'microsoft.hybridcontainerservice/provisionedclusters',
   'microsoft.network/publicipaddresses',
+  'microsoft.network/publicipprefixes',
+  'microsoft.network/trafficmanagerprofiles',
+  'microsoft.network/virtualhubs',
+  'microsoft.network/virtualnetworkgateways',
+  'microsoft.network/virtualnetworks',
+  'microsoft.network/virtualrouters',
+  'microsoft.network/vpngateways',
+  'microsoft.networkanalytics/dataconnectors',
+  'microsoft.networkcloud/baremetalmachines',
+  'microsoft.networkcloud/clusters',
+  'microsoft.networkcloud/storageappliances',
+  'microsoft.networkfunction/azuretrafficcollectors',
+  'microsoft.notificationhubs/namespaces/notificationhubs',
+  'microsoft.operationalinsights/workspaces',
+  'microsoft.operationsmanagement/solutions',
+  'microsoft.orbital/contactprofiles',
+  'microsoft.orbital/l2connections',
+  'microsoft.orbital/spacecrafts',
+  'microsoft.orbital/terminals',
+  'microsoft.peering/peerings',
+  'microsoft.peering/peeringservices',
+  'microsoft.playfab/titles',
+  'microsoft.powerbidedicated/capacities',
+  'microsoft.purview/accounts',
   'microsoft.recoveryservices/vaults',
-  'microsoft.cache/redis',
-  'microsoft.cache/redisenterprise',
   'microsoft.relay/namespaces',
+  'microsoft.resources/subscriptions',
   'microsoft.search/searchservices',
-  'microsoft.dbforpostgresql/servergroupsv2',
+  'microsoft.securitydetonation/chambers',
+  'microsoft.securitydetonation/securitydetonationchambers',
   'microsoft.servicebus/namespaces',
   'microsoft.servicefabricmesh/applications',
+  'microsoft.servicenetworking/trafficcontrollers',
   'microsoft.signalrservice/signalr',
+  'microsoft.signalrservice/signalr/replicas',
   'microsoft.signalrservice/webpubsub',
-  'microsoft.operationsmanagement/solutions',
+  'microsoft.signalrservice/webpubsub/replicas',
+  'microsoft.singularity/accounts',
   'microsoft.sql/managedinstances',
   'microsoft.sql/servers/databases',
   'microsoft.sql/servers/elasticpools',
+  'microsoft.sql/servers/jobagents',
   'microsoft.storage/storageaccounts',
+  'microsoft.storage/storageaccounts/blobservices',
+  'microsoft.storage/storageaccounts/fileservices',
+  'microsoft.storage/storageaccounts/objectreplicationpolicies',
+  'microsoft.storage/storageaccounts/queueservices',
+  'microsoft.storage/storageaccounts/storagetasks',
+  'microsoft.storage/storageaccounts/tableservices',
+  'microsoft.storage/storagetasks',
+  'microsoft.storagecache/amlfilesystems',
   'microsoft.storagecache/caches',
-  'microsoft.classicstorage/storageaccounts',
   'microsoft.storagemover/storagemovers',
   'microsoft.storagesync/storagesyncservices',
+  'microsoft.storagetasks/storagetasks',
   'microsoft.streamanalytics/streamingjobs',
   'microsoft.synapse/workspaces',
+  'microsoft.synapse/workspaces/bigdatapools',
+  'microsoft.synapse/workspaces/kustopools',
+  'microsoft.synapse/workspaces/scopepools',
+  'microsoft.synapse/workspaces/sqlpools',
   'microsoft.timeseriesinsights/environments',
-  'microsoft.network/trafficmanagerprofiles',
-  'microsoft.compute/virtualmachines',
-  'microsoft.compute/virtualmachinescalesets',
-  'microsoft.network/virtualnetworkgateways',
-  'microsoft.web/sites/slots',
-  'microsoft.insights/autoscalesettings',
-  'microsoft.aadiam/azureadmetrics',
-  'microsoft.azurestackresourcemonitor/storageaccountmonitor',
-  'microsoft.network/networkwatchers/connectionmonitors',
-  'microsoft.app/containerapps',
-  'microsoft.customerinsights/hubs',
-  'microsoft.network/expressroutegateways',
-  'microsoft.fabric.admin/fabriclocations',
-  'microsoft.network/networkvirtualappliances',
-  'microsoft.network/networkwatchers',
-  'microsoft.network/p2svpngateways',
-  'microsoft.dbforpostgresql/flexibleservers',
-  'microsoft.network/vpngateways',
-  'microsoft.network/virtualhubs',
+  'microsoft.timeseriesinsights/environments/eventsources',
+  'microsoft.vmwarecloudsimple/virtualmachines',
+  'microsoft.voiceservices/communicationsgateways',
+  'microsoft.web/containerapps',
+  'microsoft.web/hostingenvironments',
+  'microsoft.web/hostingenvironments/multirolepools',
   'microsoft.web/hostingenvironments/workerpools',
-  'microsoft.storagecache/amlfilesystems',
-  'microsoft.dashboard/grafana',
-  'microsoft.orbital/contactprofiles',
-  'microsoft.orbital/spacecrafts',
+  'microsoft.web/serverfarms',
+  'microsoft.web/sites',
+  'microsoft.web/sites/slots',
+  'microsoft.web/staticsites',
+  'nginx.nginxplus/nginxdeployments',
+  'wandisco.fusion/migrators',
+  'wandisco.fusion/migrators/datatransferagents',
+  'wandisco.fusion/migrators/livedatamigrations',
+  'wandisco.fusion/migrators/metadatamigrations',
 ];
