@@ -1,4 +1,4 @@
-import React, { FC, useMemo } from 'react';
+import React, { useMemo } from 'react';
 
 import { SelectableValue } from '@grafana/data';
 import { EditorField, EditorFieldGroup } from '@grafana/experimental';
@@ -6,28 +6,33 @@ import { EditorField, EditorFieldGroup } from '@grafana/experimental';
 import { ALIGNMENT_PERIODS } from '../constants';
 import CloudMonitoringDatasource from '../datasource';
 import { alignmentPeriodLabel } from '../functions';
-import { CustomMetaData, MetricQuery, SLOQuery } from '../types';
+import { PreprocessorType, TimeSeriesList } from '../types/query';
+import { CustomMetaData, MetricDescriptor } from '../types/types';
 
 import { AlignmentFunction } from './AlignmentFunction';
 import { PeriodSelect } from './PeriodSelect';
 
 export interface Props {
   refId: string;
-  onChange: (query: MetricQuery | SLOQuery) => void;
-  query: MetricQuery;
+  onChange: (query: TimeSeriesList) => void;
+  query: TimeSeriesList;
   templateVariableOptions: Array<SelectableValue<string>>;
   customMetaData: CustomMetaData;
   datasource: CloudMonitoringDatasource;
+  metricDescriptor?: MetricDescriptor;
+  preprocessor?: PreprocessorType;
 }
 
-export const Alignment: FC<Props> = ({
+export const Alignment = ({
   refId,
   templateVariableOptions,
   onChange,
   query,
   customMetaData,
   datasource,
-}) => {
+  metricDescriptor,
+  preprocessor,
+}: Props) => {
   const alignmentLabel = useMemo(() => alignmentPeriodLabel(customMetaData, datasource), [customMetaData, datasource]);
   return (
     <EditorFieldGroup>
@@ -39,7 +44,9 @@ export const Alignment: FC<Props> = ({
           inputId={`${refId}-alignment-function`}
           templateVariableOptions={templateVariableOptions}
           query={query}
-          onChange={onChange}
+          onChange={(q) => onChange({ ...query, ...q })}
+          metricDescriptor={metricDescriptor}
+          preprocessor={preprocessor}
         />
       </EditorField>
       <EditorField label="Alignment period" tooltip={alignmentLabel}>
