@@ -66,7 +66,7 @@ export class CloudMonitoringVariableQueryEditor extends PureComponent<Props, Var
     const metricDescriptors = await this.props.datasource.getMetricTypes(
       this.props.query.projectName || this.props.datasource.getDefaultProject()
     );
-    const services = extractServicesFromMetricDescriptors(metricDescriptors).map((m: any) => ({
+    const services = extractServicesFromMetricDescriptors(metricDescriptors).map((m) => ({
       value: m.service,
       label: m.serviceShortName,
     }));
@@ -87,7 +87,7 @@ export class CloudMonitoringVariableQueryEditor extends PureComponent<Props, Var
 
     const sloServices = await this.props.datasource.getSLOServices(projectName);
 
-    const state: any = {
+    const state = {
       services,
       selectedService,
       metricTypes,
@@ -108,7 +108,7 @@ export class CloudMonitoringVariableQueryEditor extends PureComponent<Props, Var
   };
 
   async onQueryTypeChange(queryType: string) {
-    const state: any = {
+    const state = {
       selectedQueryType: queryType,
       ...(await this.getLabels(this.state.selectedMetricType, this.state.projectName, queryType)),
     };
@@ -148,7 +148,7 @@ export class CloudMonitoringVariableQueryEditor extends PureComponent<Props, Var
       getTemplateSrv().replace(this.state.selectedMetricType),
       getTemplateSrv().replace(service)
     );
-    const state: any = {
+    const state = {
       selectedService: service,
       metricTypes,
       selectedMetricType,
@@ -158,7 +158,7 @@ export class CloudMonitoringVariableQueryEditor extends PureComponent<Props, Var
   }
 
   async onMetricTypeChange(metricType: string) {
-    const state: any = {
+    const state = {
       selectedMetricType: metricType,
       ...(await this.getLabels(metricType, this.state.projectName)),
     };
@@ -195,7 +195,7 @@ export class CloudMonitoringVariableQueryEditor extends PureComponent<Props, Var
       expanded: false,
       options: getTemplateSrv()
         .getVariables()
-        .map((v: any) => ({
+        .map((v) => ({
           value: `$${v.name}`,
           label: `$${v.name}`,
         })),
@@ -322,14 +322,12 @@ export class CloudMonitoringVariableQueryEditor extends PureComponent<Props, Var
   render() {
     if (this.state.loading) {
       return (
-        <div className="gf-form max-width-21">
-          <span className="gf-form-label width-10 query-keyword">Query Type</span>
-          <div className="gf-form-select-wrapper max-width-12">
-            <select className="gf-form-input">
-              <option>Loading...</option>
-            </select>
-          </div>
-        </div>
+        <VariableQueryField
+          value={'loading'}
+          options={[{ value: 'loading', label: 'Loading...' }]}
+          onChange={(value) => null}
+          label="Query Type"
+        />
       );
     }
 
