@@ -6,7 +6,14 @@ import { config } from '@grafana/runtime';
 import { InlineField } from '@grafana/ui';
 
 import { CloudWatchDatasource } from '../../datasource';
-import { useAccountOptions, useDimensionKeys, useMetrics, useNamespaces, useRegions } from '../../hooks';
+import {
+  useAccountOptions,
+  useDimensionKeys,
+  useMetrics,
+  useNamespaces,
+  useRegions,
+  useEnsureVariableHasSingleSelection,
+} from '../../hooks';
 import { migrateVariableQuery } from '../../migrations/variableQueryMigrations';
 import { CloudWatchJsonData, CloudWatchQuery, VariableQuery, VariableQueryType } from '../../types';
 import { ALL_ACCOUNTS_OPTION } from '../shared/Account';
@@ -43,6 +50,7 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
   const metrics = useMetrics(datasource, { region, namespace });
   const dimensionKeys = useDimensionKeys(datasource, { region, namespace, metricName });
   const accountState = useAccountOptions(datasource.resources, query.region);
+  const dimensionKeyError = useEnsureVariableHasSingleSelection(datasource, dimensionKey);
 
   const newFormStylingEnabled = config.featureToggles.awsDatasourcesNewFormStyling;
   const onRegionChange = async (region: string) => {
@@ -114,7 +122,7 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
     VariableQueryType.DimensionValues,
   ].includes(parsedQuery.queryType);
   return (
-    <>
+    <div className={newFormStylingEnabled ? 'width-15' : ''}>
       <VariableQueryField
         value={parsedQuery.queryType}
         options={queryTypes}
@@ -179,6 +187,7 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
             inputId={`variable-query-dimension-key-${query.refId}`}
             allowCustomValue
             newFormStylingEnabled={newFormStylingEnabled}
+            error={dimensionKeyError}
           />
           {newFormStylingEnabled ? (
             <EditorField label="Dimensions" className="width-30" tooltip="Dimensions to filter the returned values on">
@@ -263,6 +272,7 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
                   onChange({ ...parsedQuery, ec2Filters: filters });
                 }}
                 keyPlaceholder="filter/tag"
+                datasource={datasource}
               />
             </EditorField>
           ) : (
@@ -289,6 +299,7 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
                   onChange({ ...parsedQuery, ec2Filters: filters });
                 }}
                 keyPlaceholder="filter/tag"
+                datasource={datasource}
               />
             </InlineField>
           )}
@@ -310,6 +321,7 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
                   onChange({ ...parsedQuery, tags: filters });
                 }}
                 keyPlaceholder="tag"
+                datasource={datasource}
               />
             </EditorField>
           ) : (
@@ -320,6 +332,7 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
                   onChange({ ...parsedQuery, tags: filters });
                 }}
                 keyPlaceholder="tag"
+                datasource={datasource}
               />
             </InlineField>
           )}
@@ -333,6 +346,6 @@ export const VariableQueryEditor = ({ query, datasource, onChange }: Props) => {
           newFormStylingEnabled={newFormStylingEnabled}
         />
       )}
-    </>
+    </div>
   );
 };
