@@ -11,9 +11,8 @@ import {
   convertLegacyAuthProps,
   DataSourceDescription,
 } from '@grafana/experimental';
-import { Alert, SecureSocksProxySettings } from '@grafana/ui';
-import { Divider } from 'app/core/components/Divider';
-import { config } from 'app/core/config';
+import { config } from '@grafana/runtime';
+import { Alert, SecureSocksProxySettings, Divider, Stack } from '@grafana/ui';
 
 import { ElasticsearchOptions } from '../types';
 
@@ -61,9 +60,9 @@ export const ConfigEditor = (props: Props) => {
         docsLink="https://grafana.com/docs/grafana/latest/datasources/elasticsearch"
         hasRequiredFields={false}
       />
-      <Divider />
+      <Divider spacing={4} />
       <ConnectionSettings config={options} onChange={onOptionsChange} urlPlaceholder="http://localhost:9200" />
-      <Divider />
+      <Divider spacing={4} />
       <Auth
         {...authProps}
         onAuthMethodSelect={(method) => {
@@ -79,42 +78,41 @@ export const ConfigEditor = (props: Props) => {
           });
         }}
       />
-      <Divider />
+      <Divider spacing={4} />
       <ConfigSection
         title="Additional settings"
         description="Additional settings are optional settings that can be configured for more control over your data source."
         isCollapsible={true}
         isInitiallyOpen
       >
-        <AdvancedHttpSettings config={options} onChange={onOptionsChange} />
-        <Divider hideLine />
-        {config.secureSocksDSProxyEnabled && (
-          <SecureSocksProxySettings options={options} onOptionsChange={onOptionsChange} />
-        )}
-        <ElasticDetails value={options} onChange={onOptionsChange} />
-        <Divider hideLine />
-        <LogsConfig
-          value={options.jsonData}
-          onChange={(newValue) =>
-            onOptionsChange({
-              ...options,
-              jsonData: newValue,
-            })
-          }
-        />
-        <Divider hideLine />
-        <DataLinks
-          value={options.jsonData.dataLinks}
-          onChange={(newValue) => {
-            onOptionsChange({
-              ...options,
-              jsonData: {
-                ...options.jsonData,
-                dataLinks: newValue,
-              },
-            });
-          }}
-        />
+        <Stack gap={5} direction="column">
+          <AdvancedHttpSettings config={options} onChange={onOptionsChange} />
+          {config.secureSocksDSProxyEnabled && (
+            <SecureSocksProxySettings options={options} onOptionsChange={onOptionsChange} />
+          )}
+          <ElasticDetails value={options} onChange={onOptionsChange} />
+          <LogsConfig
+            value={options.jsonData}
+            onChange={(newValue) =>
+              onOptionsChange({
+                ...options,
+                jsonData: newValue,
+              })
+            }
+          />
+          <DataLinks
+            value={options.jsonData.dataLinks}
+            onChange={(newValue) => {
+              onOptionsChange({
+                ...options,
+                jsonData: {
+                  ...options.jsonData,
+                  dataLinks: newValue,
+                },
+              });
+            }}
+          />
+        </Stack>
       </ConfigSection>
     </>
   );
