@@ -11,11 +11,10 @@ import {
 } from '@grafana/data';
 import { DataSourceWithBackend, getTemplateSrv, TemplateSrv } from '@grafana/runtime';
 
-import { extractLabelMatchers, toPromLikeExpr } from '../prometheus/language_utils';
-
 import { VariableSupport } from './VariableSupport';
 import { defaultGrafanaPyroscope, defaultPyroscopeQueryType } from './dataquery.gen';
 import { PyroscopeDataSourceOptions, Query, ProfileTypeMessage } from './types';
+import { extractLabelMatchers, toPromLikeExpr } from './utils';
 
 export class PyroscopeDataSource extends DataSourceWithBackend<Query, PyroscopeDataSourceOptions> {
   constructor(
@@ -48,7 +47,14 @@ export class PyroscopeDataSource extends DataSourceWithBackend<Query, PyroscopeD
     });
   }
 
-  async getProfileTypes(): Promise<ProfileTypeMessage[]> {
+  async getProfileTypes(start: number, end: number): Promise<ProfileTypeMessage[]> {
+    return await this.getResource('profileTypes', {
+      start,
+      end,
+    });
+  }
+
+  async getAllProfileTypes(): Promise<ProfileTypeMessage[]> {
     return await this.getResource('profileTypes');
   }
 
