@@ -1,5 +1,7 @@
-import { DataQuery, DataFrameJSON } from '@grafana/data';
+import { DataFrameJSON } from '@grafana/data';
 import { LiveDataFilter } from '@grafana/runtime';
+import { DataQuery } from '@grafana/schema';
+import { TimeRegionConfig } from 'app/core/utils/timeRegions';
 import { SearchQuery } from 'app/features/search/service';
 
 //----------------------------------------------
@@ -10,6 +12,7 @@ export enum GrafanaQueryType {
   LiveMeasurements = 'measurements',
   Annotations = 'annotations',
   Snapshot = 'snapshot',
+  TimeRegions = 'timeRegions',
 
   // backend
   RandomWalk = 'randomWalk',
@@ -26,6 +29,13 @@ export interface GrafanaQuery extends DataQuery {
   path?: string; // for list and read
   search?: SearchQuery;
   snapshot?: DataFrameJSON[];
+  timeRegion?: TimeRegionConfig;
+  file?: GrafanaQueryFile;
+}
+
+export interface GrafanaQueryFile {
+  name: string;
+  size: number;
 }
 
 export const defaultQuery: GrafanaQuery = {
@@ -33,6 +43,16 @@ export const defaultQuery: GrafanaQuery = {
   queryType: GrafanaQueryType.RandomWalk,
 };
 
+export const defaultFileUploadQuery: GrafanaQuery = {
+  refId: 'A',
+  datasource: {
+    type: 'grafana',
+    uid: 'grafana',
+  },
+  queryType: GrafanaQueryType.Snapshot,
+  snapshot: [],
+};
+
 //----------------------------------------------
 // Annotations
 //----------------------------------------------
