@@ -1,8 +1,8 @@
 import { DataSourcePlugin } from '@grafana/data';
 
 import CheatSheet from './CheatSheet';
-import { ConfigEditor } from './components/ConfigEditor';
 import { QueryEditor } from './components/QueryEditor';
+import { ConfigEditor } from './configuration/ConfigEditor';
 import { JaegerDatasource } from './datasource';
 
 export const plugin = new DataSourcePlugin(JaegerDatasource)
