@@ -1,12 +1,12 @@
 import { of } from 'rxjs';
-import { getQueryOptions } from 'test/helpers/getQueryOptions';
 
-import { dateTime, LoadingState } from '@grafana/data';
+import { DataQueryRequest, dateTime, LoadingState } from '@grafana/data';
 
+import { createLokiDatasource } from './__mocks__/datasource';
+import { getMockFrames } from './__mocks__/frames';
 import { LokiDatasource } from './datasource';
 import * as logsTimeSplit from './logsTimeSplitting';
 import * as metricTimeSplit from './metricTimeSplitting';
-import { createLokiDatasource, getMockFrames } from './mocks';
 import { runSplitQuery } from './querySplitting';
 import { trackGroupedQueries } from './tracking';
 import { LokiQuery, LokiQueryType } from './types';
@@ -26,10 +26,19 @@ describe('runSplitQuery()', () => {
       to: dateTime('2023-02-10T06:00:00.000Z'),
     },
   };
-  const request = getQueryOptions<LokiQuery>({
-    targets: [{ expr: 'count_over_time({a="b"}[1m])', refId: 'A' }],
-    range,
-  });
+
+  const createRequest = (targets: LokiQuery[], overrides?: Partial<DataQueryRequest<LokiQuery>>) => {
+    const request = {
+      range,
+      targets,
+      intervalMs: 60000,
+      requestId: 'TEST',
+    } as DataQueryRequest<LokiQuery>;
+
+    Object.assign(request, overrides);
+    return request;
+  };
+  const request = createRequest([{ expr: 'count_over_time({a="b"}[1m])', refId: 'A' }]);
   beforeEach(() => {
     datasource = createLokiDatasource();
     jest.spyOn(datasource, 'runQuery').mockReturnValue(of({ data: [] }));
@@ -42,6 +51,22 @@ describe('runSplitQuery()', () => {
     });
   });
 
+  test('Metric queries with maxLines of 0 will execute', async () => {
+    const request = createRequest([{ expr: 'count_over_time({a="b"}[1m])', refId: 'A', maxLines: 0 }]);
+    await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
+      // 3 days, 3 chunks, 3 requests.
+      expect(datasource.runQuery).toHaveBeenCalledTimes(3);
+    });
+  });
+
+  test('Log queries with maxLines of 0 will NOT execute', async () => {
+    const request = createRequest([{ expr: '{a="b"}', refId: 'A', maxLines: 0 }]);
+    await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
+      // Will not request a log query with maxLines of 0
+      expect(datasource.runQuery).toHaveBeenCalledTimes(0);
+    });
+  });
+
   test('Returns a DataQueryResponse with the expected attributes', async () => {
     await expect(runSplitQuery(datasource, request)).toEmitValuesWith((response) => {
       expect(response[0].data).toBeDefined();
@@ -59,8 +84,8 @@ describe('runSplitQuery()', () => {
           intervalMs: 60000,
           range: expect.objectContaining({
             from: expect.objectContaining({
-              //2023-02-09T06:00:00.000Z
-              _i: 1675922400000,
+              //2023-02-10T05:00:00.000Z
+              _i: 1676005200000,
             }),
             to: expect.objectContaining({
               // 2023-02-10T06:00:00.000Z
@@ -77,12 +102,12 @@ describe('runSplitQuery()', () => {
           intervalMs: 60000,
           range: expect.objectContaining({
             from: expect.objectContaining({
-              //2023-02-08T05:59:00.000Z
-              _i: 1675835940000,
+              // 2023-02-09T05:00:00.000Z
+              _i: 1675918800000,
             }),
             to: expect.objectContaining({
-              // 2023-02-09T05:59:00.000Z
-              _i: 1675922340000,
+              // 2023-02-10T04:59:00.000Z
+              _i: 1676005140000,
             }),
           }),
         })
@@ -95,12 +120,12 @@ describe('runSplitQuery()', () => {
           intervalMs: 60000,
           range: expect.objectContaining({
             from: expect.objectContaining({
-              //2023-02-08T05:00:00.000Z
+              // 2023-02-08T05:00:00.000Z
               _i: 1675832400000,
             }),
             to: expect.objectContaining({
-              // 2023-02-08T05:58:00.000Z
-              _i: 1675835880000,
+              // 2023-02-09T04:59:00.000Z
+              _i: 1675918740000,
             }),
           }),
         })
@@ -119,8 +144,8 @@ describe('runSplitQuery()', () => {
           intervalMs: 60000,
           range: expect.objectContaining({
             from: expect.objectContaining({
-              //2023-02-09T06:00:00.000Z
-              _i: 1675922400000,
+              //2023-02-10T05:00:00.000Z
+              _i: 1676005200000,
             }),
             to: expect.objectContaining({
               // 2023-02-10T06:00:00.000Z
@@ -137,12 +162,12 @@ describe('runSplitQuery()', () => {
           intervalMs: 60000,
           range: expect.objectContaining({
             from: expect.objectContaining({
-              //2023-02-08T05:59:50.000Z
-              _i: 1675835990000,
+              // 2023-02-09T05:00:00.000Z
+              _i: 1675918800000,
             }),
             to: expect.objectContaining({
-              // 2023-02-09T05:59:50.000Z
-              _i: 1675922390000,
+              // 2023-02-10T04:59:50.000Z
+              _i: 1676005190000,
             }),
           }),
         })
@@ -159,8 +184,8 @@ describe('runSplitQuery()', () => {
               _i: 1675832400000,
             }),
             to: expect.objectContaining({
-              // 2023-02-08T05:59:40.000Z
-              _i: 1675835980000,
+              // 2023-02-09T04:59:50.000Z
+              _i: 1675918790000,
             }),
           }),
         })
@@ -197,13 +222,10 @@ describe('runSplitQuery()', () => {
       jest.useRealTimers();
     });
     test('Ignores hidden queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'A', hide: true },
-          { expr: '{a="b"}', refId: 'B' },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'A', hide: true },
+        { expr: '{a="b"}', refId: 'B' },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         expect(logsTimeSplit.splitTimeRange).toHaveBeenCalled();
         expect(metricTimeSplit.splitTimeRange).not.toHaveBeenCalled();
@@ -230,13 +252,10 @@ describe('runSplitQuery()', () => {
       });
     });
     test('Ignores empty queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'A' },
-          { expr: '', refId: 'B' },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'A' },
+        { expr: '', refId: 'B' },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         expect(logsTimeSplit.splitTimeRange).not.toHaveBeenCalled();
         expect(metricTimeSplit.splitTimeRange).toHaveBeenCalled();
@@ -265,10 +284,7 @@ describe('runSplitQuery()', () => {
   });
 
   describe('Dynamic maxLines for logs requests', () => {
-    const request = getQueryOptions<LokiQuery>({
-      targets: [{ expr: '{a="b"}', refId: 'A', maxLines: 4 }],
-      range,
-    });
+    const request = createRequest([{ expr: '{a="b"}', refId: 'A', maxLines: 4 }]);
     const { logFrameA } = getMockFrames();
     beforeEach(() => {
       jest.spyOn(datasource, 'runQuery').mockReturnValue(of({ data: [logFrameA], refId: 'A' }));
@@ -301,52 +317,40 @@ describe('runSplitQuery()', () => {
       jest.spyOn(datasource, 'runQuery').mockReturnValue(of({ data: [], refId: 'A' }));
     });
     test('Sends logs and metric queries individually', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: '{a="b"}', refId: 'A' },
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'B' },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: '{a="b"}', refId: 'A' },
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'B' },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 3 days, 3 chunks, 1x Metric + 1x Log, 6 requests.
         expect(datasource.runQuery).toHaveBeenCalledTimes(6);
       });
     });
     test('Groups metric queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'A' },
-          { expr: 'count_over_time({c="d"}[1m])', refId: 'B' },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'A' },
+        { expr: 'count_over_time({c="d"}[1m])', refId: 'B' },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 3 days, 3 chunks, 1x2 Metric, 3 requests.
         expect(datasource.runQuery).toHaveBeenCalledTimes(3);
       });
     });
     test('Groups logs queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: '{a="b"}', refId: 'A' },
-          { expr: '{c="d"}', refId: 'B' },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: '{a="b"}', refId: 'A' },
+        { expr: '{c="d"}', refId: 'B' },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 3 days, 3 chunks, 1x2 Logs, 3 requests.
         expect(datasource.runQuery).toHaveBeenCalledTimes(3);
       });
     });
     test('Groups instant queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'A', queryType: LokiQueryType.Instant },
-          { expr: 'count_over_time({c="d"}[1m])', refId: 'B', queryType: LokiQueryType.Instant },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'A', queryType: LokiQueryType.Instant },
+        { expr: 'count_over_time({c="d"}[1m])', refId: 'B', queryType: LokiQueryType.Instant },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // Instant queries are omitted from splitting
         expect(datasource.runQuery).toHaveBeenCalledTimes(1);
@@ -354,13 +358,10 @@ describe('runSplitQuery()', () => {
     });
     test('Respects maxLines of logs queries', async () => {
       const { logFrameA } = getMockFrames();
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: '{a="b"}', refId: 'A', maxLines: logFrameA.fields[0].values.length },
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'B' },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: '{a="b"}', refId: 'A', maxLines: logFrameA.fields[0].values.length },
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'B' },
+      ]);
       jest.spyOn(datasource, 'runQuery').mockReturnValue(of({ data: [], refId: 'B' }));
       jest.spyOn(datasource, 'runQuery').mockReturnValueOnce(of({ data: [logFrameA], refId: 'A' }));
 
@@ -370,14 +371,11 @@ describe('runSplitQuery()', () => {
       });
     });
     test('Groups multiple queries into logs, queries, instant', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'A', queryType: LokiQueryType.Instant },
-          { expr: '{c="d"}', refId: 'B' },
-          { expr: 'count_over_time({c="d"}[1m])', refId: 'C' },
-        ],
-        range,
-      });
+      const request = createRequest([
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'A', queryType: LokiQueryType.Instant },
+        { expr: '{c="d"}', refId: 'B' },
+        { expr: 'count_over_time({c="d"}[1m])', refId: 'C' },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 3 days, 3 chunks, 3x Logs + 3x Metric + (1x Instant), 7 requests.
         expect(datasource.runQuery).toHaveBeenCalledTimes(7);
@@ -398,70 +396,70 @@ describe('runSplitQuery()', () => {
       jest.spyOn(datasource, 'runQuery').mockReturnValue(of({ data: [], refId: 'A' }));
     });
     test('with 30m splitDuration runs 2 queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
+      const request = {
         targets: [{ expr: '{a="b"}', refId: 'A', splitDuration: '30m' }],
         range: range1h,
-      });
+      } as DataQueryRequest<LokiQuery>;
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         expect(datasource.runQuery).toHaveBeenCalledTimes(2);
       });
     });
     test('with 1h splitDuration runs 1 queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
+      const request = {
         targets: [{ expr: '{a="b"}', refId: 'A', splitDuration: '1h' }],
         range: range1h,
-      });
+      } as DataQueryRequest<LokiQuery>;
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         expect(datasource.runQuery).toHaveBeenCalledTimes(1);
       });
     });
     test('with 1h splitDuration and 2 targets runs 1 queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
+      const request = {
         targets: [
           { expr: '{a="b"}', refId: 'A', splitDuration: '1h' },
           { expr: '{a="b"}', refId: 'B', splitDuration: '1h' },
         ],
         range: range1h,
-      });
+      } as DataQueryRequest<LokiQuery>;
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         expect(datasource.runQuery).toHaveBeenCalledTimes(1);
       });
     });
     test('with 1h/30m splitDuration and 2 targets runs 3 queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
+      const request = {
         targets: [
           { expr: '{a="b"}', refId: 'A', splitDuration: '1h' },
           { expr: '{a="b"}', refId: 'B', splitDuration: '30m' },
         ],
         range: range1h,
-      });
+      } as DataQueryRequest<LokiQuery>;
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 2 x 30m + 1 x 1h
         expect(datasource.runQuery).toHaveBeenCalledTimes(3);
       });
     });
     test('with mixed splitDuration runs the expected amount of queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
+      const request = createRequest(
+        [
           { expr: 'count_over_time({c="d"}[1m])', refId: 'A', splitDuration: '15m' },
           { expr: '{a="b"}', refId: 'B', splitDuration: '15m' },
           { expr: '{a="b"}', refId: 'C', splitDuration: '1h' },
         ],
-        range: range1h,
-      });
+        { range: range1h }
+      );
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 4 * 15m + 4 * 15m + 1 * 1h
         expect(datasource.runQuery).toHaveBeenCalledTimes(9);
       });
     });
     test('with 1h/30m splitDuration and 1 log and 2 metric target runs 3 queries', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
+      const request = createRequest(
+        [
           { expr: '{a="b"}', refId: 'A', splitDuration: '1h' },
           { expr: 'count_over_time({c="d"}[1m])', refId: 'C', splitDuration: '30m' },
         ],
-        range: range1h,
-      });
+        { range: range1h }
+      );
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 2 x 30m + 1 x 1h
         expect(datasource.runQuery).toHaveBeenCalledTimes(3);
@@ -479,26 +477,26 @@ describe('runSplitQuery()', () => {
       },
     };
     test('Groups logs queries by resolution', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
+      const request = createRequest(
+        [
           { expr: '{a="b"}', refId: 'A', resolution: 3 },
           { expr: '{a="b"}', refId: 'B', resolution: 5 },
         ],
-        range: range1d,
-      });
+        { range: range1d }
+      );
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // A, B
         expect(datasource.runQuery).toHaveBeenCalledTimes(2);
       });
     });
     test('Groups metric queries with no step by calculated stepMs', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
+      const request = createRequest(
+        [
           { expr: 'count_over_time({a="b"}[1m])', refId: 'A', resolution: 3 },
           { expr: 'count_over_time{a="b"}[1m])', refId: 'B', resolution: 5 },
         ],
-        range: range1d,
-      });
+        { range: range1d }
+      );
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // A, B
         expect(datasource.runQuery).toHaveBeenCalledTimes(2);
@@ -506,21 +504,21 @@ describe('runSplitQuery()', () => {
     });
 
     test('Groups metric queries with step by stepMs', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
+      const request = createRequest(
+        [
           { expr: 'count_over_time({a="b"}[1m])', refId: 'A', resolution: 1, step: '10' },
           { expr: 'count_over_time{a="b"}[1m])', refId: 'B', resolution: 1, step: '5ms' },
         ],
-        range: range1d,
-      });
+        { range: range1d }
+      );
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // A, B
         expect(datasource.runQuery).toHaveBeenCalledTimes(2);
       });
     });
     test('Groups mixed queries by stepMs', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
+      const request = createRequest(
+        [
           { expr: '{a="b"}', refId: 'A', resolution: 3 },
           { expr: '{a="b"}', refId: 'B', resolution: 5 },
           { expr: 'count_over_time({a="b"}[1m])', refId: 'C', resolution: 3 },
@@ -529,26 +527,23 @@ describe('runSplitQuery()', () => {
           { expr: 'rate({a="b"}[5m])', refId: 'F', resolution: 5, step: '10' },
           { expr: 'rate({a="b"} | logfmt[5m])', refId: 'G', resolution: 5, step: '10s' },
         ],
-        range: range1d,
-      });
+        { range: range1d }
+      );
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // A, B, C, D, E, F+G
         expect(datasource.runQuery).toHaveBeenCalledTimes(6);
       });
     });
     test('Chunked groups mixed queries by stepMs', async () => {
-      const request = getQueryOptions<LokiQuery>({
-        targets: [
-          { expr: '{a="b"}', refId: 'A', resolution: 3 },
-          { expr: '{a="b"}', refId: 'B', resolution: 5 },
-          { expr: 'count_over_time({a="b"}[1m])', refId: 'C', resolution: 3 },
-          { expr: 'count_over_time{a="b"}[1m])', refId: 'D', resolution: 5 },
-          { expr: '{a="b"}', refId: 'E', resolution: 5, queryType: LokiQueryType.Instant },
-          { expr: 'rate({a="b"}[5m])', refId: 'F', resolution: 5, step: '10' },
-          { expr: 'rate({a="b"} | logfmt[5m])', refId: 'G', resolution: 5, step: '10s' },
-        ],
-        range, // 3 days
-      });
+      const request = createRequest([
+        { expr: '{a="b"}', refId: 'A', resolution: 3 },
+        { expr: '{a="b"}', refId: 'B', resolution: 5 },
+        { expr: 'count_over_time({a="b"}[1m])', refId: 'C', resolution: 3 },
+        { expr: 'count_over_time{a="b"}[1m])', refId: 'D', resolution: 5 },
+        { expr: '{a="b"}', refId: 'E', resolution: 5, queryType: LokiQueryType.Instant },
+        { expr: 'rate({a="b"}[5m])', refId: 'F', resolution: 5, step: '10' },
+        { expr: 'rate({a="b"} | logfmt[5m])', refId: 'G', resolution: 5, step: '10s' },
+      ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
         // 3 * A, 3 * B, 3 * C, 3 * D, 1 * E, 3 * F+G
         expect(datasource.runQuery).toHaveBeenCalledTimes(16);
