@@ -1,8 +1,7 @@
 import React from 'react';
 
-import { EditorRow, EditorFieldGroup } from '@grafana/experimental';
+import { EditorRow, EditorFieldGroup, RawQuery } from '@grafana/experimental';
 
-import { RawQuery } from '../../../prometheus/querybuilder/shared/RawQuery';
 import { lokiGrammar } from '../../syntax';
 
 export interface Props {
@@ -13,7 +12,7 @@ export function QueryPreview({ query }: Props) {
   return (
     <EditorRow>
       <EditorFieldGroup>
-        <RawQuery query={query} lang={{ grammar: lokiGrammar, name: 'lokiql' }} />
+        <RawQuery query={query} language={{ grammar: lokiGrammar, name: 'lokiql' }} />
       </EditorFieldGroup>
     </EditorRow>
   );
