@@ -1,15 +1,15 @@
 import React, { useState } from 'react';
 
 import { SelectableValue, getDefaultTimeRange, toOption } from '@grafana/data';
+import { QueryBuilderOperationParamEditorProps, VisualQueryModeller } from '@grafana/experimental';
+import { config } from '@grafana/runtime';
 import { Select } from '@grafana/ui';
 
-import { getOperationParamId } from '../../../prometheus/querybuilder/shared/operationUtils';
-import { QueryBuilderOperationParamEditorProps } from '../../../prometheus/querybuilder/shared/types';
 import { placeHolderScopedVars } from '../../components/monaco-query-field/monaco-completion-provider/validation';
 import { LokiDatasource } from '../../datasource';
 import { getLogQueryFromMetricsQuery, isQueryWithError } from '../../queryUtils';
 import { extractUnwrapLabelKeysFromDataFrame } from '../../responseUtils';
-import { lokiQueryModeller } from '../LokiQueryModeller';
+import { getOperationParamId } from '../operationUtils';
 import { LokiVisualQuery } from '../types';
 
 export function UnwrapParamEditor({
@@ -20,6 +20,7 @@ export function UnwrapParamEditor({
   query,
   datasource,
   timeRange,
+  queryModeller,
 }: QueryBuilderOperationParamEditorProps) {
   const [state, setState] = useState<{
     options?: Array<SelectableValue<string>>;
@@ -31,9 +32,9 @@ export function UnwrapParamEditor({
       inputId={getOperationParamId(operationId, index)}
       onOpenMenu={async () => {
         // This check is always true, we do it to make typescript happy
-        if (datasource instanceof LokiDatasource) {
+        if (datasource instanceof LokiDatasource && config.featureToggles.lokiQueryHints) {
           setState({ isLoading: true });
-          const options = await loadUnwrapOptions(query, datasource, timeRange);
+          const options = await loadUnwrapOptions(query, datasource, queryModeller, timeRange);
           setState({ options, isLoading: undefined });
         }
       }}
@@ -55,9 +56,10 @@ export function UnwrapParamEditor({
 async function loadUnwrapOptions(
   query: LokiVisualQuery,
   datasource: LokiDatasource,
+  queryModeller: VisualQueryModeller,
   timeRange = getDefaultTimeRange()
 ): Promise<Array<SelectableValue<string>>> {
-  const queryExpr = lokiQueryModeller.renderQuery(query);
+  const queryExpr = queryModeller.renderQuery(query);
   const logExpr = getLogQueryFromMetricsQuery(queryExpr);
   if (isQueryWithError(datasource.interpolateString(logExpr, placeHolderScopedVars))) {
     return [];
