@@ -1,6 +1,5 @@
-import store from 'app/core/store';
+import { QueryEditorMode } from '@grafana/experimental';
 
-import { QueryEditorMode } from '../../prometheus/querybuilder/shared/types';
 import { LokiQuery, LokiQueryType } from '../types';
 
 const queryEditorModeDefaultLocalStorageKey = 'LokiQueryEditorModeDefault';
@@ -8,7 +7,7 @@ const queryEditorModeDefaultLocalStorageKey = 'LokiQueryEditorModeDefault';
 export function changeEditorMode(query: LokiQuery, editorMode: QueryEditorMode, onChange: (query: LokiQuery) => void) {
   // If empty query store new mode as default
   if (query.expr === '') {
-    store.set(queryEditorModeDefaultLocalStorageKey, editorMode);
+    window.localStorage.setItem(queryEditorModeDefaultLocalStorageKey, editorMode);
   }
 
   onChange({ ...query, editorMode });
@@ -20,7 +19,7 @@ export function getDefaultEditorMode(expr: string) {
     return QueryEditorMode.Code;
   }
 
-  const value: string | undefined = store.get(queryEditorModeDefaultLocalStorageKey);
+  const value: string | null = window.localStorage.getItem(queryEditorModeDefaultLocalStorageKey);
   switch (value) {
     case 'code':
       return QueryEditorMode.Code;
