@@ -15,6 +15,8 @@ import { getDataSourceSrv, toDataQueryError } from '@grafana/runtime';
 
 export const MIXED_DATASOURCE_NAME = '-- Mixed --';
 
+export const mixedRequestId = (queryIdx: number, requestId?: string) => `mixed-${queryIdx}-${requestId || ''}`;
+
 export interface BatchedQueries {
   datasource: Promise<DataSourceApi>;
   targets: DataQuery[];
@@ -61,7 +63,7 @@ export class MixedDatasource extends DataSourceApi<DataQuery> {
       from(query.datasource).pipe(
         mergeMap((api: DataSourceApi) => {
           const dsRequest = cloneDeep(request);
-          dsRequest.requestId = `mixed-${i}-${dsRequest.requestId || ''}`;
+          dsRequest.requestId = mixedRequestId(i, dsRequest.requestId);
           dsRequest.targets = query.targets;
 
           return from(api.query(dsRequest)).pipe(
@@ -70,7 +72,7 @@ export class MixedDatasource extends DataSourceApi<DataQuery> {
                 ...response,
                 data: response.data || [],
                 state: LoadingState.Loading,
-                key: `mixed-${i}-${response.key || ''}`,
+                key: mixedRequestId(i, response.key),
               };
             }),
             toArray(),
@@ -83,7 +85,7 @@ export class MixedDatasource extends DataSourceApi<DataQuery> {
                   data: [],
                   state: LoadingState.Error,
                   error: err,
-                  key: `mixed-${i}-${dsRequest.requestId || ''}`,
+                  key: mixedRequestId(i, dsRequest.requestId),
                 },
               ]);
             })
