@@ -2,39 +2,49 @@ import { of } from 'rxjs';
 
 import {
   dataFrameToJSON,
+  getDefaultTimeRange,
   DataQueryRequest,
   DataSourceInstanceSettings,
   dateTime,
   FieldType,
   createDataFrame,
 } from '@grafana/data';
-import { FetchResponse, setBackendSrv } from '@grafana/runtime';
-import { backendSrv } from 'app/core/services/backend_srv'; // will use the version in __mocks__
-import { SQLQuery } from 'app/features/plugins/sql/types';
-import { TemplateSrv } from 'app/features/templating/template_srv';
-import { initialCustomVariableModelState } from 'app/features/variables/custom/reducer';
+import { FetchResponse } from '@grafana/runtime';
+import { SQLQuery, makeVariable } from '@grafana/sql';
 
 import { MySqlDatasource } from '../MySqlDatasource';
 import { MySQLOptions } from '../types';
 
+const fetchMock = jest.fn();
+jest.mock('@grafana/runtime', () => ({
+  ...jest.requireActual('@grafana/runtime'),
+  getBackendSrv: () => ({
+    fetch: fetchMock,
+  }),
+}));
+
 describe('MySQLDatasource', () => {
-  const setupTestContext = (response: unknown) => {
+  const defaultRange = getDefaultTimeRange(); // it does not matter what value this has
+  const setupTestContext = (response: unknown, templateSrv?: unknown) => {
     jest.clearAllMocks();
-    setBackendSrv(backendSrv);
-    const fetchMock = jest.spyOn(backendSrv, 'fetch');
     const instanceSettings = {
       jsonData: {
         defaultProject: 'testproject',
       },
     } as unknown as DataSourceInstanceSettings<MySQLOptions>;
-    const templateSrv: TemplateSrv = new TemplateSrv();
-    const variable = { ...initialCustomVariableModelState };
+    const variable = makeVariable('id1', 'name1');
     fetchMock.mockImplementation((options) => of(createFetchResponse(response)));
 
     const ds = new MySqlDatasource(instanceSettings);
-    Reflect.set(ds, 'templateSrv', templateSrv);
+    if (templateSrv !== undefined) {
+      Reflect.set(ds, 'templateSrv', templateSrv);
+    }
 
-    return { ds, variable, templateSrv, fetchMock };
+    return { ds, variable, fetchMock };
+  };
+
+  const simpleTemplateSrv = {
+    replace: (text: string) => text,
   };
 
   describe('When performing a query with hidden target', () => {
@@ -66,7 +76,6 @@ describe('MySQLDatasource', () => {
   });
 
   describe('When runSql returns an empty dataframe', () => {
-    let ds: MySqlDatasource;
     const response = {
       results: {
         tempvar: {
@@ -76,27 +85,27 @@ describe('MySQLDatasource', () => {
       },
     };
 
-    beforeEach(async () => {
-      ds = setupTestContext(response).ds;
-    });
-
     it('should return an empty array when metricFindQuery is called', async () => {
+      const ds = setupTestContext(response, simpleTemplateSrv).ds;
       const query = 'select * from atable';
-      const results = await ds.metricFindQuery(query);
+      const results = await ds.metricFindQuery(query, { range: defaultRange });
       expect(results.length).toBe(0);
     });
 
     it('should return an empty array when fetchDatasets is called', async () => {
+      const ds = setupTestContext(response).ds;
       const results = await ds.fetchDatasets();
       expect(results.length).toBe(0);
     });
 
     it('should return an empty array when fetchTables is called', async () => {
+      const ds = setupTestContext(response).ds;
       const results = await ds.fetchTables();
       expect(results.length).toBe(0);
     });
 
     it('should return an empty array when fetchFields is called', async () => {
+      const ds = setupTestContext(response).ds;
       const query: SQLQuery = {
         refId: 'refId',
         table: 'schema.table',
@@ -215,8 +224,8 @@ describe('MySQLDatasource', () => {
     };
 
     it('should return list of all string field values', async () => {
-      const { ds } = setupTestContext(response);
-      const results = await ds.metricFindQuery(query, {});
+      const { ds } = setupTestContext(response, simpleTemplateSrv);
+      const results = await ds.metricFindQuery(query, { range: defaultRange });
 
       expect(results.length).toBe(6);
       expect(results[0].text).toBe('aTitle');
@@ -248,8 +257,20 @@ describe('MySQLDatasource', () => {
     };
 
     it('should return list of all column values', async () => {
-      const { ds, fetchMock } = setupTestContext(response);
-      const results = await ds.metricFindQuery(query, { searchFilter: 'aTit' });
+      const templateSrv = {
+        replace: (text: string, scopedVars: unknown) => {
+          expect(text).toBe("select title from atable where title LIKE '$__searchFilter'");
+          expect(scopedVars).toStrictEqual({
+            __searchFilter: {
+              value: 'aTit%',
+              text: '',
+            },
+          });
+          return "select title from atable where title LIKE 'aTit%'";
+        },
+      };
+      const { ds, fetchMock } = setupTestContext(response, templateSrv);
+      const results = await ds.metricFindQuery(query, { range: defaultRange, searchFilter: 'aTit' });
 
       expect(fetchMock).toBeCalledTimes(1);
       expect(fetchMock.mock.calls[0][0].data.queries[0].rawSql).toBe(
@@ -283,8 +304,20 @@ describe('MySQLDatasource', () => {
     };
 
     it('should return list of all column values', async () => {
-      const { ds, fetchMock } = setupTestContext(response);
-      const results = await ds.metricFindQuery(query, {});
+      const templateSrv = {
+        replace: (text: string, scopedVars: unknown) => {
+          expect(text).toBe("select title from atable where title LIKE '$__searchFilter'");
+          expect(scopedVars).toStrictEqual({
+            __searchFilter: {
+              value: '%',
+              text: '',
+            },
+          });
+          return "select title from atable where title LIKE '%'";
+        },
+      };
+      const { ds, fetchMock } = setupTestContext(response, templateSrv);
+      const results = await ds.metricFindQuery(query, { range: defaultRange });
 
       expect(fetchMock).toBeCalledTimes(1);
       expect(fetchMock.mock.calls[0][0].data.queries[0].rawSql).toBe("select title from atable where title LIKE '%'");
@@ -316,8 +349,8 @@ describe('MySQLDatasource', () => {
     };
 
     it('should return list of as text, value', async () => {
-      const { ds } = setupTestContext(response);
-      const results = await ds.metricFindQuery(query, {});
+      const { ds } = setupTestContext(response, simpleTemplateSrv);
+      const results = await ds.metricFindQuery(query, { range: defaultRange });
 
       expect(results.length).toBe(3);
       expect(results[0].text).toBe('aTitle');
@@ -351,8 +384,8 @@ describe('MySQLDatasource', () => {
     };
 
     it('should return list of all field values as text', async () => {
-      const { ds } = setupTestContext(response);
-      const results = await ds.metricFindQuery(query, {});
+      const { ds } = setupTestContext(response, simpleTemplateSrv);
+      const results = await ds.metricFindQuery(query, { range: defaultRange });
 
       expect(results).toEqual([
         { text: 1 },
@@ -389,8 +422,8 @@ describe('MySQLDatasource', () => {
     };
 
     it('should return list of unique keys', async () => {
-      const { ds } = setupTestContext(response);
-      const results = await ds.metricFindQuery(query, {});
+      const { ds } = setupTestContext(response, simpleTemplateSrv);
+      const results = await ds.metricFindQuery(query, { range: defaultRange });
 
       expect(results.length).toBe(1);
       expect(results[0].text).toBe('aTitle');
@@ -447,7 +480,6 @@ describe('MySQLDatasource', () => {
 
   describe('targetContainsTemplate', () => {
     it('given query that contains template variable it should return true', () => {
-      const { ds, templateSrv } = setupTestContext({});
       const rawSql = `SELECT
       $__timeGroup(createdAt,'$summarize') as time_sec,
       avg(value) as value,
@@ -466,15 +498,23 @@ describe('MySQLDatasource', () => {
         rawQuery: true,
         refId: '',
       };
-      templateSrv.init([
-        { type: 'query', name: 'summarize', current: { value: '1m' } },
-        { type: 'query', name: 'host', current: { value: 'a' } },
-      ]);
+      // a fake template server:
+      // it assumes there are two template variables defined:
+      // - summarize
+      // - host
+      const templateSrv = {
+        containsTemplate: (text: string) => {
+          // when the text arrives here, it has been already pre-processed
+          // by the sql datasource, sql-specific variables have been removed
+          expect(text).toBe(rawSql.replace(/\$__time(Filter)?/g, ''));
+          return true;
+        },
+      };
+      const { ds } = setupTestContext({}, templateSrv);
       expect(ds.targetContainsTemplate(query)).toBeTruthy();
     });
 
     it('given query that only contains global template variable it should return false', () => {
-      const { ds, templateSrv } = setupTestContext({});
       const rawSql = `SELECT
       $__timeGroup(createdAt,'$__interval') as time_sec,
       avg(value) as value,
@@ -491,10 +531,19 @@ describe('MySQLDatasource', () => {
         rawQuery: true,
         refId: '',
       };
-      templateSrv.init([
-        { type: 'query', name: 'summarize', current: { value: '1m' } },
-        { type: 'query', name: 'host', current: { value: 'a' } },
-      ]);
+      // a fake template server:
+      // it assumes there are two template variables defined:
+      // - summarize
+      // - host
+      const templateSrv = {
+        containsTemplate: (text: string) => {
+          // when the text arrives here, it has been already pre-processed
+          // by the sql datasource, sql-specific variables have been removed
+          expect(text).toBe(rawSql.replace(/\$__time(Filter)?/g, ''));
+          return false;
+        },
+      };
+      const { ds } = setupTestContext({}, templateSrv);
       expect(ds.targetContainsTemplate(query)).toBeFalsy();
     });
   });
