@@ -5,9 +5,11 @@ import {
   AnnotationEvent,
   AnnotationQueryRequest,
   CoreApp,
+  CustomVariableModel,
   DataQueryRequest,
   DataSourceInstanceSettings,
   dateTime,
+  LoadingState,
   rangeUtil,
   TimeRange,
   VariableHide,
@@ -463,7 +465,7 @@ describe('PrometheusDatasource', () => {
   });
 
   describe('When interpolating variables', () => {
-    let customVariable: any;
+    let customVariable: CustomVariableModel;
     beforeEach(() => {
       customVariable = {
         id: '',
@@ -476,11 +478,14 @@ describe('PrometheusDatasource', () => {
         current: {},
         name: '',
         type: 'custom',
-        label: null,
+        error: null,
+        rootStateKey: '',
+        state: LoadingState.Done,
+        description: '',
+        label: undefined,
         hide: VariableHide.dontHide,
         skipUrlSync: false,
         index: -1,
-        initLock: null,
       };
     });
 
@@ -492,7 +497,7 @@ describe('PrometheusDatasource', () => {
 
     describe('and value is a number', () => {
       it('should return a number', () => {
-        expect(ds.interpolateQueryExpr(1000 as any, customVariable)).toEqual(1000);
+        expect(ds.interpolateQueryExpr(1000 as unknown as string, customVariable)).toEqual(1000);
       });
     });
 
@@ -863,7 +868,7 @@ describe('PrometheusDatasource2', () => {
     });
 
     describe('region annotations for sectors', () => {
-      const options: any = {
+      const options = {
         annotation: {
           expr: 'ALERTS{alertstate="firing"}',
           tagKeys: 'job',
@@ -874,7 +879,7 @@ describe('PrometheusDatasource2', () => {
           from: time({ seconds: 63 }),
           to: time({ seconds: 900 }),
         },
-      };
+      } as unknown as AnnotationQueryRequest;
 
       async function runAnnotationQuery(data: number[][]) {
         let response = createAnnotationResponse();
