@@ -11,6 +11,8 @@ export class EmptyLanguageProviderMock {
   getSeries = jest.fn().mockReturnValue({ __name__: [] });
   fetchSeries = jest.fn().mockReturnValue([]);
   fetchSeriesLabels = jest.fn().mockReturnValue([]);
+  fetchSeriesLabelsMatch = jest.fn().mockReturnValue([]);
+  fetchLabelsWithMatch = jest.fn().mockReturnValue([]);
   fetchLabels = jest.fn();
   loadMetricsMetadata = jest.fn();
 }
