@@ -6,6 +6,7 @@ import { FetchResponse, TemplateSrv } from '@grafana/runtime';
 import { backendSrv } from 'app/core/services/backend_srv'; // will use the version in __mocks__
 
 import { PrometheusDatasource } from './datasource';
+import { getPrometheusTime } from './language_utils';
 import PrometheusMetricFindQuery from './metric_find_query';
 import { PromApplication, PromOptions } from './types';
 
@@ -57,7 +58,15 @@ describe('PrometheusMetricFindQuery', () => {
     );
   });
 
-  const setupMetricFindQuery = (data: any, datasource?: PrometheusDatasource) => {
+  const setupMetricFindQuery = (
+    data: {
+      query: string;
+      response: {
+        data: unknown;
+      };
+    },
+    datasource?: PrometheusDatasource
+  ) => {
     fetchMock.mockImplementation(() => of({ status: 'success', data: data.response } as unknown as FetchResponse));
     return new PrometheusMetricFindQuery(datasource ?? legacyPrometheusDatasource, data.query);
   };
@@ -249,7 +258,38 @@ describe('PrometheusMetricFindQuery', () => {
       expect(fetchMock).toHaveBeenCalledTimes(1);
       expect(fetchMock).toHaveBeenCalledWith({
         method: 'GET',
-        url: `/api/datasources/uid/ABCDEF/resources/api/v1/query?query=metric`,
+        url: `/api/datasources/uid/ABCDEF/resources/api/v1/query?query=metric&time=${raw.to.unix()}`,
+        headers: {},
+        hideFromInspector: true,
+        showErrorAlert: false,
+      });
+    });
+
+    it('query_result(metric) should pass time parameter to datasource.metric_find_query', async () => {
+      const query = setupMetricFindQuery({
+        query: 'query_result(metric)',
+        response: {
+          data: {
+            resultType: 'vector',
+            result: [
+              {
+                metric: { __name__: 'metric', job: 'testjob' },
+                value: [1443454528.0, '3846'],
+              },
+            ],
+          },
+        },
+      });
+      const results = await query.process(raw);
+
+      const expectedTime = getPrometheusTime(raw.to, true);
+
+      expect(results).toHaveLength(1);
+      expect(results[0].text).toBe('metric{job="testjob"} 3846 1443454528000');
+      expect(fetchMock).toHaveBeenCalledTimes(1);
+      expect(fetchMock).toHaveBeenCalledWith({
+        method: 'GET',
+        url: `/api/datasources/uid/ABCDEF/resources/api/v1/query?query=metric&time=${expectedTime}`,
         headers: {},
         hideFromInspector: true,
         showErrorAlert: false,
@@ -272,7 +312,7 @@ describe('PrometheusMetricFindQuery', () => {
       expect(fetchMock).toHaveBeenCalledTimes(1);
       expect(fetchMock).toHaveBeenCalledWith({
         method: 'GET',
-        url: `/api/datasources/uid/ABCDEF/resources/api/v1/query?query=1%2B1`,
+        url: `/api/datasources/uid/ABCDEF/resources/api/v1/query?query=1%2B1&time=${raw.to.unix()}`,
         headers: {},
         hideFromInspector: true,
         showErrorAlert: false,
