@@ -7,7 +7,8 @@ import { AccessoryButton, InputGroup } from '@grafana/experimental';
 import { InlineField, Select } from '@grafana/ui';
 import { lokiOperators } from 'app/plugins/datasource/loki/querybuilder/types';
 
-import { isConflictingSelector } from './operationUtils';
+import { isConflictingSelector } from '../operationUtils';
+
 import { QueryBuilderLabelFilter } from './types';
 
 export interface Props {
@@ -76,7 +77,7 @@ export function LabelFilterItem({
         <InputGroup>
           <Select
             placeholder="Select label"
-            aria-label={selectors.components.QueryBuilder.labelSelect}
+            data-testid={selectors.components.QueryBuilder.labelSelect}
             inputId="prometheus-dimensions-filter-item-key"
             width="auto"
             value={item.label ? toOption(item.label) : null}
@@ -106,7 +107,7 @@ export function LabelFilterItem({
           />
 
           <Select
-            aria-label={selectors.components.QueryBuilder.matchOperatorSelect}
+            data-testid={selectors.components.QueryBuilder.matchOperatorSelect}
             value={toOption(item.op ?? defaultOp)}
             options={operators}
             width="auto"
@@ -124,7 +125,7 @@ export function LabelFilterItem({
 
           <Select
             placeholder="Select value"
-            aria-label={selectors.components.QueryBuilder.valueSelect}
+            data-testid={selectors.components.QueryBuilder.valueSelect}
             inputId="prometheus-dimensions-filter-item-value"
             width="auto"
             value={
