@@ -15,12 +15,11 @@ import {
   withTheme2,
 } from '@grafana/ui';
 
-import { LokiQuery } from '../loki/types';
-
 import { LokiSearch } from './LokiSearch';
 import NativeSearch from './NativeSearch/NativeSearch';
 import TraceQLSearch from './SearchTraceQLEditor/TraceQLSearch';
 import { ServiceGraphSection } from './ServiceGraphSection';
+import { LokiQuery } from './_importedDependencies/datasources/loki/types';
 import { TempoQueryType } from './dataquery.gen';
 import { TempoDatasource } from './datasource';
 import { QueryEditor } from './traceql/QueryEditor';
@@ -124,6 +123,9 @@ class TempoQueryFieldComponent extends React.PureComponent<Props, State> {
             <FileDropzone
               options={{ multiple: false }}
               onLoad={(result) => {
+                if (typeof result !== 'string' && result !== null) {
+                  throw Error(`Unexpected result type: ${typeof result}`);
+                }
                 this.props.datasource.uploadedJson = result;
                 onChange({
                   ...query,
@@ -151,7 +153,6 @@ class TempoQueryFieldComponent extends React.PureComponent<Props, State> {
                   });
 
                   this.onClearResults();
-
                   onChange({
                     ...query,
                     queryType: v,
@@ -194,6 +195,8 @@ class TempoQueryFieldComponent extends React.PureComponent<Props, State> {
             query={query}
             onChange={onChange}
             onBlur={this.props.onBlur}
+            app={app}
+            onClearResults={this.onClearResults}
           />
         )}
         {query.queryType === 'serviceMap' && (
@@ -205,6 +208,8 @@ class TempoQueryFieldComponent extends React.PureComponent<Props, State> {
             query={query}
             onRunQuery={this.props.onRunQuery}
             onChange={onChange}
+            app={app}
+            onClearResults={this.onClearResults}
           />
         )}
       </>
