@@ -1,14 +1,13 @@
-import { render, screen, waitFor } from '@testing-library/react';
+import { act, render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
-import React from 'react';
-import { act } from 'react-dom/test-utils';
-import { initTemplateSrv } from 'test/helpers/initTemplateSrv';
+import React, { useState } from 'react';
 
 import { config } from '@grafana/runtime';
 
 import { TraceqlSearchScope } from '../dataquery.gen';
 import { TempoDatasource } from '../datasource';
 import TempoLanguageProvider from '../language_provider';
+import { initTemplateSrv } from '../test_utils';
 import { TempoQuery } from '../types';
 
 import TraceQLSearch from './TraceQLSearch';
@@ -43,7 +42,13 @@ jest.mock('../language_provider', () => {
 });
 
 describe('TraceQLSearch', () => {
-  initTemplateSrv('key', []);
+  const expectedValues = {
+    interpolationVar: 'interpolationText',
+    interpolationText: 'interpolationText',
+    interpolationVarWithPipe: 'interpolationTextOne|interpolationTextTwo',
+    scopedInterpolationText: 'scopedInterpolationText',
+  };
+  initTemplateSrv([{ name: 'templateVariable1' }, { name: 'templateVariable2' }], expectedValues);
 
   let user: ReturnType<typeof userEvent.setup>;
 
@@ -70,6 +75,7 @@ describe('TraceQLSearch', () => {
   const onChange = (q: TempoQuery) => {
     query = q;
   };
+  const onClearResults = jest.fn();
 
   beforeEach(() => {
     jest.useFakeTimers();
@@ -82,8 +88,66 @@ describe('TraceQLSearch', () => {
     jest.useRealTimers();
   });
 
+  it('should only show add/remove tag when necessary', async () => {
+    const TraceQLSearchWithProps = () => {
+      const [query, setQuery] = useState<TempoQuery>({
+        refId: 'A',
+        queryType: 'traceqlSearch',
+        key: 'Q-595a9bbc-2a25-49a7-9249-a52a0a475d83-0',
+        filters: [],
+      });
+      return (
+        <TraceQLSearch
+          datasource={datasource}
+          query={query}
+          onChange={(q: TempoQuery) => setQuery(q)}
+          onClearResults={onClearResults}
+        />
+      );
+    };
+    render(<TraceQLSearchWithProps />);
+
+    await act(async () => {
+      expect(screen.queryAllByLabelText('Add tag').length).toBe(0); // not filled in the default tag, so no need to add another one
+      expect(screen.queryAllByLabelText('Remove tag').length).toBe(0); // mot filled in the default tag, so no values to remove
+      expect(screen.getAllByText('Select tag').length).toBe(1);
+    });
+
+    await user.click(screen.getByText('Select tag'));
+    jest.advanceTimersByTime(1000);
+    await user.click(screen.getByText('foo'));
+    jest.advanceTimersByTime(1000);
+    await user.click(screen.getAllByText('Select value')[2]);
+    jest.advanceTimersByTime(1000);
+    await user.click(screen.getByText('driver'));
+    jest.advanceTimersByTime(1000);
+    await act(async () => {
+      expect(screen.getAllByLabelText('Add tag').length).toBe(1);
+      expect(screen.getAllByLabelText(/Remove tag/).length).toBe(1);
+    });
+
+    await user.click(screen.getByLabelText('Add tag'));
+    jest.advanceTimersByTime(1000);
+    expect(screen.queryAllByLabelText('Add tag').length).toBe(0); // not filled in the new tag, so no need to add another one
+    expect(screen.getAllByLabelText(/Remove tag/).length).toBe(2); // one for each tag
+
+    await user.click(screen.getAllByLabelText(/Remove tag/)[1]);
+    jest.advanceTimersByTime(1000);
+    expect(screen.queryAllByLabelText('Add tag').length).toBe(1); // filled in the default tag, so can add another one
+    expect(screen.queryAllByLabelText(/Remove tag/).length).toBe(1); // filled in the default tag, so can remove values
+
+    await user.click(screen.getAllByLabelText(/Remove tag/)[0]);
+    jest.advanceTimersByTime(1000);
+    await act(async () => {
+      expect(screen.queryAllByLabelText('Add tag').length).toBe(0); // not filled in the default tag, so no need to add another one
+      expect(screen.queryAllByLabelText(/Remove tag/).length).toBe(0); // mot filled in the default tag, so no values to remove
+    });
+  });
+
   it('should update operator when new value is selected in operator input', async () => {
-    const { container } = render(<TraceQLSearch datasource={datasource} query={query} onChange={onChange} />);
+    const { container } = render(
+      <TraceQLSearch datasource={datasource} query={query} onChange={onChange} onClearResults={onClearResults} />
+    );
 
     const minDurationOperator = container.querySelector(`input[aria-label="select min-duration operator"]`);
     expect(minDurationOperator).not.toBeNull();
@@ -101,7 +165,9 @@ describe('TraceQLSearch', () => {
   });
 
   it('should add new filter when new value is selected in the service name section', async () => {
-    const { container } = render(<TraceQLSearch datasource={datasource} query={query} onChange={onChange} />);
+    const { container } = render(
+      <TraceQLSearch datasource={datasource} query={query} onChange={onChange} onClearResults={onClearResults} />
+    );
     const serviceNameValue = container.querySelector(`input[aria-label="select service-name value"]`);
     expect(serviceNameValue).not.toBeNull();
     expect(serviceNameValue).toBeInTheDocument();
@@ -136,7 +202,9 @@ describe('TraceQLSearch', () => {
     } as TempoDatasource;
     datasource.languageProvider = new TempoLanguageProvider(datasource);
     await act(async () => {
-      const { container } = render(<TraceQLSearch datasource={datasource} query={query} onChange={onChange} />);
+      const { container } = render(
+        <TraceQLSearch datasource={datasource} query={query} onChange={onChange} onClearResults={onClearResults} />
+      );
       const serviceNameValue = container.querySelector(`input[aria-label="select service-name value"]`);
       expect(serviceNameValue).toBeNull();
       expect(serviceNameValue).not.toBeInTheDocument();
@@ -145,7 +213,9 @@ describe('TraceQLSearch', () => {
 
   it('should not render group by when feature toggle is not enabled', async () => {
     await waitFor(() => {
-      render(<TraceQLSearch datasource={datasource} query={query} onChange={onChange} />);
+      render(
+        <TraceQLSearch datasource={datasource} query={query} onChange={onChange} onClearResults={onClearResults} />
+      );
       const groupBy = screen.queryByText('Aggregate by');
       expect(groupBy).toBeNull();
       expect(groupBy).not.toBeInTheDocument();
@@ -155,7 +225,9 @@ describe('TraceQLSearch', () => {
   it('should render group by when feature toggle enabled', async () => {
     config.featureToggles.metricsSummary = true;
     await waitFor(() => {
-      render(<TraceQLSearch datasource={datasource} query={query} onChange={onChange} />);
+      render(
+        <TraceQLSearch datasource={datasource} query={query} onChange={onChange} onClearResults={onClearResults} />
+      );
       const groupBy = screen.queryByText('Aggregate by');
       expect(groupBy).not.toBeNull();
       expect(groupBy).toBeInTheDocument();
