@@ -1,15 +1,14 @@
 import { css } from '@emotion/css';
 import React, { useCallback, useEffect, useState } from 'react';
 
-import { GrafanaTheme2 } from '@grafana/data';
-import { EditorRow } from '@grafana/experimental';
-import { config, FetchError, getTemplateSrv } from '@grafana/runtime';
-import { Alert, HorizontalGroup, useStyles2 } from '@grafana/ui';
+import { CoreApp, GrafanaTheme2 } from '@grafana/data';
+import { config, FetchError, getTemplateSrv, reportInteraction } from '@grafana/runtime';
+import { Alert, Button, HorizontalGroup, Select, useStyles2 } from '@grafana/ui';
 
-import { createErrorNotification } from '../../../../core/copy/appNotification';
-import { notifyApp } from '../../../../core/reducers/appNotification';
-import { dispatch } from '../../../../store/store';
-import { RawQuery } from '../../prometheus/querybuilder/shared/RawQuery';
+import { notifyApp } from '../_importedDependencies/actions/appNotification';
+import { createErrorNotification } from '../_importedDependencies/core/appNotification';
+import { RawQuery } from '../_importedDependencies/datasources/prometheus/RawQuery';
+import { dispatch } from '../_importedDependencies/store';
 import { TraceqlFilter, TraceqlSearchScope } from '../dataquery.gen';
 import { TempoDatasource } from '../datasource';
 import { TempoQueryBuilderOptions } from '../traceql/TempoQueryBuilderOptions';
@@ -28,11 +27,13 @@ interface Props {
   query: TempoQuery;
   onChange: (value: TempoQuery) => void;
   onBlur?: () => void;
+  onClearResults: () => void;
+  app?: CoreApp;
 }
 
 const hardCodedFilterIds = ['min-duration', 'max-duration', 'status'];
 
-const TraceQLSearch = ({ datasource, query, onChange }: Props) => {
+const TraceQLSearch = ({ datasource, query, onChange, onClearResults, app }: Props) => {
   const styles = useStyles2(getStyles);
   const [error, setError] = useState<Error | FetchError | null>(null);
 
@@ -95,12 +96,15 @@ const TraceQLSearch = ({ datasource, query, onChange }: Props) => {
   // filter out tags that already exist in the static fields
   const staticTags = datasource.search?.filters?.map((f) => f.tag) || [];
   staticTags.push('duration');
+  staticTags.push('traceDuration');
 
   // Dynamic filters are all filters that don't match the ID of a filter in the datasource configuration
   // The duration and status fields are a special case since its selector is hard-coded
   const dynamicFilters = (query.filters || []).filter(
     (f) =>
-      !hardCodedFilterIds.includes(f.id) && (datasource.search?.filters?.findIndex((sf) => sf.id === f.id) || 0) === -1
+      !hardCodedFilterIds.includes(f.id) &&
+      (datasource.search?.filters?.findIndex((sf) => sf.id === f.id) || 0) === -1 &&
+      f.id !== 'duration-type'
   );
 
   return (
@@ -147,13 +151,30 @@ const TraceQLSearch = ({ datasource, query, onChange }: Props) => {
               hideScope={true}
               hideTag={true}
               query={traceQlQuery}
+              isMulti={false}
+              allowCustomValue={false}
             />
           </InlineSearchField>
           <InlineSearchField
-            label={'Span Duration'}
-            tooltip="The span duration, i.e.	end - start time of the span. Accepted units are ns, ms, s, m, h"
+            label={'Duration'}
+            tooltip="The trace or span duration, i.e. end - start time of the trace/span. Accepted units are ns, ms, s, m, h"
           >
-            <HorizontalGroup spacing={'sm'}>
+            <HorizontalGroup spacing={'none'}>
+              <Select
+                options={[
+                  { label: 'span', value: 'span' },
+                  { label: 'trace', value: 'trace' },
+                ]}
+                value={findFilter('duration-type')?.value ?? 'span'}
+                onChange={(v) => {
+                  const filter = findFilter('duration-type') || {
+                    id: 'duration-type',
+                    value: 'span',
+                  };
+                  updateFilter({ ...filter, value: v?.value });
+                }}
+                aria-label={'duration type'}
+              />
               <DurationInput
                 filter={
                   findFilter('min-duration') || {
@@ -190,15 +211,37 @@ const TraceQLSearch = ({ datasource, query, onChange }: Props) => {
               staticTags={staticTags}
               isTagsLoading={isTagsLoading}
               query={traceQlQuery}
+              requireTagAndValue={true}
             />
           </InlineSearchField>
           {config.featureToggles.metricsSummary && (
             <GroupByField datasource={datasource} onChange={onChange} query={query} isTagsLoading={isTagsLoading} />
           )}
         </div>
-        <EditorRow>
+        <div className={styles.rawQueryContainer}>
           <RawQuery query={templateSrv.replace(traceQlQuery)} lang={{ grammar: traceqlGrammar, name: 'traceql' }} />
-        </EditorRow>
+          <Button
+            variant="secondary"
+            size="sm"
+            onClick={() => {
+              reportInteraction('grafana_traces_copy_to_traceql_clicked', {
+                app: app ?? '',
+                grafana_version: config.buildInfo.version,
+                location: 'search_tab',
+              });
+
+              onClearResults();
+              const traceQlQuery = generateQueryFromFilters(query.filters || []);
+              onChange({
+                ...query,
+                query: traceQlQuery,
+                queryType: 'traceql',
+              });
+            }}
+          >
+            Edit in TraceQL
+          </Button>
+        </div>
         <TempoQueryBuilderOptions onChange={onChange} query={query} />
       </div>
       {error ? (
@@ -214,14 +257,21 @@ const TraceQLSearch = ({ datasource, query, onChange }: Props) => {
 export default TraceQLSearch;
 
 const getStyles = (theme: GrafanaTheme2) => ({
-  alert: css`
-    max-width: 75ch;
-    margin-top: ${theme.spacing(2)};
-  `,
-  container: css`
-    display: flex;
-    gap: 4px;
-    flex-wrap: wrap;
-    flex-direction: column;
-  `,
+  alert: css({
+    maxWidth: '75ch',
+    marginTop: theme.spacing(2),
+  }),
+  container: css({
+    display: 'flex',
+    gap: '4px',
+    flexWrap: 'wrap',
+    flexDirection: 'column',
+  }),
+  rawQueryContainer: css({
+    alignItems: 'center',
+    backgroundColor: theme.colors.background.secondary,
+    display: 'flex',
+    justifyContent: 'space-between',
+    padding: theme.spacing(1),
+  }),
 });
