@@ -5,10 +5,9 @@ import useAsync from 'react-use/lib/useAsync';
 import { GrafanaTheme2 } from '@grafana/data';
 import { Alert, InlineField, InlineFieldRow, useStyles2 } from '@grafana/ui';
 
-import { AdHocFilter } from '../../../features/variables/adhoc/picker/AdHocFilter';
-import { AdHocVariableFilter } from '../../../features/variables/types';
-import { PrometheusDatasource } from '../prometheus/datasource';
-
+import { AdHocFilter } from './_importedDependencies/components/AdHocFilter/AdHocFilter';
+import { PrometheusDatasource } from './_importedDependencies/datasources/prometheus/types';
+import { AdHocVariableFilter } from './_importedDependencies/types';
 import { TempoQuery } from './types';
 import { getDS } from './utils';
 
@@ -68,7 +67,9 @@ export function ServiceGraphSection({
     );
   }
 
-  const filters = queryToFilter(query.serviceMapQuery || '');
+  const filters = queryToFilter(
+    (Array.isArray(query.serviceMapQuery) ? query.serviceMapQuery[0] : query.serviceMapQuery) || ''
+  );
 
   return (
     <div>
@@ -152,12 +153,12 @@ function filtersToQuery(filters: AdHocVariableFilter[]): string {
 }
 
 const getStyles = (theme: GrafanaTheme2) => ({
-  alert: css`
-    max-width: 75ch;
-    margin-top: ${theme.spacing(2)};
-  `,
-  link: css`
-    color: ${theme.colors.text.link};
-    text-decoration: underline;
-  `,
+  alert: css({
+    maxWidth: '75ch',
+    marginTop: theme.spacing(2),
+  }),
+  link: css({
+    color: theme.colors.text.link,
+    textDecoration: 'underline',
+  }),
 });
