@@ -1,4 +1,4 @@
-import { MutableDataFrame } from '@grafana/data';
+import { FieldType, MutableDataFrame } from '@grafana/data';
 
 export const bigResponse = new MutableDataFrame({
   fields: [
@@ -1807,73 +1807,73 @@ export const otlpDataFrameFromResponse = new MutableDataFrame({
   fields: [
     {
       name: 'traceID',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['60ba2abb44f13eae'],
     },
     {
       name: 'spanID',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['726b5e30102fc0d0'],
     },
     {
       name: 'parentSpanID',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['398f0f21a3db99ae'],
     },
     {
       name: 'operationName',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['HTTP GET - root'],
     },
     {
       name: 'serviceName',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['db'],
     },
     {
       name: 'kind',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['client'],
     },
     {
       name: 'statusCode',
-      type: 'number',
+      type: FieldType.number,
       config: {},
       values: [2],
     },
     {
       name: 'statusMessage',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['message'],
     },
     {
       name: 'instrumentationLibraryName',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['libraryName'],
     },
     {
       name: 'instrumentationLibraryVersion',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['libraryVersion'],
     },
     {
       name: 'traceState',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['traceState'],
     },
     {
       name: 'serviceTags',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       values: [
         [
@@ -1906,25 +1906,25 @@ export const otlpDataFrameFromResponse = new MutableDataFrame({
     },
     {
       name: 'startTime',
-      type: 'number',
+      type: FieldType.number,
       config: {},
       values: [1627471657255.809],
     },
     {
       name: 'duration',
-      type: 'number',
+      type: FieldType.number,
       config: {},
       values: [0.459008],
     },
     {
       name: 'logs',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       values: [[]],
     },
     {
       name: 'references',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       values: [
         [
@@ -1946,7 +1946,7 @@ export const otlpDataFrameFromResponse = new MutableDataFrame({
     },
     {
       name: 'tags',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       values: [
         [
@@ -1971,7 +1971,7 @@ export const otlpDataFrameFromResponse = new MutableDataFrame({
     },
   ],
   length: 1,
-} as any);
+});
 
 export const otlpDataFrameToResponse = new MutableDataFrame({
   meta: {
@@ -1983,7 +1983,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
   fields: [
     {
       name: 'traceID',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['60ba2abb44f13eae'],
       state: {
@@ -1992,7 +1992,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'spanID',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['726b5e30102fc0d0'],
       state: {
@@ -2001,7 +2001,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'parentSpanID',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['398f0f21a3db99ae'],
       state: {
@@ -2010,7 +2010,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'operationName',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['HTTP GET - root'],
       state: {
@@ -2019,7 +2019,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'serviceName',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['db'],
       state: {
@@ -2028,7 +2028,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'kind',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['client'],
       state: {
@@ -2037,7 +2037,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'statusCode',
-      type: 'number',
+      type: FieldType.number,
       config: {},
       values: [2],
       state: {
@@ -2046,7 +2046,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'statusMessage',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['message'],
       state: {
@@ -2055,7 +2055,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'instrumentationLibraryName',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['libraryName'],
       state: {
@@ -2064,7 +2064,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'instrumentationLibraryVersion',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['libraryVersion'],
       state: {
@@ -2073,7 +2073,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'traceState',
-      type: 'string',
+      type: FieldType.string,
       config: {},
       values: ['traceState'],
       state: {
@@ -2082,7 +2082,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'serviceTags',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       values: [
         [
@@ -2118,7 +2118,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'startTime',
-      type: 'number',
+      type: FieldType.number,
       config: {},
       values: [1627471657255.809],
       state: {
@@ -2127,7 +2127,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'duration',
-      type: 'number',
+      type: FieldType.number,
       config: {},
       values: [0.459008],
       state: {
@@ -2136,7 +2136,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'logs',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       values: [[]],
       state: {
@@ -2145,7 +2145,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'tags',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       values: [
         [
@@ -2173,7 +2173,7 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
     },
     {
       name: 'references',
-      type: 'other',
+      type: FieldType.other,
       config: {},
       labels: undefined,
       values: [
@@ -2198,9 +2198,8 @@ export const otlpDataFrameToResponse = new MutableDataFrame({
       },
     },
   ],
-  first: ['60ba2abb44f13eae'],
   length: 1,
-} as any);
+});
 
 export const otlpResponse = {
   batches: [
@@ -2278,7 +2277,8 @@ export const tempoSearchResponse = {
   traces: [
     {
       traceID: 'e641dcac1c3a0565',
-      rootServiceName: 'c10d7ca4e3a00354',
+      rootServiceName: 'requester',
+      rootTraceName: 'app',
       startTimeUnixNano: '1643356828724000000',
       durationMs: 65,
     },
@@ -2391,87 +2391,91 @@ export const traceQlResponse = {
       rootTraceName: 'HTTP Client',
       startTimeUnixNano: '1643342166678000000',
       durationMs: 93,
-      spanSet: {
-        spans: [
-          {
-            spanID: '3b9a5c222d3ddd8f',
-            startTimeUnixNano: '1666187875397721000',
-            durationNanos: '877000',
-            attributes: [
-              {
-                key: 'http.method',
-                value: {
-                  stringValue: 'GET',
-                },
+      spanSets: [
+        {
+          attributes: [
+            {
+              key: 'by(resource.service.name)',
+              value: {
+                stringValue: 'db',
               },
-              {
-                key: 'service.name',
-                value: {
-                  stringValue: 'db',
+            },
+          ],
+          spans: [
+            {
+              spanID: '3b9a5c222d3ddd8f',
+              startTimeUnixNano: '1666187875397721000',
+              durationNanos: '877000',
+              attributes: [
+                {
+                  key: 'http.method',
+                  value: {
+                    stringValue: 'GET',
+                  },
                 },
-              },
-            ],
-          },
-          {
-            spanID: '894d90db6b5807f',
-            startTimeUnixNano: '1666187875393293000',
-            durationNanos: '11073000',
-            attributes: [
-              {
-                key: 'http.method',
-                value: {
-                  stringValue: 'GET',
+                {
+                  key: 'service.name',
+                  value: {
+                    stringValue: 'db',
+                  },
                 },
+              ],
+            },
+          ],
+          matched: 1,
+        },
+        {
+          attributes: [
+            {
+              key: 'by(resource.service.name)',
+              value: {
+                stringValue: 'app',
               },
-              {
-                key: 'service.name',
-                value: {
-                  stringValue: 'app',
+            },
+          ],
+          spans: [
+            {
+              spanID: '894d90db6b5807f',
+              startTimeUnixNano: '1666187875393293000',
+              durationNanos: '11073000',
+              attributes: [
+                {
+                  key: 'http.method',
+                  value: {
+                    stringValue: 'GET',
+                  },
                 },
-              },
-            ],
-          },
-          {
-            spanID: 'd3284e9c5081aab',
-            startTimeUnixNano: '1666187875393897000',
-            durationNanos: '10133000',
-            attributes: [
-              {
-                key: 'service.name',
-                value: {
-                  stringValue: 'app',
+                {
+                  key: 'service.name',
+                  value: {
+                    stringValue: 'app',
+                  },
                 },
-              },
-              {
-                key: 'http.method',
-                value: {
-                  stringValue: 'GET',
+              ],
+            },
+            {
+              spanID: 'd3284e9c5081aab',
+              startTimeUnixNano: '1666187875393897000',
+              durationNanos: '10133000',
+              attributes: [
+                {
+                  key: 'service.name',
+                  value: {
+                    stringValue: 'app',
+                  },
                 },
-              },
-            ],
-          },
-          {
-            spanID: '454785498fc8b1aa',
-            startTimeUnixNano: '1666187875389957000',
-            durationNanos: '13953000',
-            attributes: [
-              {
-                key: 'http.method',
-                value: {
-                  stringValue: 'GET',
+                {
+                  key: 'http.method',
+                  value: {
+                    stringValue: 'GET',
+                  },
                 },
-              },
-              {
-                key: 'service.name',
-                value: {
-                  stringValue: 'lb',
-                },
-              },
-            ],
-          },
-        ],
-        matched: 4,
-      },
+              ],
+            },
+          ],
+          matched: 2,
+        },
+      ],
     },
     {
       traceID: '480691f7c6f20',
