@@ -5,6 +5,7 @@ import React from 'react';
 import { dateMath, dateTime, EventBus, LoadingState, TimeRange, toDataFrame, VizOrientation } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
 import { BarGaugeDisplayMode, BarGaugeValueMode } from '@grafana/schema';
+import { BarGaugeNamePlacement, BarGaugeSizing } from '@grafana/schema/dist/esm/common/common.gen';
 
 import { BarGaugePanel, BarGaugePanelProps } from './BarGaugePanel';
 
@@ -99,9 +100,12 @@ function buildPanelData(overrideValues?: Partial<BarGaugePanelProps>): BarGaugeP
       },
       orientation: VizOrientation.Horizontal,
       showUnfilled: true,
+      maxVizHeight: 100,
       minVizHeight: 10,
       minVizWidth: 0,
       valueMode: BarGaugeValueMode.Color,
+      namePlacement: BarGaugeNamePlacement.Auto,
+      sizing: BarGaugeSizing.Auto,
     },
     transparent: false,
     timeRange,
