@@ -15,9 +15,10 @@ import { getElementTypes, onAddItem } from '../utils';
 type Props = {
   scene: Scene;
   panel: CanvasPanel;
+  onVisibilityChange: (v: boolean) => void;
 };
 
-export const CanvasContextMenu = ({ scene, panel }: Props) => {
+export const CanvasContextMenu = ({ scene, panel, onVisibilityChange }: Props) => {
   const inlineEditorOpen = panel.state.openInlineEdit;
   const [isMenuVisible, setIsMenuVisible] = useState<boolean>(false);
   const [anchorPoint, setAnchorPoint] = useState<AnchorPoint>({ x: 0, y: 0 });
@@ -29,7 +30,7 @@ export const CanvasContextMenu = ({ scene, panel }: Props) => {
 
   const handleContextMenu = useCallback(
     (event: Event) => {
-      if (!(event instanceof MouseEvent)) {
+      if (!(event instanceof MouseEvent) || event.ctrlKey) {
         return;
       }
 
@@ -45,8 +46,9 @@ export const CanvasContextMenu = ({ scene, panel }: Props) => {
       }
       setAnchorPoint({ x: event.pageX, y: event.pageY });
       setIsMenuVisible(true);
+      onVisibilityChange(true);
     },
-    [scene, panel]
+    [scene, panel, onVisibilityChange]
   );
 
   useEffect(() => {
@@ -65,9 +67,11 @@ export const CanvasContextMenu = ({ scene, panel }: Props) => {
 
   const closeContextMenu = () => {
     setIsMenuVisible(false);
+    onVisibilityChange(false);
   };
 
   const renderMenuItems = () => {
+    // This is disabled when panel is in edit mode because opening inline editor over panel editor is not ideal UX
     const openCloseEditorMenuItem = !scene.isPanelEditing && (
       <MenuItem
         label={inlineEditorOpen ? 'Close Editor' : 'Open Editor'}
@@ -114,9 +118,10 @@ export const CanvasContextMenu = ({ scene, panel }: Props) => {
         let offsetY = anchorPoint.y;
         let offsetX = anchorPoint.x;
         if (scene.div) {
+          const transformScale = scene.scale;
           const sceneContainerDimensions = scene.div.getBoundingClientRect();
-          offsetY = offsetY - sceneContainerDimensions.top;
-          offsetX = offsetX - sceneContainerDimensions.left;
+          offsetY = (offsetY - sceneContainerDimensions.top) / transformScale;
+          offsetX = (offsetX - sceneContainerDimensions.left) / transformScale;
         }
 
         onAddItem(option, rootLayer, {
@@ -135,7 +140,7 @@ export const CanvasContextMenu = ({ scene, panel }: Props) => {
       return submenuItems;
     };
 
-    const addItemMenuItem = !scene.isPanelEditing && (
+    const addItemMenuItem = (
       <MenuItem
         label="Add item"
         className={styles.menuItem}
@@ -144,7 +149,7 @@ export const CanvasContextMenu = ({ scene, panel }: Props) => {
       />
     );
 
-    const setBackgroundMenuItem = !scene.isPanelEditing && (
+    const setBackgroundMenuItem = (
       <MenuItem
         label={'Set background'}
         onClick={() => {
