@@ -1,10 +1,12 @@
 import { FieldConfigProperty, PanelOptionsEditorBuilder, PanelPlugin } from '@grafana/data';
+import { config } from '@grafana/runtime';
 import { FrameState } from 'app/features/canvas/runtime/frame';
 
 import { CanvasPanel, InstanceState } from './CanvasPanel';
 import { getConnectionEditor } from './editor/connectionEditor';
 import { getElementEditor } from './editor/element/elementEditor';
 import { getLayerEditor } from './editor/layer/layerEditor';
+import { PanZoomHelp } from './editor/panZoomHelp';
 import { canvasMigrationHandler } from './migrations';
 import { Options } from './panelcfg.gen';
 
@@ -22,6 +24,21 @@ export const addStandardCanvasEditorOptions = (builder: PanelOptionsEditorBuilde
     description: 'Enable selection of experimental element types',
     defaultValue: true,
   });
+
+  builder.addBooleanSwitch({
+    path: 'panZoom',
+    name: 'Pan and zoom',
+    description: 'Enable pan and zoom',
+    defaultValue: false,
+    showIf: (opts) => config.featureToggles.canvasPanelPanZoom,
+  });
+  builder.addCustomEditor({
+    id: 'panZoomHelp',
+    path: 'panZoomHelp',
+    name: '',
+    editor: PanZoomHelp,
+    showIf: (opts) => config.featureToggles.canvasPanelPanZoom && opts.panZoom,
+  });
 };
 
 export const plugin = new PanelPlugin<Options>(CanvasPanel)
