@@ -1,13 +1,14 @@
 import React, { PureComponent } from 'react';
 
 import { FieldDisplay, getDisplayProcessor, getFieldDisplayValues, PanelProps } from '@grafana/data';
+import { BarGaugeSizing, VizOrientation } from '@grafana/schema';
 import { DataLinksContextMenu, Gauge, VizRepeater, VizRepeaterRenderValueProps } from '@grafana/ui';
 import { DataLinksContextMenuApi } from '@grafana/ui/src/components/DataLinks/DataLinksContextMenu';
 import { config } from 'app/core/config';
 
 import { clearNameForSingleSeries } from '../bargauge/BarGaugePanel';
 
-import { Options } from './panelcfg.gen';
+import { defaultOptions, Options } from './panelcfg.gen';
 
 export class GaugePanel extends PureComponent<PanelProps<Options>> {
   renderComponent = (
@@ -31,6 +32,7 @@ export class GaugePanel extends PureComponent<PanelProps<Options>> {
         theme={config.theme2}
         onClick={openMenu}
         className={targetClassName}
+        orientation={options.orientation}
       />
     );
   };
@@ -77,9 +79,25 @@ export class GaugePanel extends PureComponent<PanelProps<Options>> {
     });
   };
 
+  calculateGaugeSize = () => {
+    const { options } = this.props;
+
+    const orientation = options.orientation;
+    const isManualSizing = options.sizing === BarGaugeSizing.Manual;
+    const isVerticalOrientation = orientation === VizOrientation.Vertical;
+    const isHorizontalOrientation = orientation === VizOrientation.Horizontal;
+
+    const minVizWidth = isManualSizing && isVerticalOrientation ? options.minVizWidth : defaultOptions.minVizWidth;
+    const minVizHeight = isManualSizing && isHorizontalOrientation ? options.minVizHeight : defaultOptions.minVizHeight;
+
+    return { minVizWidth, minVizHeight };
+  };
+
   render() {
     const { height, width, data, renderCounter, options } = this.props;
 
+    const { minVizHeight, minVizWidth } = this.calculateGaugeSize();
+
     return (
       <VizRepeater
         getValues={this.getValues}
@@ -90,6 +108,8 @@ export class GaugePanel extends PureComponent<PanelProps<Options>> {
         autoGrid={true}
         renderCounter={renderCounter}
         orientation={options.orientation}
+        minVizHeight={minVizHeight}
+        minVizWidth={minVizWidth}
       />
     );
   }
