@@ -3,7 +3,7 @@ import { css, cx } from '@emotion/css';
 import React, { PureComponent } from 'react';
 
 import { PanelProps } from '@grafana/data';
-import { config } from '@grafana/runtime';
+import { config, reportInteraction } from '@grafana/runtime';
 import { Button, Spinner, stylesFactory } from '@grafana/ui';
 import { contextSrv } from 'app/core/core';
 import { backendSrv } from 'app/core/services/backend_srv';
@@ -11,7 +11,7 @@ import { getDashboardSrv } from 'app/features/dashboard/services/DashboardSrv';
 
 import { Step } from './components/Step';
 import { getSteps } from './steps';
-import { Card, SetupStep } from './types';
+import { SetupStep } from './types';
 
 interface State {
   checksDone: boolean;
@@ -30,7 +30,7 @@ export class GettingStarted extends PureComponent<PanelProps, State> {
     const { steps } = this.state;
 
     const checkedStepsPromises: Array<Promise<SetupStep>> = steps.map(async (step: SetupStep) => {
-      const checkedCardsPromises: Array<Promise<Card>> = step.cards.map((card: Card) => {
+      const checkedCardsPromises = step.cards.map(async (card) => {
         return card.check().then((passed) => {
           return { ...card, done: passed };
         });
@@ -53,12 +53,14 @@ export class GettingStarted extends PureComponent<PanelProps, State> {
   }
 
   onForwardClick = () => {
+    reportInteraction('grafana_getting_started_button_to_advanced_tutorials');
     this.setState((prevState) => ({
       currentStep: prevState.currentStep + 1,
     }));
   };
 
   onPreviousClick = () => {
+    reportInteraction('grafana_getting_started_button_to_basic_tutorials');
     this.setState((prevState) => ({
       currentStep: prevState.currentStep - 1,
     }));
@@ -69,9 +71,11 @@ export class GettingStarted extends PureComponent<PanelProps, State> {
     const dashboard = getDashboardSrv().getCurrent();
     const panel = dashboard?.getPanelById(id);
 
+    reportInteraction('grafana_getting_started_remove_panel');
+
     dashboard?.removePanel(panel!);
 
-    backendSrv.put('/api/user/helpflags/1', undefined, { showSuccessAlert: false }).then((res: any) => {
+    backendSrv.put('/api/user/helpflags/1', undefined, { showSuccessAlert: false }).then((res) => {
       contextSrv.user.helpFlags1 = res.helpFlags1;
     });
   };
@@ -86,7 +90,7 @@ export class GettingStarted extends PureComponent<PanelProps, State> {
         {!checksDone ? (
           <div className={styles.loading}>
             <div className={styles.loadingText}>Checking completed setup steps</div>
-            <Spinner size={24} inline />
+            <Spinner size="xl" inline />
           </div>
         ) : (
           <>
@@ -97,7 +101,7 @@ export class GettingStarted extends PureComponent<PanelProps, State> {
               <Button
                 className={cx(styles.backForwardButtons, styles.previous)}
                 onClick={this.onPreviousClick}
-                aria-label="To advanced tutorials"
+                aria-label="To basic tutorials"
                 icon="angle-left"
                 variant="secondary"
               />
@@ -109,7 +113,7 @@ export class GettingStarted extends PureComponent<PanelProps, State> {
               <Button
                 className={cx(styles.backForwardButtons, styles.forward)}
                 onClick={this.onForwardClick}
-                aria-label="To basic tutorials"
+                aria-label="To advanced tutorials"
                 icon="angle-right"
                 variant="secondary"
               />
@@ -124,86 +128,83 @@ export class GettingStarted extends PureComponent<PanelProps, State> {
 const getStyles = stylesFactory(() => {
   const theme = config.theme2;
   return {
-    container: css`
-      display: flex;
-      flex-direction: column;
-      height: 100%;
-      // background: url(public/img/getting_started_bg_${theme.colors.mode}.svg) no-repeat;
-      background-size: cover;
-      padding: ${theme.spacing(4)} ${theme.spacing(2)} 0;
-    `,
-    content: css`
-      label: content;
-      display: flex;
-      justify-content: center;
+    container: css({
+      display: 'flex',
+      flexDirection: 'column',
+      height: '100%',
+      backgroundSize: 'cover',
+      padding: `${theme.spacing(4)} ${theme.spacing(2)} 0`,
+    }),
+    content: css({
+      label: 'content',
+      display: 'flex',
+      justifyContent: 'center',
 
-      ${theme.breakpoints.down('xxl')} {
-        margin-left: ${theme.spacing(3)};
-        justify-content: flex-start;
-      }
-    `,
-    header: css`
-      label: header;
-      margin-bottom: ${theme.spacing(3)};
-      display: flex;
-      flex-direction: column;
+      [theme.breakpoints.down('xxl')]: {
+        marginLeft: theme.spacing(3),
+        justifyContent: 'flex-start',
+      },
+    }),
+    header: css({
+      label: 'header',
+      marginBottom: theme.spacing(3),
+      display: 'flex',
+      flexDirection: 'column',
 
-      ${theme.breakpoints.down('lg')} {
-        flex-direction: row;
-      }
-    `,
-    headerLogo: css`
-      height: 58px;
-      padding-right: ${theme.spacing(2)};
-      display: none;
+      [theme.breakpoints.down('lg')]: {
+        flexDirection: 'row',
+      },
+    }),
+    headerLogo: css({
+      height: '58px',
+      paddingRight: theme.spacing(2),
+      display: 'none',
 
-      ${theme.breakpoints.up('md')} {
-        display: block;
-      }
-    `,
-    heading: css`
-      label: heading;
-      margin-right: ${theme.spacing(3)};
-      margin-bottom: ${theme.spacing(3)};
-      flex-grow: 1;
-      display: flex;
+      [theme.breakpoints.up('md')]: {
+        display: 'block',
+      },
+    }),
+    heading: css({
+      label: 'heading',
+      marginRight: theme.spacing(3),
+      marginBottom: theme.spacing(3),
+      flexGrow: 1,
+      display: 'flex',
 
-      ${theme.breakpoints.up('md')} {
-        margin-bottom: 0;
-      }
-    `,
-    backForwardButtons: css`
-      position: absolute;
-      top: 50%;
-      transform: translateY(-50%);
-    `,
-    previous: css`
-      left: 10px;
-
-      ${theme.breakpoints.down('md')} {
-        left: 0;
-      }
-    `,
-    forward: css`
-      right: 10px;
-
-      ${theme.breakpoints.down('md')} {
-        right: 0;
-      }
-    `,
-    dismiss: css`
-      align-self: flex-end;
-      text-decoration: underline;
-      margin-bottom: ${theme.spacing(1)};
-    `,
-    loading: css`
-      display: flex;
-      justify-content: center;
-      align-items: center;
-      height: 100%;
-    `,
-    loadingText: css`
-      margin-right: ${theme.spacing(1)};
-    `,
+      [theme.breakpoints.up('md')]: {
+        marginBottom: 0,
+      },
+    }),
+    backForwardButtons: css({
+      position: 'absolute',
+      top: '50%',
+      transform: 'translateY(-50%)',
+    }),
+    previous: css({
+      left: '10px',
+      [theme.breakpoints.down('md')]: {
+        left: 0,
+      },
+    }),
+    forward: css({
+      right: '10px',
+      [theme.breakpoints.down('md')]: {
+        right: 0,
+      },
+    }),
+    dismiss: css({
+      alignSelf: 'flex-end',
+      textDecoration: 'underline',
+      marginBottom: theme.spacing(1),
+    }),
+    loading: css({
+      display: 'flex',
+      justifyContent: 'center',
+      alignItems: 'center',
+      height: '100%',
+    }),
+    loadingText: css({
+      marginRight: theme.spacing(1),
+    }),
   };
 });
