@@ -1,10 +1,10 @@
 import { css } from '@emotion/css';
-import React, { FC } from 'react';
+import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { useStyles2 } from '@grafana/ui';
 
-import { Card, SetupStep, TutorialCardType } from '../types';
+import { SetupStep } from '../types';
 
 import { DocsCard } from './DocsCard';
 import { TutorialCard } from './TutorialCard';
@@ -13,7 +13,7 @@ interface Props {
   step: SetupStep;
 }
 
-export const Step: FC<Props> = ({ step }) => {
+export const Step = ({ step }: Props) => {
   const styles = useStyles2(getStyles);
 
   return (
@@ -23,10 +23,10 @@ export const Step: FC<Props> = ({ step }) => {
         <p>{step.info}</p>
       </div>
       <div className={styles.cards}>
-        {step.cards.map((card: Card | TutorialCardType, index: number) => {
+        {step.cards.map((card, index) => {
           const key = `${card.title}-${index}`;
           if (card.type === 'tutorial') {
-            return <TutorialCard key={key} card={card as TutorialCardType} />;
+            return <TutorialCard key={key} card={card} />;
           }
           return <DocsCard key={key} card={card} />;
         })}
@@ -60,11 +60,7 @@ const getStyles = (theme: GrafanaTheme2) => {
       overflow-y: hidden;
       width: 100%;
       display: flex;
-      justify-content: center;
-
-      ${theme.breakpoints.down('xxl')} {
-        justify-content: flex-start;
-      }
+      justify-content: flex-start;
     `,
   };
 };
