@@ -9,12 +9,7 @@ import { NodeGraph } from './NodeGraph';
 import { NodeGraphOptions } from './types';
 import { getNodeGraphDataFrames } from './utils';
 
-export const NodeGraphPanel: React.FunctionComponent<PanelProps<NodeGraphOptions>> = ({
-  width,
-  height,
-  data,
-  options,
-}) => {
+export const NodeGraphPanel = ({ width, height, data, options }: PanelProps<NodeGraphOptions>) => {
   const getLinks = useLinks(data.timeRange);
   if (!data || !data.series.length) {
     return (
