@@ -370,7 +370,7 @@ function makeNode(index: number) {
 }
 
 function nodesFrame() {
-  const fields: any = {
+  const fields = {
     [NodeGraphDataFrameFieldNames.id]: {
       values: [],
       type: FieldType.string,
@@ -394,17 +394,17 @@ function nodesFrame() {
     [NodeGraphDataFrameFieldNames.arc + 'success']: {
       values: [],
       type: FieldType.number,
-      config: { color: { fixedColor: 'green' } },
+      config: { color: { mode: FieldColorModeId.Fixed, fixedColor: 'green' } },
     },
     [NodeGraphDataFrameFieldNames.arc + 'errors']: {
       values: [],
       type: FieldType.number,
-      config: { color: { fixedColor: 'red' } },
+      config: { color: { mode: FieldColorModeId.Fixed, fixedColor: 'red' } },
     },
     [NodeGraphDataFrameFieldNames.color]: {
       values: [],
       type: FieldType.number,
-      config: { color: { mode: 'continuous-GrYlRd' } },
+      config: { color: { mode: FieldColorModeId.ContinuousGrYlRd } },
     },
     [NodeGraphDataFrameFieldNames.icon]: {
       values: [],
@@ -418,8 +418,8 @@ function nodesFrame() {
 
   return new MutableDataFrame({
     name: 'nodes',
-    fields: Object.keys(fields).map((key) => ({
-      ...fields[key],
+    fields: Object.entries(fields).map(([key, value]) => ({
+      ...value,
       name: key,
     })),
   });
@@ -440,7 +440,7 @@ export function makeEdgesDataFrame(
 }
 
 function edgesFrame() {
-  const fields: any = {
+  const fields = {
     [NodeGraphDataFrameFieldNames.id]: {
       values: [],
       type: FieldType.string,
@@ -465,8 +465,8 @@ function edgesFrame() {
 
   return new MutableDataFrame({
     name: 'edges',
-    fields: Object.keys(fields).map((key) => ({
-      ...fields[key],
+    fields: Object.entries(fields).map(([key, value]) => ({
+      ...value,
       name: key,
     })),
   });
