@@ -1,6 +1,6 @@
 import { css, cx } from '@emotion/css';
-import React, { HTMLAttributes, useState } from 'react';
-import { usePopper } from 'react-popper';
+import { autoUpdate, flip, shift, useDismiss, useFloating, useInteractions } from '@floating-ui/react';
+import React, { HTMLAttributes } from 'react';
 
 import { colorManipulator, DataFrame, getDisplayProcessor, GrafanaTheme2, TimeZone } from '@grafana/data';
 import { PlotSelection, useStyles2, useTheme2, Portal, DEFAULT_ANNOTATION_COLOR } from '@grafana/ui';
@@ -31,22 +31,35 @@ export const AnnotationEditor = ({
   const theme = useTheme2();
   const styles = useStyles2(getStyles);
   const commonStyles = useStyles2(getCommonAnnotationStyles);
-  const [popperTrigger, setPopperTrigger] = useState<HTMLDivElement | null>(null);
-  const [editorPopover, setEditorPopover] = useState<HTMLDivElement | null>(null);
 
-  const popper = usePopper(popperTrigger, editorPopover, {
-    modifiers: [
-      { name: 'arrow', enabled: false },
-      {
-        name: 'preventOverflow',
-        enabled: true,
-        options: {
-          rootBoundary: 'viewport',
-        },
-      },
-    ],
+  // the order of middleware is important!
+  const middleware = [
+    flip({
+      fallbackAxisSideDirection: 'end',
+      // see https://floating-ui.com/docs/flip#combining-with-shift
+      crossAxis: false,
+      boundary: document.body,
+    }),
+    shift(),
+  ];
+
+  const { context, refs, floatingStyles } = useFloating({
+    open: true,
+    placement: 'bottom',
+    onOpenChange: (open) => {
+      if (!open) {
+        onDismiss();
+      }
+    },
+    middleware,
+    whileElementsMounted: autoUpdate,
+    strategy: 'fixed',
   });
 
+  const dismiss = useDismiss(context);
+
+  const { getReferenceProps, getFloatingProps } = useInteractions([dismiss]);
+
   let xField = data.fields[0];
   if (!xField) {
     return null;
@@ -62,23 +75,24 @@ export const AnnotationEditor = ({
         >
           <div // Annotation marker
             className={cx(
-              css`
-                position: absolute;
-                top: ${selection.bbox.top}px;
-                left: ${selection.bbox.left}px;
-                width: ${selection.bbox.width}px;
-                height: ${selection.bbox.height}px;
-              `,
+              css({
+                position: 'absolute',
+                top: selection.bbox.top,
+                left: selection.bbox.left,
+                width: selection.bbox.width,
+                height: selection.bbox.height,
+              }),
               isRegionAnnotation ? styles.overlayRange(annotation) : styles.overlay(annotation)
             )}
           >
             <div
-              ref={setPopperTrigger}
+              ref={refs.setReference}
               className={
                 isRegionAnnotation
                   ? cx(commonStyles(annotation).markerBar, styles.markerBar)
                   : cx(commonStyles(annotation).markerTriangle, styles.markerTriangle)
               }
+              {...getReferenceProps()}
             />
           </div>
         </div>
@@ -88,9 +102,9 @@ export const AnnotationEditor = ({
           timeFormatter={(v) => xFieldFmt(v).text}
           onSave={onSave}
           onDismiss={onDismiss}
-          ref={setEditorPopover}
-          style={popper.styles.popper}
-          {...popper.attributes.popper}
+          ref={refs.setFloating}
+          style={floatingStyles}
+          {...getFloatingProps()}
         />
       </>
     </Portal>
@@ -101,27 +115,27 @@ const getStyles = (theme: GrafanaTheme2) => {
   return {
     overlay: (annotation?: AnnotationsDataFrameViewDTO) => {
       const color = theme.visualization.getColorByName(annotation?.color || DEFAULT_ANNOTATION_COLOR);
-      return css`
-        border-left: 1px dashed ${color};
-      `;
+      return css({
+        borderLeft: `1px dashed ${color}`,
+      });
     },
     overlayRange: (annotation?: AnnotationsDataFrameViewDTO) => {
       const color = theme.visualization.getColorByName(annotation?.color || DEFAULT_ANNOTATION_COLOR);
-      return css`
-        background: ${colorManipulator.alpha(color, 0.1)};
-        border-left: 1px dashed ${color};
-        border-right: 1px dashed ${color};
-      `;
+      return css({
+        background: colorManipulator.alpha(color, 0.1),
+        borderLeft: `1px dashed ${color}`,
+        borderRight: `1px dashed ${color}`,
+      });
     },
-    markerTriangle: css`
-      top: calc(100% + 2px);
-      left: -4px;
-      position: absolute;
-    `,
-    markerBar: css`
-      top: 100%;
-      left: 0;
-      position: absolute;
-    `,
+    markerTriangle: css({
+      top: `calc(100% + 2px)`,
+      left: '-4px',
+      position: 'absolute',
+    }),
+    markerBar: css({
+      top: '100%',
+      left: 0,
+      position: 'absolute',
+    }),
   };
 };
