@@ -1,6 +1,15 @@
 import { css } from '@emotion/css';
-import React, { HTMLAttributes, useCallback, useRef, useState } from 'react';
-import { usePopper } from 'react-popper';
+import {
+  autoUpdate,
+  flip,
+  safePolygon,
+  shift,
+  useDismiss,
+  useFloating,
+  useHover,
+  useInteractions,
+} from '@floating-ui/react';
+import React, { HTMLAttributes, useCallback, useState } from 'react';
 
 import { GrafanaTheme2, dateTimeFormat, systemDateFormats, TimeZone } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
@@ -21,19 +30,6 @@ interface Props extends HTMLAttributes<HTMLDivElement> {
 
 const MIN_REGION_ANNOTATION_WIDTH = 6;
 
-const POPPER_CONFIG = {
-  modifiers: [
-    { name: 'arrow', enabled: false },
-    {
-      name: 'preventOverflow',
-      enabled: true,
-      options: {
-        rootBoundary: 'viewport',
-      },
-    },
-  ],
-};
-
 export function AnnotationMarker({ annotation, timeZone, width }: Props) {
   const { canEditAnnotations, canDeleteAnnotations, ...panelCtx } = usePanelContext();
   const commonStyles = useStyles2(getCommonAnnotationStyles);
@@ -41,14 +37,33 @@ export function AnnotationMarker({ annotation, timeZone, width }: Props) {
 
   const [isOpen, setIsOpen] = useState(false);
   const [isEditing, setIsEditing] = useState(false);
-  const [markerRef, setMarkerRef] = useState<HTMLDivElement | null>(null);
-  const [tooltipRef, setTooltipRef] = useState<HTMLDivElement | null>(null);
-  const [editorRef, setEditorRef] = useState<HTMLDivElement | null>(null);
 
-  const popoverRenderTimeout = useRef<NodeJS.Timeout>();
+  // the order of middleware is important!
+  const middleware = [
+    flip({
+      fallbackAxisSideDirection: 'end',
+      // see https://floating-ui.com/docs/flip#combining-with-shift
+      crossAxis: false,
+      boundary: document.body,
+    }),
+    shift(),
+  ];
 
-  const popper = usePopper(markerRef, tooltipRef, POPPER_CONFIG);
-  const editorPopper = usePopper(markerRef, editorRef, POPPER_CONFIG);
+  const { context, refs, floatingStyles } = useFloating({
+    open: isOpen,
+    placement: 'bottom',
+    onOpenChange: setIsOpen,
+    middleware,
+    whileElementsMounted: autoUpdate,
+    strategy: 'fixed',
+  });
+
+  const hover = useHover(context, {
+    handleClose: safePolygon(),
+  });
+  const dismiss = useDismiss(context);
+
+  const { getReferenceProps, getFloatingProps } = useInteractions([dismiss, hover]);
 
   const onAnnotationEdit = useCallback(() => {
     setIsEditing(true);
@@ -61,25 +76,6 @@ export function AnnotationMarker({ annotation, timeZone, width }: Props) {
     }
   }, [annotation, panelCtx]);
 
-  const onMouseEnter = useCallback(() => {
-    if (popoverRenderTimeout.current) {
-      clearTimeout(popoverRenderTimeout.current);
-    }
-    setIsOpen(true);
-  }, [setIsOpen]);
-
-  const onPopoverMouseEnter = useCallback(() => {
-    if (popoverRenderTimeout.current) {
-      clearTimeout(popoverRenderTimeout.current);
-    }
-  }, []);
-
-  const onMouseLeave = useCallback(() => {
-    popoverRenderTimeout.current = setTimeout(() => {
-      setIsOpen(false);
-    }, 100);
-  }, [setIsOpen]);
-
   const timeFormatter = useCallback(
     (value: number) => {
       return dateTimeFormat(value, {
@@ -124,25 +120,17 @@ export function AnnotationMarker({ annotation, timeZone, width }: Props) {
   return (
     <>
       <div
-        ref={setMarkerRef}
-        onMouseEnter={onMouseEnter}
-        onMouseLeave={onMouseLeave}
+        ref={refs.setReference}
         className={!isRegionAnnotation ? styles.markerWrapper : undefined}
         data-testid={selectors.pages.Dashboard.Annotations.marker}
+        {...getReferenceProps()}
       >
         {marker}
       </div>
 
       {isOpen && (
         <Portal>
-          <div
-            ref={setTooltipRef}
-            style={popper.styles.popper}
-            {...popper.attributes.popper}
-            className={styles.tooltip}
-            onMouseEnter={onPopoverMouseEnter}
-            onMouseLeave={onMouseLeave}
-          >
+          <div className={styles.tooltip} ref={refs.setFloating} style={floatingStyles} {...getFloatingProps()}>
             {renderTooltip()}
           </div>
         </Portal>
@@ -155,9 +143,9 @@ export function AnnotationMarker({ annotation, timeZone, width }: Props) {
             onSave={() => setIsEditing(false)}
             timeFormatter={timeFormatter}
             annotation={annotation}
-            ref={setEditorRef}
-            style={editorPopper.styles.popper}
-            {...editorPopper.attributes.popper}
+            ref={refs.setFloating}
+            style={floatingStyles}
+            {...getFloatingProps()}
           />
         </Portal>
       )}
@@ -167,16 +155,13 @@ export function AnnotationMarker({ annotation, timeZone, width }: Props) {
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    markerWrapper: css`
-      label: markerWrapper;
-      padding: 0 4px 4px 4px;
-    `,
-    wrapper: css`
-      max-width: 400px;
-    `,
-    tooltip: css`
-      ${getTooltipContainerStyles(theme)};
-      padding: 0;
-    `,
+    markerWrapper: css({
+      label: 'markerWrapper',
+      padding: theme.spacing(0, 0.5, 0.5, 0.5),
+    }),
+    tooltip: css({
+      ...getTooltipContainerStyles(theme),
+      padding: 0,
+    }),
   };
 };
