@@ -1,7 +1,6 @@
 import { configureStore as reduxConfigureStore, createListenerMiddleware } from '@reduxjs/toolkit';
 import { setupListeners } from '@reduxjs/toolkit/query';
 
-import { togglesApi } from 'app/features/admin/AdminFeatureTogglesAPI';
 import { browseDashboardsAPI } from 'app/features/browse-dashboards/api/browseDashboardsAPI';
 import { publicDashboardApi } from 'app/features/dashboard/api/publicDashboardApi';
 import { StoreState } from 'app/types/store';
@@ -29,8 +28,7 @@ export function configureStore(initialState?: Partial<StoreState>) {
         listenerMiddleware.middleware,
         alertingApi.middleware,
         publicDashboardApi.middleware,
-        browseDashboardsAPI.middleware,
-        togglesApi.middleware
+        browseDashboardsAPI.middleware
       ),
     devTools: process.env.NODE_ENV !== 'production',
     preloadedState: {
