@@ -1,13 +1,11 @@
 module.exports = {
   // Default namespace used in your i18next config
   defaultNamespace: 'grafana',
-
-  locales: ['en-US', 'fr-FR', 'es-ES', "de-DE", "zh-Hans", 'pseudo-LOCALE'],
+  // Adds changes only to en-US when extracting keys, every other language is provided by Crowdin
+  locales: ['en-US'],
 
   output: './public/locales/$LOCALE/$NAMESPACE.json',
 
-  pluralSeparator: '__',
-
   sort: true,
 
   createOldCatalogs: false,
@@ -15,7 +13,4 @@ module.exports = {
   failOnWarnings: true,
 
   verbose: false,
-
-  // Don't include default values for English, they'll remain in the source code
-  skipDefaultValues: (locale) => locale !== 'en-US',
 };
