@@ -1,9 +1,12 @@
+import { Config } from 'app/plugins/panel/nodeGraph/layout';
+import { EdgeDatum, NodeDatum } from 'app/plugins/panel/nodeGraph/types';
+
 const { layout } = jest.requireActual('../../app/plugins/panel/nodeGraph/layout.worker.js');
 
 class LayoutMockWorker {
   timeout: number | undefined;
   constructor() {}
-  postMessage(data: any) {
+  postMessage(data: { nodes: NodeDatum[]; edges: EdgeDatum[]; config: Config }) {
     const { nodes, edges, config } = data;
     this.timeout = window.setTimeout(() => {
       this.timeout = undefined;
